import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface ActiveDirectoryDomainConfig extends TerraformMetaArguments {
    /**
     * The name of delegated administrator account used to perform Active Directory operations.
     *
     * If not specified, setupadmin will be used.
     */
    readonly admin?: string;
    /**
     * The full names of the Google Compute Engine networks the domain instance is connected to.
     *
     * The domain is only available on networks listed in authorizedNetworks.
     * If CIDR subnets overlap between networks, domain creation will fail.
     */
    readonly authorizedNetworks?: string[];
    /**
     * The fully qualified domain name.
     *
     * e.g. mydomain.myorganization.com, with the restrictions,
     * https://cloud.google.com/managed-microsoft-ad/reference/rest/v1/projects.locations.global.domains.
     */
    readonly domainName: string;
    /**
     * Resource labels that can contain user-provided metadata.
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Locations where domain needs to be provisioned.
     *
     * [regions][compute/docs/regions-zones/]
     * e.g. us-west1 or us-east4 Service supports up to 4 locations at once. Each location will use a /26 block.
     */
    readonly locations: string[];
    /**
     *
     */
    readonly project?: string;
    /**
     * The CIDR range of internal addresses that are reserved for this domain.
     *
     * Reserved networks must be /24 or larger.
     * Ranges must be unique and non-overlapping with existing subnets in authorizedNetworks
     */
    readonly reservedIpRange: string;
    /**
     * timeouts block.
     */
    readonly timeouts?: ActiveDirectoryDomainTimeouts;
}
/**
 *
 */
export interface ActiveDirectoryDomainTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class ActiveDirectoryDomain extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: ActiveDirectoryDomainConfig);
    private _admin?;
    /**
     *
     */
    get admin(): string;
    /**
     *
     */
    set admin(value: string);
    /**
     *
     */
    resetAdmin(): void;
    /**
     *
     */
    get adminInput(): string | undefined;
    private _authorizedNetworks?;
    /**
     *
     */
    get authorizedNetworks(): string[];
    /**
     *
     */
    set authorizedNetworks(value: string[]);
    /**
     *
     */
    resetAuthorizedNetworks(): void;
    /**
     *
     */
    get authorizedNetworksInput(): string[] | undefined;
    private _domainName;
    /**
     *
     */
    get domainName(): string;
    /**
     *
     */
    set domainName(value: string);
    /**
     *
     */
    get domainNameInput(): string;
    /**
     *
     */
    get fqdn(): string;
    /**
     *
     */
    get id(): string;
    private _labels?;
    /**
     *
     */
    get labels(): {
        [key: string]: string;
    };
    /**
     *
     */
    set labels(value: {
        [key: string]: string;
    });
    /**
     *
     */
    resetLabels(): void;
    /**
     *
     */
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _locations;
    /**
     *
     */
    get locations(): string[];
    /**
     *
     */
    set locations(value: string[]);
    /**
     *
     */
    get locationsInput(): string[];
    /**
     *
     */
    get name(): string;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _reservedIpRange;
    /**
     *
     */
    get reservedIpRange(): string;
    /**
     *
     */
    set reservedIpRange(value: string);
    /**
     *
     */
    get reservedIpRangeInput(): string;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): ActiveDirectoryDomainTimeouts;
    /**
     *
     */
    set timeouts(value: ActiveDirectoryDomainTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): ActiveDirectoryDomainTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
