import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface AppEngineFirewallRuleConfig extends TerraformMetaArguments {
    /**
     * The action to take if this rule matches.
     *
     * Possible values: ["UNSPECIFIED_ACTION", "ALLOW", "DENY"]
     */
    readonly action: string;
    /**
     * An optional string description of this rule.
     */
    readonly description?: string;
    /**
     * A positive integer that defines the order of rule evaluation. Rules with the lowest priority are evaluated first.
     *
     * A default rule at priority Int32.MaxValue matches all IPv4 and
     * IPv6 traffic when no previous rule matches. Only the action of
     * this rule can be modified by the user.
     */
    readonly priority?: number;
    /**
     *
     */
    readonly project?: string;
    /**
     * IP address or range, defined using CIDR notation, of requests that this rule applies to.
     */
    readonly sourceRange: string;
    /**
     * timeouts block.
     */
    readonly timeouts?: AppEngineFirewallRuleTimeouts;
}
/**
 *
 */
export interface AppEngineFirewallRuleTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class AppEngineFirewallRule extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: AppEngineFirewallRuleConfig);
    private _action;
    /**
     *
     */
    get action(): string;
    /**
     *
     */
    set action(value: string);
    /**
     *
     */
    get actionInput(): string;
    private _description?;
    /**
     *
     */
    get description(): string;
    /**
     *
     */
    set description(value: string);
    /**
     *
     */
    resetDescription(): void;
    /**
     *
     */
    get descriptionInput(): string | undefined;
    /**
     *
     */
    get id(): string;
    private _priority?;
    /**
     *
     */
    get priority(): number;
    /**
     *
     */
    set priority(value: number);
    /**
     *
     */
    resetPriority(): void;
    /**
     *
     */
    get priorityInput(): number | undefined;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _sourceRange;
    /**
     *
     */
    get sourceRange(): string;
    /**
     *
     */
    set sourceRange(value: string);
    /**
     *
     */
    get sourceRangeInput(): string;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): AppEngineFirewallRuleTimeouts;
    /**
     *
     */
    set timeouts(value: AppEngineFirewallRuleTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): AppEngineFirewallRuleTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
