import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface AppEngineStandardAppVersionConfig extends TerraformMetaArguments {
    /**
     *
     */
    readonly deleteServiceOnDestroy?: boolean;
    /**
     * Environment variables available to the application.
     */
    readonly envVariables?: {
        [key: string]: string;
    };
    /**
     * A list of the types of messages that this application is able to receive.
     *
     * Possible values: ["INBOUND_SERVICE_MAIL", "INBOUND_SERVICE_MAIL_BOUNCE", "INBOUND_SERVICE_XMPP_ERROR", "INBOUND_SERVICE_XMPP_MESSAGE", "INBOUND_SERVICE_XMPP_SUBSCRIBE", "INBOUND_SERVICE_XMPP_PRESENCE", "INBOUND_SERVICE_CHANNEL_PRESENCE", "INBOUND_SERVICE_WARMUP"]
     */
    readonly inboundServices?: string[];
    /**
     * Instance class that is used to run this version.
     *
     * Valid values are
     * AutomaticScaling: F1, F2, F4, F4_1G
     * BasicScaling or ManualScaling: B1, B2, B4, B4_1G, B8
     * Defaults to F1 for AutomaticScaling and B2 for ManualScaling and BasicScaling. If no scaling is specified, AutomaticScaling is chosen.
     */
    readonly instanceClass?: string;
    /**
     *
     */
    readonly noopOnDestroy?: boolean;
    /**
     *
     */
    readonly project?: string;
    /**
     * Desired runtime.
     *
     * Example python27.
     */
    readonly runtime: string;
    /**
     * The version of the API in the given runtime environment.
     *
     * Please see the app.yaml reference for valid values at https://cloud.google.com/appengine/docs/standard//config/appref
     */
    readonly runtimeApiVersion?: string;
    /**
     * AppEngine service resource.
     */
    readonly service: string;
    /**
     * Whether multiple requests can be dispatched to this version at once.
     */
    readonly threadsafe?: boolean;
    /**
     * Relative name of the version within the service.
     *
     * For example, 'v1'. Version names can contain only lowercase letters, numbers, or hyphens. Reserved names,"default", "latest", and any name with the prefix "ah-".
     */
    readonly versionId?: string;
    /**
     * automatic_scaling block.
     */
    readonly automaticScaling?: AppEngineStandardAppVersionAutomaticScaling[];
    /**
     * basic_scaling block.
     */
    readonly basicScaling?: AppEngineStandardAppVersionBasicScaling[];
    /**
     * deployment block.
     */
    readonly deployment: AppEngineStandardAppVersionDeployment[];
    /**
     * entrypoint block.
     */
    readonly entrypoint?: AppEngineStandardAppVersionEntrypoint[];
    /**
     * handlers block.
     */
    readonly handlers?: AppEngineStandardAppVersionHandlers[];
    /**
     * libraries block.
     */
    readonly libraries?: AppEngineStandardAppVersionLibraries[];
    /**
     * manual_scaling block.
     */
    readonly manualScaling?: AppEngineStandardAppVersionManualScaling[];
    /**
     * timeouts block.
     */
    readonly timeouts?: AppEngineStandardAppVersionTimeouts;
    /**
     * vpc_access_connector block.
     */
    readonly vpcAccessConnector?: AppEngineStandardAppVersionVpcAccessConnector[];
}
/**
 *
 */
export interface AppEngineStandardAppVersionAutomaticScalingStandardSchedulerSettings {
    /**
     * Maximum number of instances to run for this version.
     *
     * Set to zero to disable maxInstances configuration.
     */
    readonly maxInstances?: number;
    /**
     * Minimum number of instances to run for this version.
     *
     * Set to zero to disable minInstances configuration.
     */
    readonly minInstances?: number;
    /**
     * Target CPU utilization ratio to maintain when scaling.
     *
     * Should be a value in the range [0.50, 0.95], zero, or a negative value.
     */
    readonly targetCpuUtilization?: number;
    /**
     * Target throughput utilization ratio to maintain when scaling.
     *
     * Should be a value in the range [0.50, 0.95], zero, or a negative value.
     */
    readonly targetThroughputUtilization?: number;
}
/**
 *
 */
export interface AppEngineStandardAppVersionAutomaticScaling {
    /**
     * Number of concurrent requests an automatic scaling instance can accept before the scheduler spawns a new instance.
     *
     * Defaults to a runtime-specific value.
     */
    readonly maxConcurrentRequests?: number;
    /**
     * Maximum number of idle instances that should be maintained for this version.
     */
    readonly maxIdleInstances?: number;
    /**
     * Maximum amount of time that a request should wait in the pending queue before starting a new instance to handle it.
     *
     * A duration in seconds with up to nine fractional digits, terminated by 's'. Example: "3.5s".
     */
    readonly maxPendingLatency?: string;
    /**
     * Minimum number of idle instances that should be maintained for this version.
     *
     * Only applicable for the default version of a service.
     */
    readonly minIdleInstances?: number;
    /**
     * Minimum amount of time a request should wait in the pending queue before starting a new instance to handle it.
     *
     * A duration in seconds with up to nine fractional digits, terminated by 's'. Example: "3.5s".
     */
    readonly minPendingLatency?: string;
    /**
     * standard_scheduler_settings block.
     */
    readonly standardSchedulerSettings?: AppEngineStandardAppVersionAutomaticScalingStandardSchedulerSettings[];
}
/**
 *
 */
export interface AppEngineStandardAppVersionBasicScaling {
    /**
     * Duration of time after the last request that an instance must wait before the instance is shut down.
     *
     * A duration in seconds with up to nine fractional digits, terminated by 's'. Example: "3.5s". Defaults to 900s.
     */
    readonly idleTimeout?: string;
    /**
     * Maximum number of instances to create for this version.
     *
     * Must be in the range [1.0, 200.0].
     */
    readonly maxInstances: number;
}
/**
 *
 */
export interface AppEngineStandardAppVersionDeploymentFiles {
    /**
     *
     */
    readonly name: string;
    /**
     * SHA1 checksum of the file.
     */
    readonly sha1Sum?: string;
    /**
     * Source URL.
     */
    readonly sourceUrl: string;
}
/**
 *
 */
export interface AppEngineStandardAppVersionDeploymentZip {
    /**
     * files count.
     */
    readonly filesCount?: number;
    /**
     * Source URL.
     */
    readonly sourceUrl: string;
}
/**
 *
 */
export interface AppEngineStandardAppVersionDeployment {
    /**
     * files block.
     */
    readonly files?: AppEngineStandardAppVersionDeploymentFiles[];
    /**
     * zip block.
     */
    readonly zip?: AppEngineStandardAppVersionDeploymentZip[];
}
/**
 *
 */
export interface AppEngineStandardAppVersionEntrypoint {
    /**
     * The format should be a shell command that can be fed to bash -c.
     */
    readonly shell: string;
}
/**
 *
 */
export interface AppEngineStandardAppVersionHandlersScript {
    /**
     * Path to the script from the application root directory.
     */
    readonly scriptPath: string;
}
/**
 *
 */
export interface AppEngineStandardAppVersionHandlersStaticFiles {
    /**
     * Whether files should also be uploaded as code data.
     *
     * By default, files declared in static file handlers are uploaded as
     * static data and are only served to end users; they cannot be read by the application. If enabled, uploads are charged
     * against both your code and static data storage resource quotas.
     */
    readonly applicationReadable?: boolean;
    /**
     * Time a static file served by this handler should be cached by web proxies and browsers.
     *
     * A duration in seconds with up to nine fractional digits, terminated by 's'. Example "3.5s".
     */
    readonly expiration?: string;
    /**
     * HTTP headers to use for all responses from these URLs.
     *
     * An object containing a list of "key:value" value pairs.".
     */
    readonly httpHeaders?: {
        [key: string]: string;
    };
    /**
     * MIME type used to serve all files served by this handler.
     *
     * Defaults to file-specific MIME types, which are derived from each file's filename extension.
     */
    readonly mimeType?: string;
    /**
     * Path to the static files matched by the URL pattern, from the application root directory.
     *
     * The path can refer to text matched in groupings in the URL pattern.
     */
    readonly path?: string;
    /**
     * Whether this handler should match the request if the file referenced by the handler does not exist.
     */
    readonly requireMatchingFile?: boolean;
    /**
     * Regular expression that matches the file paths for all files that should be referenced by this handler.
     */
    readonly uploadPathRegex?: string;
}
/**
 *
 */
export interface AppEngineStandardAppVersionHandlers {
    /**
     * Actions to take when the user is not logged in.
     *
     * Possible values: ["AUTH_FAIL_ACTION_REDIRECT", "AUTH_FAIL_ACTION_UNAUTHORIZED"]
     */
    readonly authFailAction?: string;
    /**
     * Methods to restrict access to a URL based on login status.
     *
     * Possible values: ["LOGIN_OPTIONAL", "LOGIN_ADMIN", "LOGIN_REQUIRED"]
     */
    readonly login?: string;
    /**
     * 30x code to use when performing redirects for the secure field.
     *
     * Possible values: ["REDIRECT_HTTP_RESPONSE_CODE_301", "REDIRECT_HTTP_RESPONSE_CODE_302", "REDIRECT_HTTP_RESPONSE_CODE_303", "REDIRECT_HTTP_RESPONSE_CODE_307"]
     */
    readonly redirectHttpResponseCode?: string;
    /**
     * Security (HTTPS) enforcement for this URL.
     *
     * Possible values: ["SECURE_DEFAULT", "SECURE_NEVER", "SECURE_OPTIONAL", "SECURE_ALWAYS"]
     */
    readonly securityLevel?: string;
    /**
     * URL prefix.
     *
     * Uses regular expression syntax, which means regexp special characters must be escaped, but should not contain groupings.
     * All URLs that begin with this prefix are handled by this handler, using the portion of the URL after the prefix as part of the file path.
     */
    readonly urlRegex?: string;
    /**
     * script block.
     */
    readonly script?: AppEngineStandardAppVersionHandlersScript[];
    /**
     * static_files block.
     */
    readonly staticFiles?: AppEngineStandardAppVersionHandlersStaticFiles[];
}
/**
 *
 */
export interface AppEngineStandardAppVersionLibraries {
    /**
     * Name of the library.
     *
     * Example "django".
     */
    readonly name?: string;
    /**
     * Version of the library to select, or "latest".
     */
    readonly version?: string;
}
/**
 *
 */
export interface AppEngineStandardAppVersionManualScaling {
    /**
     * Number of instances to assign to the service at the start.
     *
     * *Note:** When managing the number of instances at runtime through the App Engine Admin API or the (now deprecated) Python 2
     * Modules API set_num_instances() you must use 'lifecycle.ignore_changes = ["manual_scaling"[0].instances]' to prevent drift detection.
     */
    readonly instances: number;
}
/**
 *
 */
export interface AppEngineStandardAppVersionTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export interface AppEngineStandardAppVersionVpcAccessConnector {
    /**
     * Full Serverless VPC Access Connector name e.g. /projects/my-project/locations/us-central1/connectors/c1.
     */
    readonly name: string;
}
/**
 *
 */
export declare class AppEngineStandardAppVersion extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: AppEngineStandardAppVersionConfig);
    private _deleteServiceOnDestroy?;
    /**
     *
     */
    get deleteServiceOnDestroy(): boolean;
    /**
     *
     */
    set deleteServiceOnDestroy(value: boolean);
    /**
     *
     */
    resetDeleteServiceOnDestroy(): void;
    /**
     *
     */
    get deleteServiceOnDestroyInput(): boolean | undefined;
    private _envVariables?;
    /**
     *
     */
    get envVariables(): {
        [key: string]: string;
    };
    /**
     *
     */
    set envVariables(value: {
        [key: string]: string;
    });
    /**
     *
     */
    resetEnvVariables(): void;
    /**
     *
     */
    get envVariablesInput(): {
        [key: string]: string;
    } | undefined;
    /**
     *
     */
    get id(): string;
    private _inboundServices?;
    /**
     *
     */
    get inboundServices(): string[];
    /**
     *
     */
    set inboundServices(value: string[]);
    /**
     *
     */
    resetInboundServices(): void;
    /**
     *
     */
    get inboundServicesInput(): string[] | undefined;
    private _instanceClass?;
    /**
     *
     */
    get instanceClass(): string;
    /**
     *
     */
    set instanceClass(value: string);
    /**
     *
     */
    resetInstanceClass(): void;
    /**
     *
     */
    get instanceClassInput(): string | undefined;
    /**
     *
     */
    get name(): string;
    private _noopOnDestroy?;
    /**
     *
     */
    get noopOnDestroy(): boolean;
    /**
     *
     */
    set noopOnDestroy(value: boolean);
    /**
     *
     */
    resetNoopOnDestroy(): void;
    /**
     *
     */
    get noopOnDestroyInput(): boolean | undefined;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _runtime;
    /**
     *
     */
    get runtime(): string;
    /**
     *
     */
    set runtime(value: string);
    /**
     *
     */
    get runtimeInput(): string;
    private _runtimeApiVersion?;
    /**
     *
     */
    get runtimeApiVersion(): string;
    /**
     *
     */
    set runtimeApiVersion(value: string);
    /**
     *
     */
    resetRuntimeApiVersion(): void;
    /**
     *
     */
    get runtimeApiVersionInput(): string | undefined;
    private _service;
    /**
     *
     */
    get service(): string;
    /**
     *
     */
    set service(value: string);
    /**
     *
     */
    get serviceInput(): string;
    private _threadsafe?;
    /**
     *
     */
    get threadsafe(): boolean;
    /**
     *
     */
    set threadsafe(value: boolean);
    /**
     *
     */
    resetThreadsafe(): void;
    /**
     *
     */
    get threadsafeInput(): boolean | undefined;
    private _versionId?;
    /**
     *
     */
    get versionId(): string;
    /**
     *
     */
    set versionId(value: string);
    /**
     *
     */
    resetVersionId(): void;
    /**
     *
     */
    get versionIdInput(): string | undefined;
    private _automaticScaling?;
    /**
     *
     */
    get automaticScaling(): AppEngineStandardAppVersionAutomaticScaling[];
    /**
     *
     */
    set automaticScaling(value: AppEngineStandardAppVersionAutomaticScaling[]);
    /**
     *
     */
    resetAutomaticScaling(): void;
    /**
     *
     */
    get automaticScalingInput(): AppEngineStandardAppVersionAutomaticScaling[] | undefined;
    private _basicScaling?;
    /**
     *
     */
    get basicScaling(): AppEngineStandardAppVersionBasicScaling[];
    /**
     *
     */
    set basicScaling(value: AppEngineStandardAppVersionBasicScaling[]);
    /**
     *
     */
    resetBasicScaling(): void;
    /**
     *
     */
    get basicScalingInput(): AppEngineStandardAppVersionBasicScaling[] | undefined;
    private _deployment;
    /**
     *
     */
    get deployment(): AppEngineStandardAppVersionDeployment[];
    /**
     *
     */
    set deployment(value: AppEngineStandardAppVersionDeployment[]);
    /**
     *
     */
    get deploymentInput(): AppEngineStandardAppVersionDeployment[];
    private _entrypoint?;
    /**
     *
     */
    get entrypoint(): AppEngineStandardAppVersionEntrypoint[];
    /**
     *
     */
    set entrypoint(value: AppEngineStandardAppVersionEntrypoint[]);
    /**
     *
     */
    resetEntrypoint(): void;
    /**
     *
     */
    get entrypointInput(): AppEngineStandardAppVersionEntrypoint[] | undefined;
    private _handlers?;
    /**
     *
     */
    get handlers(): AppEngineStandardAppVersionHandlers[];
    /**
     *
     */
    set handlers(value: AppEngineStandardAppVersionHandlers[]);
    /**
     *
     */
    resetHandlers(): void;
    /**
     *
     */
    get handlersInput(): AppEngineStandardAppVersionHandlers[] | undefined;
    private _libraries?;
    /**
     *
     */
    get libraries(): AppEngineStandardAppVersionLibraries[];
    /**
     *
     */
    set libraries(value: AppEngineStandardAppVersionLibraries[]);
    /**
     *
     */
    resetLibraries(): void;
    /**
     *
     */
    get librariesInput(): AppEngineStandardAppVersionLibraries[] | undefined;
    private _manualScaling?;
    /**
     *
     */
    get manualScaling(): AppEngineStandardAppVersionManualScaling[];
    /**
     *
     */
    set manualScaling(value: AppEngineStandardAppVersionManualScaling[]);
    /**
     *
     */
    resetManualScaling(): void;
    /**
     *
     */
    get manualScalingInput(): AppEngineStandardAppVersionManualScaling[] | undefined;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): AppEngineStandardAppVersionTimeouts;
    /**
     *
     */
    set timeouts(value: AppEngineStandardAppVersionTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): AppEngineStandardAppVersionTimeouts | undefined;
    private _vpcAccessConnector?;
    /**
     *
     */
    get vpcAccessConnector(): AppEngineStandardAppVersionVpcAccessConnector[];
    /**
     *
     */
    set vpcAccessConnector(value: AppEngineStandardAppVersionVpcAccessConnector[]);
    /**
     *
     */
    resetVpcAccessConnector(): void;
    /**
     *
     */
    get vpcAccessConnectorInput(): AppEngineStandardAppVersionVpcAccessConnector[] | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
