import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface BigqueryDataTransferConfigConfig extends TerraformMetaArguments {
    /**
     * The number of days to look back to automatically refresh the data.
     *
     * For example, if dataRefreshWindowDays = 10, then every day BigQuery
     * reingests data for [today-10, today-1], rather than ingesting data for
     * just [today-1]. Only valid if the data source supports the feature.
     * Set the value to 0 to use the default value.
     */
    readonly dataRefreshWindowDays?: number;
    /**
     * The data source id.
     *
     * Cannot be changed once the transfer config is created.
     */
    readonly dataSourceId: string;
    /**
     * The BigQuery target dataset id.
     */
    readonly destinationDatasetId: string;
    /**
     * When set to true, no runs are scheduled for a given transfer.
     */
    readonly disabled?: boolean;
    /**
     * The user specified display name for the transfer config.
     */
    readonly displayName: string;
    /**
     * The geographic location where the transfer config should reside.
     *
     * Examples: US, EU, asia-northeast1. The default value is US.
     */
    readonly location?: string;
    /**
     * Pub/Sub topic where notifications will be sent after transfer runs associated with this transfer config finish.
     */
    readonly notificationPubsubTopic?: string;
    /**
     * These parameters are specific to each data source.
     */
    readonly params: {
        [key: string]: string;
    };
    /**
     *
     */
    readonly project?: string;
    /**
     * Data transfer schedule.
     *
     * If the data source does not support a custom
     * schedule, this should be empty. If it is empty, the default value for
     * the data source will be used. The specified times are in UTC. Examples
     * of valid format: 1st,3rd monday of month 15:30, every wed,fri of jan,
     * jun 13:15, and first sunday of quarter 00:00. See more explanation
     * about the format here:
     * https://cloud.google.com/appengine/docs/flexible/python/scheduling-jobs-with-cron-yaml#the_schedule_format
     * NOTE: the granularity should be at least 8 hours, or less frequent.
     */
    readonly schedule?: string;
    /**
     * Optional service account name.
     *
     * If this field is set, transfer config will
     * be created with this service account credentials. It requires that
     * requesting user calling this API has permissions to act as this service account.
     */
    readonly serviceAccountName?: string;
    /**
     * email_preferences block.
     */
    readonly emailPreferences?: BigqueryDataTransferConfigEmailPreferences[];
    /**
     * schedule_options block.
     */
    readonly scheduleOptions?: BigqueryDataTransferConfigScheduleOptions[];
    /**
     * sensitive_params block.
     */
    readonly sensitiveParams?: BigqueryDataTransferConfigSensitiveParams[];
    /**
     * timeouts block.
     */
    readonly timeouts?: BigqueryDataTransferConfigTimeouts;
}
/**
 *
 */
export interface BigqueryDataTransferConfigEmailPreferences {
    /**
     * If true, email notifications will be sent on transfer run failures.
     */
    readonly enableFailureEmail: boolean;
}
/**
 *
 */
export interface BigqueryDataTransferConfigScheduleOptions {
    /**
     * If true, automatic scheduling of data transfer runs for this configuration will be disabled.
     *
     * The runs can be started on ad-hoc
     * basis using transferConfigs.startManualRuns API. When automatic
     * scheduling is disabled, the TransferConfig.schedule field will
     * be ignored.
     */
    readonly disableAutoScheduling?: boolean;
    /**
     * Defines time to stop scheduling transfer runs.
     *
     * A transfer run cannot be
     * scheduled at or after the end time. The end time can be changed at any
     * moment. The time when a data transfer can be triggered manually is not
     * limited by this option.
     */
    readonly endTime?: string;
    /**
     * Specifies time to start scheduling transfer runs.
     *
     * The first run will be
     * scheduled at or after the start time according to a recurrence pattern
     * defined in the schedule string. The start time can be changed at any
     * moment. The time when a data transfer can be triggered manually is not
     * limited by this option.
     */
    readonly startTime?: string;
}
/**
 *
 */
export interface BigqueryDataTransferConfigSensitiveParams {
    /**
     * The Secret Access Key of the AWS account transferring data from.
     */
    readonly secretAccessKey: string;
}
/**
 *
 */
export interface BigqueryDataTransferConfigTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class BigqueryDataTransferConfig extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: BigqueryDataTransferConfigConfig);
    private _dataRefreshWindowDays?;
    /**
     *
     */
    get dataRefreshWindowDays(): number;
    /**
     *
     */
    set dataRefreshWindowDays(value: number);
    /**
     *
     */
    resetDataRefreshWindowDays(): void;
    /**
     *
     */
    get dataRefreshWindowDaysInput(): number | undefined;
    private _dataSourceId;
    /**
     *
     */
    get dataSourceId(): string;
    /**
     *
     */
    set dataSourceId(value: string);
    /**
     *
     */
    get dataSourceIdInput(): string;
    private _destinationDatasetId;
    /**
     *
     */
    get destinationDatasetId(): string;
    /**
     *
     */
    set destinationDatasetId(value: string);
    /**
     *
     */
    get destinationDatasetIdInput(): string;
    private _disabled?;
    /**
     *
     */
    get disabled(): boolean;
    /**
     *
     */
    set disabled(value: boolean);
    /**
     *
     */
    resetDisabled(): void;
    /**
     *
     */
    get disabledInput(): boolean | undefined;
    private _displayName;
    /**
     *
     */
    get displayName(): string;
    /**
     *
     */
    set displayName(value: string);
    /**
     *
     */
    get displayNameInput(): string;
    /**
     *
     */
    get id(): string;
    private _location?;
    /**
     *
     */
    get location(): string;
    /**
     *
     */
    set location(value: string);
    /**
     *
     */
    resetLocation(): void;
    /**
     *
     */
    get locationInput(): string | undefined;
    /**
     *
     */
    get name(): string;
    private _notificationPubsubTopic?;
    /**
     *
     */
    get notificationPubsubTopic(): string;
    /**
     *
     */
    set notificationPubsubTopic(value: string);
    /**
     *
     */
    resetNotificationPubsubTopic(): void;
    /**
     *
     */
    get notificationPubsubTopicInput(): string | undefined;
    private _params;
    /**
     *
     */
    get params(): {
        [key: string]: string;
    };
    /**
     *
     */
    set params(value: {
        [key: string]: string;
    });
    /**
     *
     */
    get paramsInput(): {
        [key: string]: string;
    };
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _schedule?;
    /**
     *
     */
    get schedule(): string;
    /**
     *
     */
    set schedule(value: string);
    /**
     *
     */
    resetSchedule(): void;
    /**
     *
     */
    get scheduleInput(): string | undefined;
    private _serviceAccountName?;
    /**
     *
     */
    get serviceAccountName(): string;
    /**
     *
     */
    set serviceAccountName(value: string);
    /**
     *
     */
    resetServiceAccountName(): void;
    /**
     *
     */
    get serviceAccountNameInput(): string | undefined;
    private _emailPreferences?;
    /**
     *
     */
    get emailPreferences(): BigqueryDataTransferConfigEmailPreferences[];
    /**
     *
     */
    set emailPreferences(value: BigqueryDataTransferConfigEmailPreferences[]);
    /**
     *
     */
    resetEmailPreferences(): void;
    /**
     *
     */
    get emailPreferencesInput(): BigqueryDataTransferConfigEmailPreferences[] | undefined;
    private _scheduleOptions?;
    /**
     *
     */
    get scheduleOptions(): BigqueryDataTransferConfigScheduleOptions[];
    /**
     *
     */
    set scheduleOptions(value: BigqueryDataTransferConfigScheduleOptions[]);
    /**
     *
     */
    resetScheduleOptions(): void;
    /**
     *
     */
    get scheduleOptionsInput(): BigqueryDataTransferConfigScheduleOptions[] | undefined;
    private _sensitiveParams?;
    /**
     *
     */
    get sensitiveParams(): BigqueryDataTransferConfigSensitiveParams[];
    /**
     *
     */
    set sensitiveParams(value: BigqueryDataTransferConfigSensitiveParams[]);
    /**
     *
     */
    resetSensitiveParams(): void;
    /**
     *
     */
    get sensitiveParamsInput(): BigqueryDataTransferConfigSensitiveParams[] | undefined;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): BigqueryDataTransferConfigTimeouts;
    /**
     *
     */
    set timeouts(value: BigqueryDataTransferConfigTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): BigqueryDataTransferConfigTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
