import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface BigqueryRoutineConfig extends TerraformMetaArguments {
    /**
     * The ID of the dataset containing this routine.
     */
    readonly datasetId: string;
    /**
     * The body of the routine.
     *
     * For functions, this is the expression in the AS clause.
     * If language=SQL, it is the substring inside (but excluding) the parentheses.
     */
    readonly definitionBody: string;
    /**
     * The description of the routine if defined.
     */
    readonly description?: string;
    /**
     * The determinism level of the JavaScript UDF if defined.
     *
     * Possible values: ["DETERMINISM_LEVEL_UNSPECIFIED", "DETERMINISTIC", "NOT_DETERMINISTIC"]
     */
    readonly determinismLevel?: string;
    /**
     * Optional.
     *
     * If language = "JAVASCRIPT", this field stores the path of the
     * imported JAVASCRIPT libraries.
     */
    readonly importedLibraries?: string[];
    /**
     * The language of the routine.
     *
     * Possible values: ["SQL", "JAVASCRIPT"]
     */
    readonly language?: string;
    /**
     *
     */
    readonly project?: string;
    /**
     * A JSON schema for the return type.
     *
     * Optional if language = "SQL"; required otherwise.
     * If absent, the return type is inferred from definitionBody at query time in each query
     * that references this routine. If present, then the evaluated result will be cast to
     * the specified returned type at query time. ~>**NOTE**: Because this field expects a JSON
     * string, any changes to the string will create a diff, even if the JSON itself hasn't
     * changed. If the API returns a different value for the same schema, e.g. it switche
     * d the order of values or replaced STRUCT field type with RECORD field type, we currently
     * cannot suppress the recurring diff this causes. As a workaround, we recommend using
     * the schema as returned by the API.
     */
    readonly returnType?: string;
    /**
     * The ID of the the routine.
     *
     * The ID must contain only letters (a-z, A-Z), numbers (0-9), or underscores (_). The maximum length is 256 characters.
     */
    readonly routineId: string;
    /**
     * The type of routine.
     *
     * Possible values: ["SCALAR_FUNCTION", "PROCEDURE"]
     */
    readonly routineType?: string;
    /**
     * arguments block.
     */
    readonly arguments?: BigqueryRoutineArguments[];
    /**
     * timeouts block.
     */
    readonly timeouts?: BigqueryRoutineTimeouts;
}
/**
 *
 */
export interface BigqueryRoutineArguments {
    /**
     * Defaults to FIXED_TYPE.
     *
     * Default value: "FIXED_TYPE" Possible values: ["FIXED_TYPE", "ANY_TYPE"]
     */
    readonly argumentKind?: string;
    /**
     * A JSON schema for the data type.
     *
     * Required unless argumentKind = ANY_TYPE.
     * ~>**NOTE**: Because this field expects a JSON string, any changes to the string
     * will create a diff, even if the JSON itself hasn't changed. If the API returns
     * a different value for the same schema, e.g. it switched the order of values
     * or replaced STRUCT field type with RECORD field type, we currently cannot
     * suppress the recurring diff this causes. As a workaround, we recommend using
     * the schema as returned by the API.
     */
    readonly dataType?: string;
    /**
     * Specifies whether the argument is input or output.
     *
     * Can be set for procedures only. Possible values: ["IN", "OUT", "INOUT"]
     */
    readonly mode?: string;
    /**
     * The name of this argument.
     *
     * Can be absent for function return argument.
     */
    readonly name?: string;
}
/**
 *
 */
export interface BigqueryRoutineTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class BigqueryRoutine extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: BigqueryRoutineConfig);
    /**
     *
     */
    get creationTime(): number;
    private _datasetId;
    /**
     *
     */
    get datasetId(): string;
    /**
     *
     */
    set datasetId(value: string);
    /**
     *
     */
    get datasetIdInput(): string;
    private _definitionBody;
    /**
     *
     */
    get definitionBody(): string;
    /**
     *
     */
    set definitionBody(value: string);
    /**
     *
     */
    get definitionBodyInput(): string;
    private _description?;
    /**
     *
     */
    get description(): string;
    /**
     *
     */
    set description(value: string);
    /**
     *
     */
    resetDescription(): void;
    /**
     *
     */
    get descriptionInput(): string | undefined;
    private _determinismLevel?;
    /**
     *
     */
    get determinismLevel(): string;
    /**
     *
     */
    set determinismLevel(value: string);
    /**
     *
     */
    resetDeterminismLevel(): void;
    /**
     *
     */
    get determinismLevelInput(): string | undefined;
    /**
     *
     */
    get id(): string;
    private _importedLibraries?;
    /**
     *
     */
    get importedLibraries(): string[];
    /**
     *
     */
    set importedLibraries(value: string[]);
    /**
     *
     */
    resetImportedLibraries(): void;
    /**
     *
     */
    get importedLibrariesInput(): string[] | undefined;
    private _language?;
    /**
     *
     */
    get language(): string;
    /**
     *
     */
    set language(value: string);
    /**
     *
     */
    resetLanguage(): void;
    /**
     *
     */
    get languageInput(): string | undefined;
    /**
     *
     */
    get lastModifiedTime(): number;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _returnType?;
    /**
     *
     */
    get returnType(): string;
    /**
     *
     */
    set returnType(value: string);
    /**
     *
     */
    resetReturnType(): void;
    /**
     *
     */
    get returnTypeInput(): string | undefined;
    private _routineId;
    /**
     *
     */
    get routineId(): string;
    /**
     *
     */
    set routineId(value: string);
    /**
     *
     */
    get routineIdInput(): string;
    private _routineType?;
    /**
     *
     */
    get routineType(): string;
    /**
     *
     */
    set routineType(value: string);
    /**
     *
     */
    resetRoutineType(): void;
    /**
     *
     */
    get routineTypeInput(): string | undefined;
    private _arguments?;
    /**
     *
     */
    get arguments(): BigqueryRoutineArguments[];
    /**
     *
     */
    set arguments(value: BigqueryRoutineArguments[]);
    /**
     *
     */
    resetArguments(): void;
    /**
     *
     */
    get argumentsInput(): BigqueryRoutineArguments[] | undefined;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): BigqueryRoutineTimeouts;
    /**
     *
     */
    set timeouts(value: BigqueryRoutineTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): BigqueryRoutineTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
