import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface BigqueryTableConfig extends TerraformMetaArguments {
    /**
     * Specifies column names to use for data clustering.
     *
     * Up to four top-level columns are allowed, and should be specified in descending priority order.
     */
    readonly clustering?: string[];
    /**
     * The dataset ID to create the table in.
     *
     * Changing this forces a new resource to be created.
     */
    readonly datasetId: string;
    /**
     * The field description.
     */
    readonly description?: string;
    /**
     * The time when this table expires, in milliseconds since the epoch.
     *
     * If not present, the table will persist indefinitely. Expired tables will be deleted and their storage reclaimed.
     */
    readonly expirationTime?: number;
    /**
     * A descriptive name for the table.
     */
    readonly friendlyName?: string;
    /**
     * A mapping of labels to assign to the resource.
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * The ID of the project in which the resource belongs.
     */
    readonly project?: string;
    /**
     * A JSON schema for the table.
     */
    readonly schema?: string;
    /**
     * A unique ID for the resource.
     *
     * Changing this forces a new resource to be created.
     */
    readonly tableId: string;
    /**
     * encryption_configuration block.
     */
    readonly encryptionConfiguration?: BigqueryTableEncryptionConfiguration[];
    /**
     * external_data_configuration block.
     */
    readonly externalDataConfiguration?: BigqueryTableExternalDataConfiguration[];
    /**
     * materialized_view block.
     */
    readonly materializedView?: BigqueryTableMaterializedView[];
    /**
     * range_partitioning block.
     */
    readonly rangePartitioning?: BigqueryTableRangePartitioning[];
    /**
     * time_partitioning block.
     */
    readonly timePartitioning?: BigqueryTableTimePartitioning[];
    /**
     * view block.
     */
    readonly view?: BigqueryTableView[];
}
/**
 *
 */
export interface BigqueryTableEncryptionConfiguration {
    /**
     * The self link or full name of a key which should be used to encrypt this table.
     *
     * Note that the default bigquery service account will need to have encrypt/decrypt permissions on this key - you may want to see the google_bigquery_default_service_account datasource and the google_kms_crypto_key_iam_binding resource.
     */
    readonly kmsKeyName: string;
}
/**
 *
 */
export interface BigqueryTableExternalDataConfigurationCsvOptions {
    /**
     * Indicates if BigQuery should accept rows that are missing trailing optional columns.
     */
    readonly allowJaggedRows?: boolean;
    /**
     * Indicates if BigQuery should allow quoted data sections that contain newline characters in a CSV file.
     *
     * The default value is false.
     */
    readonly allowQuotedNewlines?: boolean;
    /**
     * The character encoding of the data.
     *
     * The supported values are UTF-8 or ISO-8859-1.
     */
    readonly encoding?: string;
    /**
     * The separator for fields in a CSV file.
     */
    readonly fieldDelimiter?: string;
    /**
     * The value that is used to quote data sections in a CSV file.
     *
     * If your data does not contain quoted sections, set the property value to an empty string. If your data contains quoted newline characters, you must also set the allow_quoted_newlines property to true. The API-side default is ", specified in Terraform escaped as \". Due to limitations with Terraform default values, this value is required to be explicitly set.
     */
    readonly quote: string;
    /**
     * The number of rows at the top of a CSV file that BigQuery will skip when reading the data.
     */
    readonly skipLeadingRows?: number;
}
/**
 *
 */
export interface BigqueryTableExternalDataConfigurationGoogleSheetsOptions {
    /**
     * Range of a sheet to query from.
     *
     * Only used when non-empty. At least one of range or skip_leading_rows must be set. Typical format: "sheet_name!top_left_cell_id:bottom_right_cell_id" For example: "sheet1!A1:B20"
     */
    readonly range?: string;
    /**
     * The number of rows at the top of the sheet that BigQuery will skip when reading the data.
     *
     * At least one of range or skip_leading_rows must be set.
     */
    readonly skipLeadingRows?: number;
}
/**
 *
 */
export interface BigqueryTableExternalDataConfigurationHivePartitioningOptions {
    /**
     * When set, what mode of hive partitioning to use when reading data.
     */
    readonly mode?: string;
    /**
     * When hive partition detection is requested, a common for all source uris must be required.
     *
     * The prefix must end immediately before the partition key encoding begins.
     */
    readonly sourceUriPrefix?: string;
}
/**
 *
 */
export interface BigqueryTableExternalDataConfiguration {
    /**
     * Let BigQuery try to autodetect the schema and format of the table.
     */
    readonly autodetect: boolean;
    /**
     * The compression type of the data source.
     *
     * Valid values are "NONE" or "GZIP".
     */
    readonly compression?: string;
    /**
     * Indicates if BigQuery should allow extra values that are not represented in the table schema.
     *
     * If true, the extra values are ignored. If false, records with extra columns are treated as bad records, and if there are too many bad records, an invalid error is returned in the job result. The default value is false.
     */
    readonly ignoreUnknownValues?: boolean;
    /**
     * The maximum number of bad records that BigQuery can ignore when reading data.
     */
    readonly maxBadRecords?: number;
    /**
     * A JSON schema for the external table.
     *
     * Schema is required for CSV and JSON formats and is disallowed for Google Cloud Bigtable, Cloud Datastore backups, and Avro formats when using external tables.
     */
    readonly schema?: string;
    /**
     * The data format.
     *
     * Supported values are: "CSV", "GOOGLE_SHEETS", "NEWLINE_DELIMITED_JSON", "AVRO", "PARQUET", and "DATASTORE_BACKUP". To use "GOOGLE_SHEETS" the scopes must include "googleapis.com/auth/drive.readonly".
     */
    readonly sourceFormat: string;
    /**
     * A list of the fully-qualified URIs that point to your data in Google Cloud.
     */
    readonly sourceUris: string[];
    /**
     * csv_options block.
     */
    readonly csvOptions?: BigqueryTableExternalDataConfigurationCsvOptions[];
    /**
     * google_sheets_options block.
     */
    readonly googleSheetsOptions?: BigqueryTableExternalDataConfigurationGoogleSheetsOptions[];
    /**
     * hive_partitioning_options block.
     */
    readonly hivePartitioningOptions?: BigqueryTableExternalDataConfigurationHivePartitioningOptions[];
}
/**
 *
 */
export interface BigqueryTableMaterializedView {
    /**
     * Specifies if BigQuery should automatically refresh materialized view when the base table is updated.
     *
     * The default is true.
     */
    readonly enableRefresh?: boolean;
    /**
     * A query whose result is persisted.
     */
    readonly query: string;
    /**
     * Specifies maximum frequency at which this materialized view will be refreshed.
     *
     * The default is 1800000
     */
    readonly refreshIntervalMs?: number;
}
/**
 *
 */
export interface BigqueryTableRangePartitioningRange {
    /**
     * End of the range partitioning, exclusive.
     */
    readonly end: number;
    /**
     * The width of each range within the partition.
     */
    readonly interval: number;
    /**
     * Start of the range partitioning, inclusive.
     */
    readonly start: number;
}
/**
 *
 */
export interface BigqueryTableRangePartitioning {
    /**
     * The field used to determine how to create a range-based partition.
     */
    readonly field: string;
    /**
     * range block.
     */
    readonly range: BigqueryTableRangePartitioningRange[];
}
/**
 *
 */
export interface BigqueryTableTimePartitioning {
    /**
     * Number of milliseconds for which to keep the storage for a partition.
     */
    readonly expirationMs?: number;
    /**
     * The field used to determine how to create a time-based partition.
     *
     * If time-based partitioning is enabled without this value, the table is partitioned based on the load time.
     */
    readonly field?: string;
    /**
     * If set to true, queries over this table require a partition filter that can be used for partition elimination to be specified.
     */
    readonly requirePartitionFilter?: boolean;
    /**
     * The supported types are DAY, HOUR, MONTH, and YEAR, which will generate one partition per day, hour, month, and year, respectively.
     */
    readonly type: string;
}
/**
 *
 */
export interface BigqueryTableView {
    /**
     * A query that BigQuery executes when the view is referenced.
     */
    readonly query: string;
    /**
     * Specifies whether to use BigQuery's legacy SQL for this view.
     *
     * The default value is true. If set to false, the view will use BigQuery's standard SQL
     */
    readonly useLegacySql?: boolean;
}
/**
 *
 */
export declare class BigqueryTable extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: BigqueryTableConfig);
    private _clustering?;
    /**
     *
     */
    get clustering(): string[];
    /**
     *
     */
    set clustering(value: string[]);
    /**
     *
     */
    resetClustering(): void;
    /**
     *
     */
    get clusteringInput(): string[] | undefined;
    /**
     *
     */
    get creationTime(): number;
    private _datasetId;
    /**
     *
     */
    get datasetId(): string;
    /**
     *
     */
    set datasetId(value: string);
    /**
     *
     */
    get datasetIdInput(): string;
    private _description?;
    /**
     *
     */
    get description(): string;
    /**
     *
     */
    set description(value: string);
    /**
     *
     */
    resetDescription(): void;
    /**
     *
     */
    get descriptionInput(): string | undefined;
    /**
     *
     */
    get etag(): string;
    private _expirationTime?;
    /**
     *
     */
    get expirationTime(): number;
    /**
     *
     */
    set expirationTime(value: number);
    /**
     *
     */
    resetExpirationTime(): void;
    /**
     *
     */
    get expirationTimeInput(): number | undefined;
    private _friendlyName?;
    /**
     *
     */
    get friendlyName(): string;
    /**
     *
     */
    set friendlyName(value: string);
    /**
     *
     */
    resetFriendlyName(): void;
    /**
     *
     */
    get friendlyNameInput(): string | undefined;
    /**
     *
     */
    get id(): string;
    private _labels?;
    /**
     *
     */
    get labels(): {
        [key: string]: string;
    };
    /**
     *
     */
    set labels(value: {
        [key: string]: string;
    });
    /**
     *
     */
    resetLabels(): void;
    /**
     *
     */
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    /**
     *
     */
    get lastModifiedTime(): number;
    /**
     *
     */
    get location(): string;
    /**
     *
     */
    get numBytes(): number;
    /**
     *
     */
    get numLongTermBytes(): number;
    /**
     *
     */
    get numRows(): number;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _schema?;
    /**
     *
     */
    get schema(): string;
    /**
     *
     */
    set schema(value: string);
    /**
     *
     */
    resetSchema(): void;
    /**
     *
     */
    get schemaInput(): string | undefined;
    /**
     *
     */
    get selfLink(): string;
    private _tableId;
    /**
     *
     */
    get tableId(): string;
    /**
     *
     */
    set tableId(value: string);
    /**
     *
     */
    get tableIdInput(): string;
    /**
     *
     */
    get type(): string;
    private _encryptionConfiguration?;
    /**
     *
     */
    get encryptionConfiguration(): BigqueryTableEncryptionConfiguration[];
    /**
     *
     */
    set encryptionConfiguration(value: BigqueryTableEncryptionConfiguration[]);
    /**
     *
     */
    resetEncryptionConfiguration(): void;
    /**
     *
     */
    get encryptionConfigurationInput(): BigqueryTableEncryptionConfiguration[] | undefined;
    private _externalDataConfiguration?;
    /**
     *
     */
    get externalDataConfiguration(): BigqueryTableExternalDataConfiguration[];
    /**
     *
     */
    set externalDataConfiguration(value: BigqueryTableExternalDataConfiguration[]);
    /**
     *
     */
    resetExternalDataConfiguration(): void;
    /**
     *
     */
    get externalDataConfigurationInput(): BigqueryTableExternalDataConfiguration[] | undefined;
    private _materializedView?;
    /**
     *
     */
    get materializedView(): BigqueryTableMaterializedView[];
    /**
     *
     */
    set materializedView(value: BigqueryTableMaterializedView[]);
    /**
     *
     */
    resetMaterializedView(): void;
    /**
     *
     */
    get materializedViewInput(): BigqueryTableMaterializedView[] | undefined;
    private _rangePartitioning?;
    /**
     *
     */
    get rangePartitioning(): BigqueryTableRangePartitioning[];
    /**
     *
     */
    set rangePartitioning(value: BigqueryTableRangePartitioning[]);
    /**
     *
     */
    resetRangePartitioning(): void;
    /**
     *
     */
    get rangePartitioningInput(): BigqueryTableRangePartitioning[] | undefined;
    private _timePartitioning?;
    /**
     *
     */
    get timePartitioning(): BigqueryTableTimePartitioning[];
    /**
     *
     */
    set timePartitioning(value: BigqueryTableTimePartitioning[]);
    /**
     *
     */
    resetTimePartitioning(): void;
    /**
     *
     */
    get timePartitioningInput(): BigqueryTableTimePartitioning[] | undefined;
    private _view?;
    /**
     *
     */
    get view(): BigqueryTableView[];
    /**
     *
     */
    set view(value: BigqueryTableView[]);
    /**
     *
     */
    resetView(): void;
    /**
     *
     */
    get viewInput(): BigqueryTableView[] | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
