import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface BigtableGcPolicyConfig extends TerraformMetaArguments {
    /**
     * The name of the column family.
     */
    readonly columnFamily: string;
    /**
     * The name of the Bigtable instance.
     */
    readonly instanceName: string;
    /**
     * If multiple policies are set, you should choose between UNION OR INTERSECTION.
     */
    readonly mode?: string;
    /**
     * The ID of the project in which the resource belongs.
     *
     * If it is not provided, the provider project is used.
     */
    readonly project?: string;
    /**
     * The name of the table.
     */
    readonly table: string;
    /**
     * max_age block.
     */
    readonly maxAge?: BigtableGcPolicyMaxAge[];
    /**
     * max_version block.
     */
    readonly maxVersion?: BigtableGcPolicyMaxVersion[];
}
/**
 *
 */
export interface BigtableGcPolicyMaxAge {
    /**
     * Number of days before applying GC policy.
     */
    readonly days: number;
}
/**
 *
 */
export interface BigtableGcPolicyMaxVersion {
    /**
     * Number of version before applying the GC policy.
     */
    readonly number: number;
}
/**
 *
 */
export declare class BigtableGcPolicy extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: BigtableGcPolicyConfig);
    private _columnFamily;
    /**
     *
     */
    get columnFamily(): string;
    /**
     *
     */
    set columnFamily(value: string);
    /**
     *
     */
    get columnFamilyInput(): string;
    /**
     *
     */
    get id(): string;
    private _instanceName;
    /**
     *
     */
    get instanceName(): string;
    /**
     *
     */
    set instanceName(value: string);
    /**
     *
     */
    get instanceNameInput(): string;
    private _mode?;
    /**
     *
     */
    get mode(): string;
    /**
     *
     */
    set mode(value: string);
    /**
     *
     */
    resetMode(): void;
    /**
     *
     */
    get modeInput(): string | undefined;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _table;
    /**
     *
     */
    get table(): string;
    /**
     *
     */
    set table(value: string);
    /**
     *
     */
    get tableInput(): string;
    private _maxAge?;
    /**
     *
     */
    get maxAge(): BigtableGcPolicyMaxAge[];
    /**
     *
     */
    set maxAge(value: BigtableGcPolicyMaxAge[]);
    /**
     *
     */
    resetMaxAge(): void;
    /**
     *
     */
    get maxAgeInput(): BigtableGcPolicyMaxAge[] | undefined;
    private _maxVersion?;
    /**
     *
     */
    get maxVersion(): BigtableGcPolicyMaxVersion[];
    /**
     *
     */
    set maxVersion(value: BigtableGcPolicyMaxVersion[]);
    /**
     *
     */
    resetMaxVersion(): void;
    /**
     *
     */
    get maxVersionInput(): BigtableGcPolicyMaxVersion[] | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
