import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface BinaryAuthorizationPolicyConfig extends TerraformMetaArguments {
    /**
     * A descriptive comment.
     */
    readonly description?: string;
    /**
     * Controls the evaluation of a Google-maintained global admission policy for common system-level images.
     *
     * Images not covered by the global
     * policy will be subject to the project admission policy. Possible values: ["ENABLE", "DISABLE"]
     */
    readonly globalPolicyEvaluationMode?: string;
    /**
     *
     */
    readonly project?: string;
    /**
     * admission_whitelist_patterns block.
     */
    readonly admissionWhitelistPatterns?: BinaryAuthorizationPolicyAdmissionWhitelistPatterns[];
    /**
     * cluster_admission_rules block.
     */
    readonly clusterAdmissionRules?: BinaryAuthorizationPolicyClusterAdmissionRules[];
    /**
     * default_admission_rule block.
     */
    readonly defaultAdmissionRule: BinaryAuthorizationPolicyDefaultAdmissionRule[];
    /**
     * timeouts block.
     */
    readonly timeouts?: BinaryAuthorizationPolicyTimeouts;
}
/**
 *
 */
export interface BinaryAuthorizationPolicyAdmissionWhitelistPatterns {
    /**
     * An image name pattern to whitelist, in the form 'registry/path/to/image'.
     *
     * This supports a trailing * as a
     * wildcard, but this is allowed only in text after the registry/
     * part.
     */
    readonly namePattern: string;
}
/**
 *
 */
export interface BinaryAuthorizationPolicyClusterAdmissionRules {
    /**
     *
     */
    readonly cluster: string;
    /**
     * The action when a pod creation is denied by the admission rule.
     *
     * Possible values: ["ENFORCED_BLOCK_AND_AUDIT_LOG", "DRYRUN_AUDIT_LOG_ONLY"]
     */
    readonly enforcementMode: string;
    /**
     * How this admission rule will be evaluated.
     *
     * Possible values: ["ALWAYS_ALLOW", "REQUIRE_ATTESTATION", "ALWAYS_DENY"]
     */
    readonly evaluationMode: string;
    /**
     * The resource names of the attestors that must attest to a container image.
     *
     * If the attestor is in a different project from the
     * policy, it should be specified in the format 'projects/*\/attestors/*'.
     * Each attestor must exist before a policy can reference it. To add an
     * attestor to a policy the principal issuing the policy change
     * request must be able to read the attestor resource.
     *
     * Note: this field must be non-empty when the evaluation_mode field
     * specifies REQUIRE_ATTESTATION, otherwise it must be empty.
     */
    readonly requireAttestationsBy?: string[];
}
/**
 *
 */
export interface BinaryAuthorizationPolicyDefaultAdmissionRule {
    /**
     * The action when a pod creation is denied by the admission rule.
     *
     * Possible values: ["ENFORCED_BLOCK_AND_AUDIT_LOG", "DRYRUN_AUDIT_LOG_ONLY"]
     */
    readonly enforcementMode: string;
    /**
     * How this admission rule will be evaluated.
     *
     * Possible values: ["ALWAYS_ALLOW", "REQUIRE_ATTESTATION", "ALWAYS_DENY"]
     */
    readonly evaluationMode: string;
    /**
     * The resource names of the attestors that must attest to a container image.
     *
     * If the attestor is in a different project from the
     * policy, it should be specified in the format 'projects/*\/attestors/*'.
     * Each attestor must exist before a policy can reference it. To add an
     * attestor to a policy the principal issuing the policy change
     * request must be able to read the attestor resource.
     *
     * Note: this field must be non-empty when the evaluation_mode field
     * specifies REQUIRE_ATTESTATION, otherwise it must be empty.
     */
    readonly requireAttestationsBy?: string[];
}
/**
 *
 */
export interface BinaryAuthorizationPolicyTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class BinaryAuthorizationPolicy extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: BinaryAuthorizationPolicyConfig);
    private _description?;
    /**
     *
     */
    get description(): string;
    /**
     *
     */
    set description(value: string);
    /**
     *
     */
    resetDescription(): void;
    /**
     *
     */
    get descriptionInput(): string | undefined;
    private _globalPolicyEvaluationMode?;
    /**
     *
     */
    get globalPolicyEvaluationMode(): string;
    /**
     *
     */
    set globalPolicyEvaluationMode(value: string);
    /**
     *
     */
    resetGlobalPolicyEvaluationMode(): void;
    /**
     *
     */
    get globalPolicyEvaluationModeInput(): string | undefined;
    /**
     *
     */
    get id(): string;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _admissionWhitelistPatterns?;
    /**
     *
     */
    get admissionWhitelistPatterns(): BinaryAuthorizationPolicyAdmissionWhitelistPatterns[];
    /**
     *
     */
    set admissionWhitelistPatterns(value: BinaryAuthorizationPolicyAdmissionWhitelistPatterns[]);
    /**
     *
     */
    resetAdmissionWhitelistPatterns(): void;
    /**
     *
     */
    get admissionWhitelistPatternsInput(): BinaryAuthorizationPolicyAdmissionWhitelistPatterns[] | undefined;
    private _clusterAdmissionRules?;
    /**
     *
     */
    get clusterAdmissionRules(): BinaryAuthorizationPolicyClusterAdmissionRules[];
    /**
     *
     */
    set clusterAdmissionRules(value: BinaryAuthorizationPolicyClusterAdmissionRules[]);
    /**
     *
     */
    resetClusterAdmissionRules(): void;
    /**
     *
     */
    get clusterAdmissionRulesInput(): BinaryAuthorizationPolicyClusterAdmissionRules[] | undefined;
    private _defaultAdmissionRule;
    /**
     *
     */
    get defaultAdmissionRule(): BinaryAuthorizationPolicyDefaultAdmissionRule[];
    /**
     *
     */
    set defaultAdmissionRule(value: BinaryAuthorizationPolicyDefaultAdmissionRule[]);
    /**
     *
     */
    get defaultAdmissionRuleInput(): BinaryAuthorizationPolicyDefaultAdmissionRule[];
    private _timeouts?;
    /**
     *
     */
    get timeouts(): BinaryAuthorizationPolicyTimeouts;
    /**
     *
     */
    set timeouts(value: BinaryAuthorizationPolicyTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): BinaryAuthorizationPolicyTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
