import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface CloudfunctionsFunctionConfig extends TerraformMetaArguments {
    /**
     * Memory (in MB), available to the function.
     *
     * Default value is 256MB. Allowed values are: 128MB, 256MB, 512MB, 1024MB, and 2048MB.
     */
    readonly availableMemoryMb?: number;
    /**
     * A set of key/value environment variable pairs available during build time.
     */
    readonly buildEnvironmentVariables?: {
        [key: string]: string;
    };
    /**
     * Description of the function.
     */
    readonly description?: string;
    /**
     * Name of the function that will be executed when the Google Cloud Function is triggered.
     */
    readonly entryPoint?: string;
    /**
     * A set of key/value environment variable pairs to assign to the function.
     */
    readonly environmentVariables?: {
        [key: string]: string;
    };
    /**
     * URL which triggers function execution.
     *
     * Returned only if trigger_http is used.
     */
    readonly httpsTriggerUrl?: string;
    /**
     * String value that controls what traffic can reach the function.
     *
     * Allowed values are ALLOW_ALL and ALLOW_INTERNAL_ONLY. Changes to this field will recreate the cloud function.
     */
    readonly ingressSettings?: string;
    /**
     * A set of key/value label pairs to assign to the function.
     *
     * Label keys must follow the requirements at https://cloud.google.com/resource-manager/docs/creating-managing-labels#requirements.
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * The limit on the maximum number of function instances that may coexist at a given time.
     */
    readonly maxInstances?: number;
    /**
     * A user-defined name of the function.
     *
     * Function names must be unique globally.
     */
    readonly name: string;
    /**
     * Project of the function.
     *
     * If it is not provided, the provider project is used.
     */
    readonly project?: string;
    /**
     * Region of function.
     *
     * Currently can be only "us-central1". If it is not provided, the provider region is used.
     */
    readonly region?: string;
    /**
     * The runtime in which the function is going to run.
     *
     * Eg. "nodejs8", "nodejs10", "python37", "go111".
     */
    readonly runtime: string;
    /**
     * If provided, the self-provided service account to run the function with.
     */
    readonly serviceAccountEmail?: string;
    /**
     * The GCS bucket containing the zip archive which contains the function.
     */
    readonly sourceArchiveBucket?: string;
    /**
     * The source archive object (file) in archive bucket.
     */
    readonly sourceArchiveObject?: string;
    /**
     * Timeout (in seconds) for the function.
     *
     * Default value is 60 seconds. Cannot be more than 540 seconds.
     */
    readonly timeout?: number;
    /**
     * Boolean variable.
     *
     * Any HTTP request (of a supported type) to the endpoint will trigger function execution. Supported HTTP request types are: POST, PUT, GET, DELETE, and OPTIONS. Endpoint is returned as https_trigger_url. Cannot be used with trigger_bucket and trigger_topic.
     */
    readonly triggerHttp?: boolean;
    /**
     * The VPC Network Connector that this cloud function can connect to.
     *
     * It can be either the fully-qualified URI, or the short name of the network connector resource. The format of this field is projects/*\/locations/*\/connectors/*.
     */
    readonly vpcConnector?: string;
    /**
     * The egress settings for the connector, controlling what traffic is diverted through it.
     *
     * Allowed values are ALL_TRAFFIC and PRIVATE_RANGES_ONLY. Defaults to PRIVATE_RANGES_ONLY. If unset, this field preserves the previously set value.
     */
    readonly vpcConnectorEgressSettings?: string;
    /**
     * event_trigger block.
     */
    readonly eventTrigger?: CloudfunctionsFunctionEventTrigger[];
    /**
     * source_repository block.
     */
    readonly sourceRepository?: CloudfunctionsFunctionSourceRepository[];
    /**
     * timeouts block.
     */
    readonly timeouts?: CloudfunctionsFunctionTimeouts;
}
/**
 *
 */
export interface CloudfunctionsFunctionEventTriggerFailurePolicy {
    /**
     * Whether the function should be retried on failure.
     *
     * Defaults to false.
     */
    readonly retry: boolean;
}
/**
 *
 */
export interface CloudfunctionsFunctionEventTrigger {
    /**
     * The type of event to observe.
     *
     * For example: "google.storage.object.finalize". See the documentation on calling Cloud Functions for a full reference of accepted triggers.
     */
    readonly eventType: string;
    /**
     * The name or partial URI of the resource from which to observe events.
     *
     * For example, "myBucket" or "projects/my-project/topics/my-topic"
     */
    readonly resource: string;
    /**
     * failure_policy block.
     */
    readonly failurePolicy?: CloudfunctionsFunctionEventTriggerFailurePolicy[];
}
/**
 *
 */
export interface CloudfunctionsFunctionSourceRepository {
    /**
     * The URL pointing to the hosted repository where the function is defined.
     */
    readonly url: string;
}
/**
 *
 */
export interface CloudfunctionsFunctionTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly read?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class CloudfunctionsFunction extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: CloudfunctionsFunctionConfig);
    private _availableMemoryMb?;
    /**
     *
     */
    get availableMemoryMb(): number;
    /**
     *
     */
    set availableMemoryMb(value: number);
    /**
     *
     */
    resetAvailableMemoryMb(): void;
    /**
     *
     */
    get availableMemoryMbInput(): number | undefined;
    private _buildEnvironmentVariables?;
    /**
     *
     */
    get buildEnvironmentVariables(): {
        [key: string]: string;
    };
    /**
     *
     */
    set buildEnvironmentVariables(value: {
        [key: string]: string;
    });
    /**
     *
     */
    resetBuildEnvironmentVariables(): void;
    /**
     *
     */
    get buildEnvironmentVariablesInput(): {
        [key: string]: string;
    } | undefined;
    private _description?;
    /**
     *
     */
    get description(): string;
    /**
     *
     */
    set description(value: string);
    /**
     *
     */
    resetDescription(): void;
    /**
     *
     */
    get descriptionInput(): string | undefined;
    private _entryPoint?;
    /**
     *
     */
    get entryPoint(): string;
    /**
     *
     */
    set entryPoint(value: string);
    /**
     *
     */
    resetEntryPoint(): void;
    /**
     *
     */
    get entryPointInput(): string | undefined;
    private _environmentVariables?;
    /**
     *
     */
    get environmentVariables(): {
        [key: string]: string;
    };
    /**
     *
     */
    set environmentVariables(value: {
        [key: string]: string;
    });
    /**
     *
     */
    resetEnvironmentVariables(): void;
    /**
     *
     */
    get environmentVariablesInput(): {
        [key: string]: string;
    } | undefined;
    private _httpsTriggerUrl?;
    /**
     *
     */
    get httpsTriggerUrl(): string;
    /**
     *
     */
    set httpsTriggerUrl(value: string);
    /**
     *
     */
    resetHttpsTriggerUrl(): void;
    /**
     *
     */
    get httpsTriggerUrlInput(): string | undefined;
    /**
     *
     */
    get id(): string;
    private _ingressSettings?;
    /**
     *
     */
    get ingressSettings(): string;
    /**
     *
     */
    set ingressSettings(value: string);
    /**
     *
     */
    resetIngressSettings(): void;
    /**
     *
     */
    get ingressSettingsInput(): string | undefined;
    private _labels?;
    /**
     *
     */
    get labels(): {
        [key: string]: string;
    };
    /**
     *
     */
    set labels(value: {
        [key: string]: string;
    });
    /**
     *
     */
    resetLabels(): void;
    /**
     *
     */
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _maxInstances?;
    /**
     *
     */
    get maxInstances(): number;
    /**
     *
     */
    set maxInstances(value: number);
    /**
     *
     */
    resetMaxInstances(): void;
    /**
     *
     */
    get maxInstancesInput(): number | undefined;
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    get nameInput(): string;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _region?;
    /**
     *
     */
    get region(): string;
    /**
     *
     */
    set region(value: string);
    /**
     *
     */
    resetRegion(): void;
    /**
     *
     */
    get regionInput(): string | undefined;
    private _runtime;
    /**
     *
     */
    get runtime(): string;
    /**
     *
     */
    set runtime(value: string);
    /**
     *
     */
    get runtimeInput(): string;
    private _serviceAccountEmail?;
    /**
     *
     */
    get serviceAccountEmail(): string;
    /**
     *
     */
    set serviceAccountEmail(value: string);
    /**
     *
     */
    resetServiceAccountEmail(): void;
    /**
     *
     */
    get serviceAccountEmailInput(): string | undefined;
    private _sourceArchiveBucket?;
    /**
     *
     */
    get sourceArchiveBucket(): string;
    /**
     *
     */
    set sourceArchiveBucket(value: string);
    /**
     *
     */
    resetSourceArchiveBucket(): void;
    /**
     *
     */
    get sourceArchiveBucketInput(): string | undefined;
    private _sourceArchiveObject?;
    /**
     *
     */
    get sourceArchiveObject(): string;
    /**
     *
     */
    set sourceArchiveObject(value: string);
    /**
     *
     */
    resetSourceArchiveObject(): void;
    /**
     *
     */
    get sourceArchiveObjectInput(): string | undefined;
    private _timeout?;
    /**
     *
     */
    get timeout(): number;
    /**
     *
     */
    set timeout(value: number);
    /**
     *
     */
    resetTimeout(): void;
    /**
     *
     */
    get timeoutInput(): number | undefined;
    private _triggerHttp?;
    /**
     *
     */
    get triggerHttp(): boolean;
    /**
     *
     */
    set triggerHttp(value: boolean);
    /**
     *
     */
    resetTriggerHttp(): void;
    /**
     *
     */
    get triggerHttpInput(): boolean | undefined;
    private _vpcConnector?;
    /**
     *
     */
    get vpcConnector(): string;
    /**
     *
     */
    set vpcConnector(value: string);
    /**
     *
     */
    resetVpcConnector(): void;
    /**
     *
     */
    get vpcConnectorInput(): string | undefined;
    private _vpcConnectorEgressSettings?;
    /**
     *
     */
    get vpcConnectorEgressSettings(): string;
    /**
     *
     */
    set vpcConnectorEgressSettings(value: string);
    /**
     *
     */
    resetVpcConnectorEgressSettings(): void;
    /**
     *
     */
    get vpcConnectorEgressSettingsInput(): string | undefined;
    private _eventTrigger?;
    /**
     *
     */
    get eventTrigger(): CloudfunctionsFunctionEventTrigger[];
    /**
     *
     */
    set eventTrigger(value: CloudfunctionsFunctionEventTrigger[]);
    /**
     *
     */
    resetEventTrigger(): void;
    /**
     *
     */
    get eventTriggerInput(): CloudfunctionsFunctionEventTrigger[] | undefined;
    private _sourceRepository?;
    /**
     *
     */
    get sourceRepository(): CloudfunctionsFunctionSourceRepository[];
    /**
     *
     */
    set sourceRepository(value: CloudfunctionsFunctionSourceRepository[]);
    /**
     *
     */
    resetSourceRepository(): void;
    /**
     *
     */
    get sourceRepositoryInput(): CloudfunctionsFunctionSourceRepository[] | undefined;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): CloudfunctionsFunctionTimeouts;
    /**
     *
     */
    set timeouts(value: CloudfunctionsFunctionTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): CloudfunctionsFunctionTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
