import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface ComputeDiskConfig extends TerraformMetaArguments {
    /**
     * An optional description of this resource.
     *
     * Provide this property when
     * you create the resource.
     */
    readonly description?: string;
    /**
     * The image from which to initialize this disk.
     *
     * This can be
     * one of: the image's 'self_link', 'projects/{project}/global/images/{image}',
     * 'projects/{project}/global/images/family/{family}', 'global/images/{image}',
     * 'global/images/family/{family}', 'family/{family}', '{project}/{family}',
     * '{project}/{image}', '{family}', or '{image}'. If referred by family, the
     * images names must include the family name. If they don't, use the
     * [google_compute_image data source](/docs/providers/google/d/compute_image.html).
     * For instance, the image 'centos-6-v20180104' includes its family name 'centos-6'.
     * These images can be referred by family name here.
     */
    readonly image?: string;
    /**
     * Labels to apply to this disk.
     *
     * A list of key->value pairs.
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the resource.
     *
     * Provided by the client when the resource is
     * created. The name must be 1-63 characters long, and comply with
     * RFC1035. Specifically, the name must be 1-63 characters long and match
     * the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means the
     * first character must be a lowercase letter, and all following
     * characters must be a dash, lowercase letter, or digit, except the last
     * character, which cannot be a dash.
     */
    readonly name: string;
    /**
     * Physical block size of the persistent disk, in bytes.
     *
     * If not present
     * in a request, a default value is used. Currently supported sizes
     * are 4096 and 16384, other sizes may be added in the future.
     * If an unsupported value is requested, the error message will list
     * the supported values for the caller's project.
     */
    readonly physicalBlockSizeBytes?: number;
    /**
     *
     */
    readonly project?: string;
    /**
     * Size of the persistent disk, specified in GB.
     *
     * You can specify this
     * field when creating a persistent disk using the 'image' or
     * 'snapshot' parameter, or specify it alone to create an empty
     * persistent disk.
     *
     * If you specify this field along with 'image' or 'snapshot',
     * the value must not be less than the size of the image
     * or the size of the snapshot.
     */
    readonly size?: number;
    /**
     * The source snapshot used to create this disk.
     *
     * You can provide this as
     * a partial or full URL to the resource. If the snapshot is in another
     * project than this disk, you must supply a full URL. For example, the
     * following are valid values:
     *
     * 'https://www.googleapis.com/compute/v1/projects/project/global/snapshots/snapshot'
     * 'projects/project/global/snapshots/snapshot'
     * 'global/snapshots/snapshot'
     * 'snapshot'
     */
    readonly snapshot?: string;
    /**
     * URL of the disk type resource describing which disk type to use to create the disk.
     *
     * Provide this when creating the disk.
     */
    readonly type?: string;
    /**
     * A reference to the zone where the disk resides.
     */
    readonly zone?: string;
    /**
     * disk_encryption_key block.
     */
    readonly diskEncryptionKey?: ComputeDiskDiskEncryptionKey[];
    /**
     * source_image_encryption_key block.
     */
    readonly sourceImageEncryptionKey?: ComputeDiskSourceImageEncryptionKey[];
    /**
     * source_snapshot_encryption_key block.
     */
    readonly sourceSnapshotEncryptionKey?: ComputeDiskSourceSnapshotEncryptionKey[];
    /**
     * timeouts block.
     */
    readonly timeouts?: ComputeDiskTimeouts;
}
/**
 *
 */
export interface ComputeDiskDiskEncryptionKey {
    /**
     * The self link of the encryption key used to encrypt the disk.
     *
     * Also called KmsKeyName
     * in the cloud console. Your project's Compute Engine System service account
     * ('service-{{PROJECT_NUMBER}}@compute-system.iam.gserviceaccount.com') must have
     * 'roles/cloudkms.cryptoKeyEncrypterDecrypter' to use this feature.
     * See https://cloud.google.com/compute/docs/disks/customer-managed-encryption#encrypt_a_new_persistent_disk_with_your_own_keys
     */
    readonly kmsKeySelfLink?: string;
    /**
     * The service account used for the encryption request for the given KMS key.
     *
     * If absent, the Compute Engine Service Agent service account is used.
     */
    readonly kmsKeyServiceAccount?: string;
    /**
     * Specifies a 256-bit customer-supplied encryption key, encoded in RFC 4648 base64 to either encrypt or decrypt this resource.
     */
    readonly rawKey?: string;
}
/**
 *
 */
export interface ComputeDiskSourceImageEncryptionKey {
    /**
     * The self link of the encryption key used to encrypt the disk.
     *
     * Also called KmsKeyName
     * in the cloud console. Your project's Compute Engine System service account
     * ('service-{{PROJECT_NUMBER}}@compute-system.iam.gserviceaccount.com') must have
     * 'roles/cloudkms.cryptoKeyEncrypterDecrypter' to use this feature.
     * See https://cloud.google.com/compute/docs/disks/customer-managed-encryption#encrypt_a_new_persistent_disk_with_your_own_keys
     */
    readonly kmsKeySelfLink?: string;
    /**
     * The service account used for the encryption request for the given KMS key.
     *
     * If absent, the Compute Engine Service Agent service account is used.
     */
    readonly kmsKeyServiceAccount?: string;
    /**
     * Specifies a 256-bit customer-supplied encryption key, encoded in RFC 4648 base64 to either encrypt or decrypt this resource.
     */
    readonly rawKey?: string;
}
/**
 *
 */
export interface ComputeDiskSourceSnapshotEncryptionKey {
    /**
     * The self link of the encryption key used to encrypt the disk.
     *
     * Also called KmsKeyName
     * in the cloud console. Your project's Compute Engine System service account
     * ('service-{{PROJECT_NUMBER}}@compute-system.iam.gserviceaccount.com') must have
     * 'roles/cloudkms.cryptoKeyEncrypterDecrypter' to use this feature.
     * See https://cloud.google.com/compute/docs/disks/customer-managed-encryption#encrypt_a_new_persistent_disk_with_your_own_keys
     */
    readonly kmsKeySelfLink?: string;
    /**
     * The service account used for the encryption request for the given KMS key.
     *
     * If absent, the Compute Engine Service Agent service account is used.
     */
    readonly kmsKeyServiceAccount?: string;
    /**
     * Specifies a 256-bit customer-supplied encryption key, encoded in RFC 4648 base64 to either encrypt or decrypt this resource.
     */
    readonly rawKey?: string;
}
/**
 *
 */
export interface ComputeDiskTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class ComputeDisk extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: ComputeDiskConfig);
    /**
     *
     */
    get creationTimestamp(): string;
    private _description?;
    /**
     *
     */
    get description(): string;
    /**
     *
     */
    set description(value: string);
    /**
     *
     */
    resetDescription(): void;
    /**
     *
     */
    get descriptionInput(): string | undefined;
    /**
     *
     */
    get id(): string;
    private _image?;
    /**
     *
     */
    get image(): string;
    /**
     *
     */
    set image(value: string);
    /**
     *
     */
    resetImage(): void;
    /**
     *
     */
    get imageInput(): string | undefined;
    /**
     *
     */
    get labelFingerprint(): string;
    private _labels?;
    /**
     *
     */
    get labels(): {
        [key: string]: string;
    };
    /**
     *
     */
    set labels(value: {
        [key: string]: string;
    });
    /**
     *
     */
    resetLabels(): void;
    /**
     *
     */
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    /**
     *
     */
    get lastAttachTimestamp(): string;
    /**
     *
     */
    get lastDetachTimestamp(): string;
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    get nameInput(): string;
    private _physicalBlockSizeBytes?;
    /**
     *
     */
    get physicalBlockSizeBytes(): number;
    /**
     *
     */
    set physicalBlockSizeBytes(value: number);
    /**
     *
     */
    resetPhysicalBlockSizeBytes(): void;
    /**
     *
     */
    get physicalBlockSizeBytesInput(): number | undefined;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    /**
     *
     */
    get selfLink(): string;
    private _size?;
    /**
     *
     */
    get size(): number;
    /**
     *
     */
    set size(value: number);
    /**
     *
     */
    resetSize(): void;
    /**
     *
     */
    get sizeInput(): number | undefined;
    private _snapshot?;
    /**
     *
     */
    get snapshot(): string;
    /**
     *
     */
    set snapshot(value: string);
    /**
     *
     */
    resetSnapshot(): void;
    /**
     *
     */
    get snapshotInput(): string | undefined;
    /**
     *
     */
    get sourceImageId(): string;
    /**
     *
     */
    get sourceSnapshotId(): string;
    private _type?;
    /**
     *
     */
    get type(): string;
    /**
     *
     */
    set type(value: string);
    /**
     *
     */
    resetType(): void;
    /**
     *
     */
    get typeInput(): string | undefined;
    /**
     *
     */
    get users(): string[];
    private _zone?;
    /**
     *
     */
    get zone(): string;
    /**
     *
     */
    set zone(value: string);
    /**
     *
     */
    resetZone(): void;
    /**
     *
     */
    get zoneInput(): string | undefined;
    private _diskEncryptionKey?;
    /**
     *
     */
    get diskEncryptionKey(): ComputeDiskDiskEncryptionKey[];
    /**
     *
     */
    set diskEncryptionKey(value: ComputeDiskDiskEncryptionKey[]);
    /**
     *
     */
    resetDiskEncryptionKey(): void;
    /**
     *
     */
    get diskEncryptionKeyInput(): ComputeDiskDiskEncryptionKey[] | undefined;
    private _sourceImageEncryptionKey?;
    /**
     *
     */
    get sourceImageEncryptionKey(): ComputeDiskSourceImageEncryptionKey[];
    /**
     *
     */
    set sourceImageEncryptionKey(value: ComputeDiskSourceImageEncryptionKey[]);
    /**
     *
     */
    resetSourceImageEncryptionKey(): void;
    /**
     *
     */
    get sourceImageEncryptionKeyInput(): ComputeDiskSourceImageEncryptionKey[] | undefined;
    private _sourceSnapshotEncryptionKey?;
    /**
     *
     */
    get sourceSnapshotEncryptionKey(): ComputeDiskSourceSnapshotEncryptionKey[];
    /**
     *
     */
    set sourceSnapshotEncryptionKey(value: ComputeDiskSourceSnapshotEncryptionKey[]);
    /**
     *
     */
    resetSourceSnapshotEncryptionKey(): void;
    /**
     *
     */
    get sourceSnapshotEncryptionKeyInput(): ComputeDiskSourceSnapshotEncryptionKey[] | undefined;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): ComputeDiskTimeouts;
    /**
     *
     */
    set timeouts(value: ComputeDiskTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): ComputeDiskTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
