import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface ComputeFirewallConfig extends TerraformMetaArguments {
    /**
     * An optional description of this resource.
     *
     * Provide this property when
     * you create the resource.
     */
    readonly description?: string;
    /**
     * If destination ranges are specified, the firewall will apply only to traffic that has destination IP address in these ranges.
     *
     * These ranges
     * must be expressed in CIDR format. Only IPv4 is supported.
     */
    readonly destinationRanges?: string[];
    /**
     * Direction of traffic to which this firewall applies;
     *
     * default is
     * INGRESS. Note: For INGRESS traffic, it is NOT supported to specify
     * destinationRanges; For EGRESS traffic, it is NOT supported to specify
     * sourceRanges OR sourceTags. Possible values: ["INGRESS", "EGRESS"]
     */
    readonly direction?: string;
    /**
     * Denotes whether the firewall rule is disabled, i.e not applied to the network it is associated with. When set to true, the firewall rule is not enforced and the network behaves as if it did not exist. If this is unspecified, the firewall rule will be enabled.
     */
    readonly disabled?: boolean;
    /**
     * This field denotes whether to enable logging for a particular firewall rule.
     *
     * If logging is enabled, logs will be exported to Stackdriver.
     */
    readonly enableLogging?: boolean;
    /**
     * Name of the resource.
     *
     * Provided by the client when the resource is
     * created. The name must be 1-63 characters long, and comply with
     * RFC1035. Specifically, the name must be 1-63 characters long and match
     * the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means the
     * first character must be a lowercase letter, and all following
     * characters must be a dash, lowercase letter, or digit, except the last
     * character, which cannot be a dash.
     */
    readonly name: string;
    /**
     * The name or self_link of the network to attach this firewall to.
     */
    readonly network: string;
    /**
     * Priority for this rule.
     *
     * This is an integer between 0 and 65535, both
     * inclusive. When not specified, the value assumed is 1000. Relative
     * priorities determine precedence of conflicting rules. Lower value of
     * priority implies higher precedence (eg, a rule with priority 0 has
     * higher precedence than a rule with priority 1). DENY rules take
     * precedence over ALLOW rules having equal priority.
     */
    readonly priority?: number;
    /**
     *
     */
    readonly project?: string;
    /**
     * If source ranges are specified, the firewall will apply only to traffic that has source IP address in these ranges.
     *
     * These ranges must
     * be expressed in CIDR format. One or both of sourceRanges and
     * sourceTags may be set. If both properties are set, the firewall will
     * apply to traffic that has source IP address within sourceRanges OR the
     * source IP that belongs to a tag listed in the sourceTags property. The
     * connection does not need to match both properties for the firewall to
     * apply. Only IPv4 is supported.
     */
    readonly sourceRanges?: string[];
    /**
     * If source service accounts are specified, the firewall will apply only to traffic originating from an instance with a service account in this list.
     *
     * Source service accounts cannot be used to control traffic to an
     * instance's external IP address because service accounts are associated
     * with an instance, not an IP address. sourceRanges can be set at the
     * same time as sourceServiceAccounts. If both are set, the firewall will
     * apply to traffic that has source IP address within sourceRanges OR the
     * source IP belongs to an instance with service account listed in
     * sourceServiceAccount. The connection does not need to match both
     * properties for the firewall to apply. sourceServiceAccounts cannot be
     * used at the same time as sourceTags or targetTags.
     */
    readonly sourceServiceAccounts?: string[];
    /**
     * If source tags are specified, the firewall will apply only to traffic with source IP that belongs to a tag listed in source tags.
     *
     * Source
     * tags cannot be used to control traffic to an instance's external IP
     * address. Because tags are associated with an instance, not an IP
     * address. One or both of sourceRanges and sourceTags may be set. If
     * both properties are set, the firewall will apply to traffic that has
     * source IP address within sourceRanges OR the source IP that belongs to
     * a tag listed in the sourceTags property. The connection does not need
     * to match both properties for the firewall to apply.
     */
    readonly sourceTags?: string[];
    /**
     * A list of service accounts indicating sets of instances located in the network that may make network connections as specified in allowed[].
     *
     * targetServiceAccounts cannot be used at the same time as targetTags or
     * sourceTags. If neither targetServiceAccounts nor targetTags are
     * specified, the firewall rule applies to all instances on the specified
     * network.
     */
    readonly targetServiceAccounts?: string[];
    /**
     * A list of instance tags indicating sets of instances located in the network that may make network connections as specified in allowed[].
     *
     * If no targetTags are specified, the firewall rule applies to all
     * instances on the specified network.
     */
    readonly targetTags?: string[];
    /**
     * allow block.
     */
    readonly allow?: ComputeFirewallAllow[];
    /**
     * deny block.
     */
    readonly deny?: ComputeFirewallDeny[];
    /**
     * log_config block.
     */
    readonly logConfig?: ComputeFirewallLogConfig[];
    /**
     * timeouts block.
     */
    readonly timeouts?: ComputeFirewallTimeouts;
}
/**
 *
 */
export interface ComputeFirewallAllow {
    /**
     * An optional list of ports to which this rule applies.
     *
     * This field
     * is only applicable for UDP or TCP protocol. Each entry must be
     * either an integer or a range. If not specified, this rule
     * applies to connections through any port.
     *
     * Example inputs include: ["22"], ["80","443"], and
     * ["12345-12349"].
     */
    readonly ports?: string[];
    /**
     * The IP protocol to which this rule applies.
     *
     * The protocol type is
     * required when creating a firewall rule. This value can either be
     * one of the following well known protocol strings (tcp, udp,
     * icmp, esp, ah, sctp, ipip, all), or the IP protocol number.
     */
    readonly protocol: string;
}
/**
 *
 */
export interface ComputeFirewallDeny {
    /**
     * An optional list of ports to which this rule applies.
     *
     * This field
     * is only applicable for UDP or TCP protocol. Each entry must be
     * either an integer or a range. If not specified, this rule
     * applies to connections through any port.
     *
     * Example inputs include: ["22"], ["80","443"], and
     * ["12345-12349"].
     */
    readonly ports?: string[];
    /**
     * The IP protocol to which this rule applies.
     *
     * The protocol type is
     * required when creating a firewall rule. This value can either be
     * one of the following well known protocol strings (tcp, udp,
     * icmp, esp, ah, sctp, ipip, all), or the IP protocol number.
     */
    readonly protocol: string;
}
/**
 *
 */
export interface ComputeFirewallLogConfig {
    /**
     * This field denotes whether to include or exclude metadata for firewall logs.
     *
     * Possible values: ["EXCLUDE_ALL_METADATA", "INCLUDE_ALL_METADATA"]
     */
    readonly metadata: string;
}
/**
 *
 */
export interface ComputeFirewallTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class ComputeFirewall extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: ComputeFirewallConfig);
    /**
     *
     */
    get creationTimestamp(): string;
    private _description?;
    /**
     *
     */
    get description(): string;
    /**
     *
     */
    set description(value: string);
    /**
     *
     */
    resetDescription(): void;
    /**
     *
     */
    get descriptionInput(): string | undefined;
    private _destinationRanges?;
    /**
     *
     */
    get destinationRanges(): string[];
    /**
     *
     */
    set destinationRanges(value: string[]);
    /**
     *
     */
    resetDestinationRanges(): void;
    /**
     *
     */
    get destinationRangesInput(): string[] | undefined;
    private _direction?;
    /**
     *
     */
    get direction(): string;
    /**
     *
     */
    set direction(value: string);
    /**
     *
     */
    resetDirection(): void;
    /**
     *
     */
    get directionInput(): string | undefined;
    private _disabled?;
    /**
     *
     */
    get disabled(): boolean;
    /**
     *
     */
    set disabled(value: boolean);
    /**
     *
     */
    resetDisabled(): void;
    /**
     *
     */
    get disabledInput(): boolean | undefined;
    private _enableLogging?;
    /**
     *
     */
    get enableLogging(): boolean;
    /**
     *
     */
    set enableLogging(value: boolean);
    /**
     *
     */
    resetEnableLogging(): void;
    /**
     *
     */
    get enableLoggingInput(): boolean | undefined;
    /**
     *
     */
    get id(): string;
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    get nameInput(): string;
    private _network;
    /**
     *
     */
    get network(): string;
    /**
     *
     */
    set network(value: string);
    /**
     *
     */
    get networkInput(): string;
    private _priority?;
    /**
     *
     */
    get priority(): number;
    /**
     *
     */
    set priority(value: number);
    /**
     *
     */
    resetPriority(): void;
    /**
     *
     */
    get priorityInput(): number | undefined;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    /**
     *
     */
    get selfLink(): string;
    private _sourceRanges?;
    /**
     *
     */
    get sourceRanges(): string[];
    /**
     *
     */
    set sourceRanges(value: string[]);
    /**
     *
     */
    resetSourceRanges(): void;
    /**
     *
     */
    get sourceRangesInput(): string[] | undefined;
    private _sourceServiceAccounts?;
    /**
     *
     */
    get sourceServiceAccounts(): string[];
    /**
     *
     */
    set sourceServiceAccounts(value: string[]);
    /**
     *
     */
    resetSourceServiceAccounts(): void;
    /**
     *
     */
    get sourceServiceAccountsInput(): string[] | undefined;
    private _sourceTags?;
    /**
     *
     */
    get sourceTags(): string[];
    /**
     *
     */
    set sourceTags(value: string[]);
    /**
     *
     */
    resetSourceTags(): void;
    /**
     *
     */
    get sourceTagsInput(): string[] | undefined;
    private _targetServiceAccounts?;
    /**
     *
     */
    get targetServiceAccounts(): string[];
    /**
     *
     */
    set targetServiceAccounts(value: string[]);
    /**
     *
     */
    resetTargetServiceAccounts(): void;
    /**
     *
     */
    get targetServiceAccountsInput(): string[] | undefined;
    private _targetTags?;
    /**
     *
     */
    get targetTags(): string[];
    /**
     *
     */
    set targetTags(value: string[]);
    /**
     *
     */
    resetTargetTags(): void;
    /**
     *
     */
    get targetTagsInput(): string[] | undefined;
    private _allow?;
    /**
     *
     */
    get allow(): ComputeFirewallAllow[];
    /**
     *
     */
    set allow(value: ComputeFirewallAllow[]);
    /**
     *
     */
    resetAllow(): void;
    /**
     *
     */
    get allowInput(): ComputeFirewallAllow[] | undefined;
    private _deny?;
    /**
     *
     */
    get deny(): ComputeFirewallDeny[];
    /**
     *
     */
    set deny(value: ComputeFirewallDeny[]);
    /**
     *
     */
    resetDeny(): void;
    /**
     *
     */
    get denyInput(): ComputeFirewallDeny[] | undefined;
    private _logConfig?;
    /**
     *
     */
    get logConfig(): ComputeFirewallLogConfig[];
    /**
     *
     */
    set logConfig(value: ComputeFirewallLogConfig[]);
    /**
     *
     */
    resetLogConfig(): void;
    /**
     *
     */
    get logConfigInput(): ComputeFirewallLogConfig[] | undefined;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): ComputeFirewallTimeouts;
    /**
     *
     */
    set timeouts(value: ComputeFirewallTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): ComputeFirewallTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
