import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface ComputeForwardingRuleConfig extends TerraformMetaArguments {
    /**
     * For internal TCP/UDP load balancing (i.e. load balancing scheme is INTERNAL and protocol is TCP/UDP), set this to true to allow packets addressed to any ports to be forwarded to the backends configured with this forwarding rule. Used with backend service. Cannot be set if port or portRange are set.
     */
    readonly allPorts?: boolean;
    /**
     * If true, clients can access ILB from all regions.
     *
     * Otherwise only allows from the local region the ILB is located at.
     */
    readonly allowGlobalAccess?: boolean;
    /**
     * A BackendService to receive the matched traffic.
     *
     * This is used only
     * for INTERNAL load balancing.
     */
    readonly backendService?: string;
    /**
     * An optional description of this resource.
     *
     * Provide this property when
     * you create the resource.
     */
    readonly description?: string;
    /**
     * The IP address that this forwarding rule is serving on behalf of.
     *
     * Addresses are restricted based on the forwarding rule's load balancing
     * scheme (EXTERNAL or INTERNAL) and scope (global or regional).
     *
     * When the load balancing scheme is EXTERNAL, for global forwarding
     * rules, the address must be a global IP, and for regional forwarding
     * rules, the address must live in the same region as the forwarding
     * rule. If this field is empty, an ephemeral IPv4 address from the same
     * scope (global or regional) will be assigned. A regional forwarding
     * rule supports IPv4 only. A global forwarding rule supports either IPv4
     * or IPv6.
     *
     * When the load balancing scheme is INTERNAL, this can only be an RFC
     * 1918 IP address belonging to the network/subnet configured for the
     * forwarding rule. By default, if this field is empty, an ephemeral
     * internal IP address will be automatically allocated from the IP range
     * of the subnet or network configured for this forwarding rule.
     *
     * An address must be specified by a literal IP address. ~> **NOTE:** While
     * the API allows you to specify various resource paths for an address resource
     * instead, Terraform requires this to specifically be an IP address to
     * avoid needing to fetching the IP address from resource paths on refresh
     * or unnecessary diffs.
     */
    readonly ipAddress?: string;
    /**
     * The IP protocol to which this rule applies.
     *
     * When the load balancing scheme is INTERNAL, only TCP and UDP are
     * valid. Possible values: ["TCP", "UDP", "ESP", "AH", "SCTP", "ICMP"]
     */
    readonly ipProtocol?: string;
    /**
     * This signifies what the ForwardingRule will be used for and can be EXTERNAL, INTERNAL, or INTERNAL_MANAGED.
     *
     * EXTERNAL is used for Classic
     * Cloud VPN gateways, protocol forwarding to VMs from an external IP address,
     * and HTTP(S), SSL Proxy, TCP Proxy, and Network TCP/UDP load balancers.
     * INTERNAL is used for protocol forwarding to VMs from an internal IP address,
     * and internal TCP/UDP load balancers.
     * INTERNAL_MANAGED is used for internal HTTP(S) load balancers. Default value: "EXTERNAL" Possible values: ["EXTERNAL", "INTERNAL", "INTERNAL_MANAGED"]
     */
    readonly loadBalancingScheme?: string;
    /**
     * Name of the resource;
     *
     * provided by the client when the resource is
     * created. The name must be 1-63 characters long, and comply with
     * RFC1035. Specifically, the name must be 1-63 characters long and match
     * the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means the
     * first character must be a lowercase letter, and all following
     * characters must be a dash, lowercase letter, or digit, except the last
     * character, which cannot be a dash.
     */
    readonly name: string;
    /**
     * For internal load balancing, this field identifies the network that the load balanced IP should belong to for this Forwarding Rule.
     *
     * If
     * this field is not specified, the default network will be used.
     * This field is only used for INTERNAL load balancing.
     */
    readonly network?: string;
    /**
     * The networking tier used for configuring this address.
     *
     * If this field is not
     * specified, it is assumed to be PREMIUM. Possible values: ["PREMIUM", "STANDARD"]
     */
    readonly networkTier?: string;
    /**
     * This field is used along with the target field for TargetHttpProxy, TargetHttpsProxy, TargetSslProxy, TargetTcpProxy, TargetVpnGateway, TargetPool, TargetInstance.
     *
     * Applicable only when IPProtocol is TCP, UDP, or SCTP, only packets
     * addressed to ports in the specified range will be forwarded to target.
     * Forwarding rules with the same [IPAddress, IPProtocol] pair must have
     * disjoint port ranges.
     *
     * Some types of forwarding target have constraints on the acceptable
     * ports:
     *
     * TargetHttpProxy: 80, 8080
     * TargetHttpsProxy: 443
     * TargetTcpProxy: 25, 43, 110, 143, 195, 443, 465, 587, 700, 993, 995,
     *             1883, 5222
     * TargetSslProxy: 25, 43, 110, 143, 195, 443, 465, 587, 700, 993, 995,
     *             1883, 5222
     * TargetVpnGateway: 500, 4500
     */
    readonly portRange?: string;
    /**
     * This field is used along with the backend_service field for internal load balancing.
     *
     * When the load balancing scheme is INTERNAL, a single port or a comma
     * separated list of ports can be configured. Only packets addressed to
     * these ports will be forwarded to the backends configured with this
     * forwarding rule.
     *
     * You may specify a maximum of up to 5 ports.
     */
    readonly ports?: string[];
    /**
     *
     */
    readonly project?: string;
    /**
     * A reference to the region where the regional forwarding rule resides.
     *
     * This field is not applicable to global forwarding rules.
     */
    readonly region?: string;
    /**
     * An optional prefix to the service name for this Forwarding Rule.
     *
     * If specified, will be the first label of the fully qualified service
     * name.
     *
     * The label must be 1-63 characters long, and comply with RFC1035.
     * Specifically, the label must be 1-63 characters long and match the
     * regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means the first
     * character must be a lowercase letter, and all following characters
     * must be a dash, lowercase letter, or digit, except the last
     * character, which cannot be a dash.
     *
     * This field is only used for INTERNAL load balancing.
     */
    readonly serviceLabel?: string;
    /**
     * The subnetwork that the load balanced IP should belong to for this Forwarding Rule.
     *
     * This field is only used for INTERNAL load balancing.
     *
     * If the network specified is in auto subnet mode, this field is
     * optional. However, if the network is in custom subnet mode, a
     * subnetwork must be specified.
     */
    readonly subnetwork?: string;
    /**
     * The URL of the target resource to receive the matched traffic.
     *
     * The target must live in the same region as the forwarding rule.
     * The forwarded traffic must be of a type appropriate to the target
     * object.
     */
    readonly target?: string;
    /**
     * timeouts block.
     */
    readonly timeouts?: ComputeForwardingRuleTimeouts;
}
/**
 *
 */
export interface ComputeForwardingRuleTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class ComputeForwardingRule extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: ComputeForwardingRuleConfig);
    private _allPorts?;
    /**
     *
     */
    get allPorts(): boolean;
    /**
     *
     */
    set allPorts(value: boolean);
    /**
     *
     */
    resetAllPorts(): void;
    /**
     *
     */
    get allPortsInput(): boolean | undefined;
    private _allowGlobalAccess?;
    /**
     *
     */
    get allowGlobalAccess(): boolean;
    /**
     *
     */
    set allowGlobalAccess(value: boolean);
    /**
     *
     */
    resetAllowGlobalAccess(): void;
    /**
     *
     */
    get allowGlobalAccessInput(): boolean | undefined;
    private _backendService?;
    /**
     *
     */
    get backendService(): string;
    /**
     *
     */
    set backendService(value: string);
    /**
     *
     */
    resetBackendService(): void;
    /**
     *
     */
    get backendServiceInput(): string | undefined;
    /**
     *
     */
    get creationTimestamp(): string;
    private _description?;
    /**
     *
     */
    get description(): string;
    /**
     *
     */
    set description(value: string);
    /**
     *
     */
    resetDescription(): void;
    /**
     *
     */
    get descriptionInput(): string | undefined;
    /**
     *
     */
    get id(): string;
    private _ipAddress?;
    /**
     *
     */
    get ipAddress(): string;
    /**
     *
     */
    set ipAddress(value: string);
    /**
     *
     */
    resetIpAddress(): void;
    /**
     *
     */
    get ipAddressInput(): string | undefined;
    private _ipProtocol?;
    /**
     *
     */
    get ipProtocol(): string;
    /**
     *
     */
    set ipProtocol(value: string);
    /**
     *
     */
    resetIpProtocol(): void;
    /**
     *
     */
    get ipProtocolInput(): string | undefined;
    private _loadBalancingScheme?;
    /**
     *
     */
    get loadBalancingScheme(): string;
    /**
     *
     */
    set loadBalancingScheme(value: string);
    /**
     *
     */
    resetLoadBalancingScheme(): void;
    /**
     *
     */
    get loadBalancingSchemeInput(): string | undefined;
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    get nameInput(): string;
    private _network?;
    /**
     *
     */
    get network(): string;
    /**
     *
     */
    set network(value: string);
    /**
     *
     */
    resetNetwork(): void;
    /**
     *
     */
    get networkInput(): string | undefined;
    private _networkTier?;
    /**
     *
     */
    get networkTier(): string;
    /**
     *
     */
    set networkTier(value: string);
    /**
     *
     */
    resetNetworkTier(): void;
    /**
     *
     */
    get networkTierInput(): string | undefined;
    private _portRange?;
    /**
     *
     */
    get portRange(): string;
    /**
     *
     */
    set portRange(value: string);
    /**
     *
     */
    resetPortRange(): void;
    /**
     *
     */
    get portRangeInput(): string | undefined;
    private _ports?;
    /**
     *
     */
    get ports(): string[];
    /**
     *
     */
    set ports(value: string[]);
    /**
     *
     */
    resetPorts(): void;
    /**
     *
     */
    get portsInput(): string[] | undefined;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _region?;
    /**
     *
     */
    get region(): string;
    /**
     *
     */
    set region(value: string);
    /**
     *
     */
    resetRegion(): void;
    /**
     *
     */
    get regionInput(): string | undefined;
    /**
     *
     */
    get selfLink(): string;
    private _serviceLabel?;
    /**
     *
     */
    get serviceLabel(): string;
    /**
     *
     */
    set serviceLabel(value: string);
    /**
     *
     */
    resetServiceLabel(): void;
    /**
     *
     */
    get serviceLabelInput(): string | undefined;
    /**
     *
     */
    get serviceName(): string;
    private _subnetwork?;
    /**
     *
     */
    get subnetwork(): string;
    /**
     *
     */
    set subnetwork(value: string);
    /**
     *
     */
    resetSubnetwork(): void;
    /**
     *
     */
    get subnetworkInput(): string | undefined;
    private _target?;
    /**
     *
     */
    get target(): string;
    /**
     *
     */
    set target(value: string);
    /**
     *
     */
    resetTarget(): void;
    /**
     *
     */
    get targetInput(): string | undefined;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): ComputeForwardingRuleTimeouts;
    /**
     *
     */
    set timeouts(value: ComputeForwardingRuleTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): ComputeForwardingRuleTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
