import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface ComputeHttpHealthCheckConfig extends TerraformMetaArguments {
    /**
     * How often (in seconds) to send a health check.
     *
     * The default value is 5
     * seconds.
     */
    readonly checkIntervalSec?: number;
    /**
     * An optional description of this resource.
     *
     * Provide this property when
     * you create the resource.
     */
    readonly description?: string;
    /**
     * A so-far unhealthy instance will be marked healthy after this many consecutive successes.
     *
     * The default value is 2.
     */
    readonly healthyThreshold?: number;
    /**
     * The value of the host header in the HTTP health check request.
     *
     * If
     * left empty (default value), the public IP on behalf of which this
     * health check is performed will be used.
     */
    readonly host?: string;
    /**
     * Name of the resource.
     *
     * Provided by the client when the resource is
     * created. The name must be 1-63 characters long, and comply with
     * RFC1035.  Specifically, the name must be 1-63 characters long and
     * match the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means
     * the first character must be a lowercase letter, and all following
     * characters must be a dash, lowercase letter, or digit, except the
     * last character, which cannot be a dash.
     */
    readonly name: string;
    /**
     * The TCP port number for the HTTP health check request.
     *
     * The default value is 80.
     */
    readonly port?: number;
    /**
     *
     */
    readonly project?: string;
    /**
     * The request path of the HTTP health check request.
     *
     * The default value is /.
     */
    readonly requestPath?: string;
    /**
     * How long (in seconds) to wait before claiming failure.
     *
     * The default value is 5 seconds.  It is invalid for timeoutSec to have
     * greater value than checkIntervalSec.
     */
    readonly timeoutSec?: number;
    /**
     * A so-far healthy instance will be marked unhealthy after this many consecutive failures.
     *
     * The default value is 2.
     */
    readonly unhealthyThreshold?: number;
    /**
     * timeouts block.
     */
    readonly timeouts?: ComputeHttpHealthCheckTimeouts;
}
/**
 *
 */
export interface ComputeHttpHealthCheckTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class ComputeHttpHealthCheck extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: ComputeHttpHealthCheckConfig);
    private _checkIntervalSec?;
    /**
     *
     */
    get checkIntervalSec(): number;
    /**
     *
     */
    set checkIntervalSec(value: number);
    /**
     *
     */
    resetCheckIntervalSec(): void;
    /**
     *
     */
    get checkIntervalSecInput(): number | undefined;
    /**
     *
     */
    get creationTimestamp(): string;
    private _description?;
    /**
     *
     */
    get description(): string;
    /**
     *
     */
    set description(value: string);
    /**
     *
     */
    resetDescription(): void;
    /**
     *
     */
    get descriptionInput(): string | undefined;
    private _healthyThreshold?;
    /**
     *
     */
    get healthyThreshold(): number;
    /**
     *
     */
    set healthyThreshold(value: number);
    /**
     *
     */
    resetHealthyThreshold(): void;
    /**
     *
     */
    get healthyThresholdInput(): number | undefined;
    private _host?;
    /**
     *
     */
    get host(): string;
    /**
     *
     */
    set host(value: string);
    /**
     *
     */
    resetHost(): void;
    /**
     *
     */
    get hostInput(): string | undefined;
    /**
     *
     */
    get id(): string;
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    get nameInput(): string;
    private _port?;
    /**
     *
     */
    get port(): number;
    /**
     *
     */
    set port(value: number);
    /**
     *
     */
    resetPort(): void;
    /**
     *
     */
    get portInput(): number | undefined;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _requestPath?;
    /**
     *
     */
    get requestPath(): string;
    /**
     *
     */
    set requestPath(value: string);
    /**
     *
     */
    resetRequestPath(): void;
    /**
     *
     */
    get requestPathInput(): string | undefined;
    /**
     *
     */
    get selfLink(): string;
    private _timeoutSec?;
    /**
     *
     */
    get timeoutSec(): number;
    /**
     *
     */
    set timeoutSec(value: number);
    /**
     *
     */
    resetTimeoutSec(): void;
    /**
     *
     */
    get timeoutSecInput(): number | undefined;
    private _unhealthyThreshold?;
    /**
     *
     */
    get unhealthyThreshold(): number;
    /**
     *
     */
    set unhealthyThreshold(value: number);
    /**
     *
     */
    resetUnhealthyThreshold(): void;
    /**
     *
     */
    get unhealthyThresholdInput(): number | undefined;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): ComputeHttpHealthCheckTimeouts;
    /**
     *
     */
    set timeouts(value: ComputeHttpHealthCheckTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): ComputeHttpHealthCheckTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
