import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface ComputeNodeGroupConfig extends TerraformMetaArguments {
    /**
     * An optional textual description of the resource.
     */
    readonly description?: string;
    /**
     * Specifies how to handle instances when a node in the group undergoes maintenance.
     *
     * Set to one of: DEFAULT, RESTART_IN_PLACE, or MIGRATE_WITHIN_NODE_GROUP. The default value is DEFAULT.
     */
    readonly maintenancePolicy?: string;
    /**
     * Name of the resource.
     */
    readonly name?: string;
    /**
     * The URL of the node template to which this node group belongs.
     */
    readonly nodeTemplate: string;
    /**
     *
     */
    readonly project?: string;
    /**
     * The total number of nodes in the node group.
     */
    readonly size: number;
    /**
     * Zone where this node group is located.
     */
    readonly zone?: string;
    /**
     * autoscaling_policy block.
     */
    readonly autoscalingPolicy?: ComputeNodeGroupAutoscalingPolicy[];
    /**
     * timeouts block.
     */
    readonly timeouts?: ComputeNodeGroupTimeouts;
}
/**
 *
 */
export interface ComputeNodeGroupAutoscalingPolicy {
    /**
     * Maximum size of the node group.
     *
     * Set to a value less than or equal
     * to 100 and greater than or equal to min-nodes.
     */
    readonly maxNodes?: number;
    /**
     * Minimum size of the node group.
     *
     * Must be less
     * than or equal to max-nodes. The default value is 0.
     */
    readonly minNodes?: number;
    /**
     * The autoscaling mode.
     *
     * Set to one of the following:
     * - OFF: Disables the autoscaler.
     * - ON: Enables scaling in and scaling out.
     * - ONLY_SCALE_OUT: Enables only scaling out.
     * You must use this mode if your node groups are configured to
     * restart their hosted VMs on minimal servers. Possible values: ["OFF", "ON", "ONLY_SCALE_OUT"]
     */
    readonly mode?: string;
}
/**
 *
 */
export interface ComputeNodeGroupTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class ComputeNodeGroup extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: ComputeNodeGroupConfig);
    /**
     *
     */
    get creationTimestamp(): string;
    private _description?;
    /**
     *
     */
    get description(): string;
    /**
     *
     */
    set description(value: string);
    /**
     *
     */
    resetDescription(): void;
    /**
     *
     */
    get descriptionInput(): string | undefined;
    /**
     *
     */
    get id(): string;
    private _maintenancePolicy?;
    /**
     *
     */
    get maintenancePolicy(): string;
    /**
     *
     */
    set maintenancePolicy(value: string);
    /**
     *
     */
    resetMaintenancePolicy(): void;
    /**
     *
     */
    get maintenancePolicyInput(): string | undefined;
    private _name?;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    resetName(): void;
    /**
     *
     */
    get nameInput(): string | undefined;
    private _nodeTemplate;
    /**
     *
     */
    get nodeTemplate(): string;
    /**
     *
     */
    set nodeTemplate(value: string);
    /**
     *
     */
    get nodeTemplateInput(): string;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    /**
     *
     */
    get selfLink(): string;
    private _size;
    /**
     *
     */
    get size(): number;
    /**
     *
     */
    set size(value: number);
    /**
     *
     */
    get sizeInput(): number;
    private _zone?;
    /**
     *
     */
    get zone(): string;
    /**
     *
     */
    set zone(value: string);
    /**
     *
     */
    resetZone(): void;
    /**
     *
     */
    get zoneInput(): string | undefined;
    private _autoscalingPolicy?;
    /**
     *
     */
    get autoscalingPolicy(): ComputeNodeGroupAutoscalingPolicy[];
    /**
     *
     */
    set autoscalingPolicy(value: ComputeNodeGroupAutoscalingPolicy[]);
    /**
     *
     */
    resetAutoscalingPolicy(): void;
    /**
     *
     */
    get autoscalingPolicyInput(): ComputeNodeGroupAutoscalingPolicy[] | undefined;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): ComputeNodeGroupTimeouts;
    /**
     *
     */
    set timeouts(value: ComputeNodeGroupTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): ComputeNodeGroupTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
