import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface ComputeNodeTemplateConfig extends TerraformMetaArguments {
    /**
     * An optional textual description of the resource.
     */
    readonly description?: string;
    /**
     * Name of the resource.
     */
    readonly name?: string;
    /**
     * Labels to use for node affinity, which will be used in instance scheduling.
     */
    readonly nodeAffinityLabels?: {
        [key: string]: string;
    };
    /**
     * Node type to use for nodes group that are created from this template.
     *
     * Only one of nodeTypeFlexibility and nodeType can be specified.
     */
    readonly nodeType?: string;
    /**
     *
     */
    readonly project?: string;
    /**
     * Region where nodes using the node template will be created.
     *
     * If it is not provided, the provider region is used.
     */
    readonly region?: string;
    /**
     * node_type_flexibility block.
     */
    readonly nodeTypeFlexibility?: ComputeNodeTemplateNodeTypeFlexibility[];
    /**
     * timeouts block.
     */
    readonly timeouts?: ComputeNodeTemplateTimeouts;
}
/**
 *
 */
export interface ComputeNodeTemplateNodeTypeFlexibility {
    /**
     * Number of virtual CPUs to use.
     */
    readonly cpus?: string;
    /**
     * Physical memory available to the node, defined in MB.
     */
    readonly memory?: string;
}
/**
 *
 */
export interface ComputeNodeTemplateTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
}
/**
 *
 */
export declare class ComputeNodeTemplate extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config?: ComputeNodeTemplateConfig);
    /**
     *
     */
    get creationTimestamp(): string;
    private _description?;
    /**
     *
     */
    get description(): string;
    /**
     *
     */
    set description(value: string);
    /**
     *
     */
    resetDescription(): void;
    /**
     *
     */
    get descriptionInput(): string | undefined;
    /**
     *
     */
    get id(): string;
    private _name?;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    resetName(): void;
    /**
     *
     */
    get nameInput(): string | undefined;
    private _nodeAffinityLabels?;
    /**
     *
     */
    get nodeAffinityLabels(): {
        [key: string]: string;
    };
    /**
     *
     */
    set nodeAffinityLabels(value: {
        [key: string]: string;
    });
    /**
     *
     */
    resetNodeAffinityLabels(): void;
    /**
     *
     */
    get nodeAffinityLabelsInput(): {
        [key: string]: string;
    } | undefined;
    private _nodeType?;
    /**
     *
     */
    get nodeType(): string;
    /**
     *
     */
    set nodeType(value: string);
    /**
     *
     */
    resetNodeType(): void;
    /**
     *
     */
    get nodeTypeInput(): string | undefined;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _region?;
    /**
     *
     */
    get region(): string;
    /**
     *
     */
    set region(value: string);
    /**
     *
     */
    resetRegion(): void;
    /**
     *
     */
    get regionInput(): string | undefined;
    /**
     *
     */
    get selfLink(): string;
    private _nodeTypeFlexibility?;
    /**
     *
     */
    get nodeTypeFlexibility(): ComputeNodeTemplateNodeTypeFlexibility[];
    /**
     *
     */
    set nodeTypeFlexibility(value: ComputeNodeTemplateNodeTypeFlexibility[]);
    /**
     *
     */
    resetNodeTypeFlexibility(): void;
    /**
     *
     */
    get nodeTypeFlexibilityInput(): ComputeNodeTemplateNodeTypeFlexibility[] | undefined;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): ComputeNodeTemplateTimeouts;
    /**
     *
     */
    set timeouts(value: ComputeNodeTemplateTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): ComputeNodeTemplateTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
