import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface ComputeRegionDiskConfig extends TerraformMetaArguments {
    /**
     * An optional description of this resource.
     *
     * Provide this property when
     * you create the resource.
     */
    readonly description?: string;
    /**
     * Labels to apply to this disk.
     *
     * A list of key->value pairs.
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the resource.
     *
     * Provided by the client when the resource is
     * created. The name must be 1-63 characters long, and comply with
     * RFC1035. Specifically, the name must be 1-63 characters long and match
     * the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means the
     * first character must be a lowercase letter, and all following
     * characters must be a dash, lowercase letter, or digit, except the last
     * character, which cannot be a dash.
     */
    readonly name: string;
    /**
     * Physical block size of the persistent disk, in bytes.
     *
     * If not present
     * in a request, a default value is used. Currently supported sizes
     * are 4096 and 16384, other sizes may be added in the future.
     * If an unsupported value is requested, the error message will list
     * the supported values for the caller's project.
     */
    readonly physicalBlockSizeBytes?: number;
    /**
     *
     */
    readonly project?: string;
    /**
     * A reference to the region where the disk resides.
     */
    readonly region?: string;
    /**
     * URLs of the zones where the disk should be replicated to.
     */
    readonly replicaZones: string[];
    /**
     * Size of the persistent disk, specified in GB.
     *
     * You can specify this
     * field when creating a persistent disk using the sourceImage or
     * sourceSnapshot parameter, or specify it alone to create an empty
     * persistent disk.
     *
     * If you specify this field along with sourceImage or sourceSnapshot,
     * the value of sizeGb must not be less than the size of the sourceImage
     * or the size of the snapshot.
     */
    readonly size?: number;
    /**
     * The source snapshot used to create this disk.
     *
     * You can provide this as
     * a partial or full URL to the resource. For example, the following are
     * valid values:
     *
     * 'https://www.googleapis.com/compute/v1/projects/project/global/snapshots/snapshot'
     * 'projects/project/global/snapshots/snapshot'
     * 'global/snapshots/snapshot'
     * 'snapshot'
     */
    readonly snapshot?: string;
    /**
     * URL of the disk type resource describing which disk type to use to create the disk.
     *
     * Provide this when creating the disk.
     */
    readonly type?: string;
    /**
     * disk_encryption_key block.
     */
    readonly diskEncryptionKey?: ComputeRegionDiskDiskEncryptionKey[];
    /**
     * source_snapshot_encryption_key block.
     */
    readonly sourceSnapshotEncryptionKey?: ComputeRegionDiskSourceSnapshotEncryptionKey[];
    /**
     * timeouts block.
     */
    readonly timeouts?: ComputeRegionDiskTimeouts;
}
/**
 *
 */
export interface ComputeRegionDiskDiskEncryptionKey {
    /**
     * Specifies a 256-bit customer-supplied encryption key, encoded in RFC 4648 base64 to either encrypt or decrypt this resource.
     */
    readonly rawKey?: string;
}
/**
 *
 */
export interface ComputeRegionDiskSourceSnapshotEncryptionKey {
    /**
     * Specifies a 256-bit customer-supplied encryption key, encoded in RFC 4648 base64 to either encrypt or decrypt this resource.
     */
    readonly rawKey?: string;
}
/**
 *
 */
export interface ComputeRegionDiskTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class ComputeRegionDisk extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: ComputeRegionDiskConfig);
    /**
     *
     */
    get creationTimestamp(): string;
    private _description?;
    /**
     *
     */
    get description(): string;
    /**
     *
     */
    set description(value: string);
    /**
     *
     */
    resetDescription(): void;
    /**
     *
     */
    get descriptionInput(): string | undefined;
    /**
     *
     */
    get id(): string;
    /**
     *
     */
    get labelFingerprint(): string;
    private _labels?;
    /**
     *
     */
    get labels(): {
        [key: string]: string;
    };
    /**
     *
     */
    set labels(value: {
        [key: string]: string;
    });
    /**
     *
     */
    resetLabels(): void;
    /**
     *
     */
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    /**
     *
     */
    get lastAttachTimestamp(): string;
    /**
     *
     */
    get lastDetachTimestamp(): string;
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    get nameInput(): string;
    private _physicalBlockSizeBytes?;
    /**
     *
     */
    get physicalBlockSizeBytes(): number;
    /**
     *
     */
    set physicalBlockSizeBytes(value: number);
    /**
     *
     */
    resetPhysicalBlockSizeBytes(): void;
    /**
     *
     */
    get physicalBlockSizeBytesInput(): number | undefined;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _region?;
    /**
     *
     */
    get region(): string;
    /**
     *
     */
    set region(value: string);
    /**
     *
     */
    resetRegion(): void;
    /**
     *
     */
    get regionInput(): string | undefined;
    private _replicaZones;
    /**
     *
     */
    get replicaZones(): string[];
    /**
     *
     */
    set replicaZones(value: string[]);
    /**
     *
     */
    get replicaZonesInput(): string[];
    /**
     *
     */
    get selfLink(): string;
    private _size?;
    /**
     *
     */
    get size(): number;
    /**
     *
     */
    set size(value: number);
    /**
     *
     */
    resetSize(): void;
    /**
     *
     */
    get sizeInput(): number | undefined;
    private _snapshot?;
    /**
     *
     */
    get snapshot(): string;
    /**
     *
     */
    set snapshot(value: string);
    /**
     *
     */
    resetSnapshot(): void;
    /**
     *
     */
    get snapshotInput(): string | undefined;
    /**
     *
     */
    get sourceSnapshotId(): string;
    private _type?;
    /**
     *
     */
    get type(): string;
    /**
     *
     */
    set type(value: string);
    /**
     *
     */
    resetType(): void;
    /**
     *
     */
    get typeInput(): string | undefined;
    /**
     *
     */
    get users(): string[];
    private _diskEncryptionKey?;
    /**
     *
     */
    get diskEncryptionKey(): ComputeRegionDiskDiskEncryptionKey[];
    /**
     *
     */
    set diskEncryptionKey(value: ComputeRegionDiskDiskEncryptionKey[]);
    /**
     *
     */
    resetDiskEncryptionKey(): void;
    /**
     *
     */
    get diskEncryptionKeyInput(): ComputeRegionDiskDiskEncryptionKey[] | undefined;
    private _sourceSnapshotEncryptionKey?;
    /**
     *
     */
    get sourceSnapshotEncryptionKey(): ComputeRegionDiskSourceSnapshotEncryptionKey[];
    /**
     *
     */
    set sourceSnapshotEncryptionKey(value: ComputeRegionDiskSourceSnapshotEncryptionKey[]);
    /**
     *
     */
    resetSourceSnapshotEncryptionKey(): void;
    /**
     *
     */
    get sourceSnapshotEncryptionKeyInput(): ComputeRegionDiskSourceSnapshotEncryptionKey[] | undefined;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): ComputeRegionDiskTimeouts;
    /**
     *
     */
    set timeouts(value: ComputeRegionDiskTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): ComputeRegionDiskTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
