import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface ComputeResourcePolicyConfig extends TerraformMetaArguments {
    /**
     * The name of the resource, provided by the client when initially creating the resource.
     *
     * The resource name must be 1-63 characters long, and comply
     * with RFC1035. Specifically, the name must be 1-63 characters long and
     * match the regular expression '[a-z]([-a-z0-9]*[a-z0-9])'? which means the
     * first character must be a lowercase letter, and all following characters
     * must be a dash, lowercase letter, or digit, except the last character,
     * which cannot be a dash.
     */
    readonly name: string;
    /**
     *
     */
    readonly project?: string;
    /**
     * Region where resource policy resides.
     */
    readonly region?: string;
    /**
     * group_placement_policy block.
     */
    readonly groupPlacementPolicy?: ComputeResourcePolicyGroupPlacementPolicy[];
    /**
     * snapshot_schedule_policy block.
     */
    readonly snapshotSchedulePolicy?: ComputeResourcePolicySnapshotSchedulePolicy[];
    /**
     * timeouts block.
     */
    readonly timeouts?: ComputeResourcePolicyTimeouts;
}
/**
 *
 */
export interface ComputeResourcePolicyGroupPlacementPolicy {
    /**
     * The number of availability domains instances will be spread across.
     *
     * If two instances are in different
     * availability domain, they will not be put in the same low latency network
     */
    readonly availabilityDomainCount?: number;
    /**
     * Collocation specifies whether to place VMs inside the same availability domain on the same low-latency network.
     *
     * Specify 'COLLOCATED' to enable collocation. Can only be specified with 'vm_count'. If compute instances are created
     * with a COLLOCATED policy, then exactly 'vm_count' instances must be created at the same time with the resource policy
     * attached. Possible values: ["COLLOCATED"]
     */
    readonly collocation?: string;
    /**
     * Number of vms in this placement group.
     */
    readonly vmCount?: number;
}
/**
 *
 */
export interface ComputeResourcePolicySnapshotSchedulePolicyRetentionPolicy {
    /**
     * Maximum age of the snapshot that is allowed to be kept.
     */
    readonly maxRetentionDays: number;
    /**
     * Specifies the behavior to apply to scheduled snapshots when the source disk is deleted.
     *
     * Default value: "KEEP_AUTO_SNAPSHOTS" Possible values: ["KEEP_AUTO_SNAPSHOTS", "APPLY_RETENTION_POLICY"]
     */
    readonly onSourceDiskDelete?: string;
}
/**
 *
 */
export interface ComputeResourcePolicySnapshotSchedulePolicyScheduleDailySchedule {
    /**
     * The number of days between snapshots.
     */
    readonly daysInCycle: number;
    /**
     * This must be in UTC format that resolves to one of 00:00, 04:00, 08:00, 12:00, 16:00, or 20:00.
     *
     * For example,
     * both 13:00-5 and 08:00 are valid.
     */
    readonly startTime: string;
}
/**
 *
 */
export interface ComputeResourcePolicySnapshotSchedulePolicyScheduleHourlySchedule {
    /**
     * The number of hours between snapshots.
     */
    readonly hoursInCycle: number;
    /**
     * Time within the window to start the operations.
     *
     * It must be in an hourly format "HH:MM",
     * where HH : [00-23] and MM : [00] GMT.
     * eg: 21:00
     */
    readonly startTime: string;
}
/**
 *
 */
export interface ComputeResourcePolicySnapshotSchedulePolicyScheduleWeeklyScheduleDayOfWeeks {
    /**
     * The day of the week to create the snapshot.
     *
     * e.g. MONDAY Possible values: ["MONDAY", "TUESDAY", "WEDNESDAY", "THURSDAY", "FRIDAY", "SATURDAY", "SUNDAY"]
     */
    readonly day: string;
    /**
     * Time within the window to start the operations.
     *
     * It must be in format "HH:MM", where HH : [00-23] and MM : [00-00] GMT.
     */
    readonly startTime: string;
}
/**
 *
 */
export interface ComputeResourcePolicySnapshotSchedulePolicyScheduleWeeklySchedule {
    /**
     * day_of_weeks block.
     */
    readonly dayOfWeeks: ComputeResourcePolicySnapshotSchedulePolicyScheduleWeeklyScheduleDayOfWeeks[];
}
/**
 *
 */
export interface ComputeResourcePolicySnapshotSchedulePolicySchedule {
    /**
     * daily_schedule block.
     */
    readonly dailySchedule?: ComputeResourcePolicySnapshotSchedulePolicyScheduleDailySchedule[];
    /**
     * hourly_schedule block.
     */
    readonly hourlySchedule?: ComputeResourcePolicySnapshotSchedulePolicyScheduleHourlySchedule[];
    /**
     * weekly_schedule block.
     */
    readonly weeklySchedule?: ComputeResourcePolicySnapshotSchedulePolicyScheduleWeeklySchedule[];
}
/**
 *
 */
export interface ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties {
    /**
     * Whether to perform a 'guest aware' snapshot.
     */
    readonly guestFlush?: boolean;
    /**
     * A set of key-value pairs.
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Cloud Storage bucket location to store the auto snapshot (regional or multi-regional).
     */
    readonly storageLocations?: string[];
}
/**
 *
 */
export interface ComputeResourcePolicySnapshotSchedulePolicy {
    /**
     * retention_policy block.
     */
    readonly retentionPolicy?: ComputeResourcePolicySnapshotSchedulePolicyRetentionPolicy[];
    /**
     * schedule block.
     */
    readonly schedule: ComputeResourcePolicySnapshotSchedulePolicySchedule[];
    /**
     * snapshot_properties block.
     */
    readonly snapshotProperties?: ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties[];
}
/**
 *
 */
export interface ComputeResourcePolicyTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
}
/**
 *
 */
export declare class ComputeResourcePolicy extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: ComputeResourcePolicyConfig);
    /**
     *
     */
    get id(): string;
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    get nameInput(): string;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _region?;
    /**
     *
     */
    get region(): string;
    /**
     *
     */
    set region(value: string);
    /**
     *
     */
    resetRegion(): void;
    /**
     *
     */
    get regionInput(): string | undefined;
    /**
     *
     */
    get selfLink(): string;
    private _groupPlacementPolicy?;
    /**
     *
     */
    get groupPlacementPolicy(): ComputeResourcePolicyGroupPlacementPolicy[];
    /**
     *
     */
    set groupPlacementPolicy(value: ComputeResourcePolicyGroupPlacementPolicy[]);
    /**
     *
     */
    resetGroupPlacementPolicy(): void;
    /**
     *
     */
    get groupPlacementPolicyInput(): ComputeResourcePolicyGroupPlacementPolicy[] | undefined;
    private _snapshotSchedulePolicy?;
    /**
     *
     */
    get snapshotSchedulePolicy(): ComputeResourcePolicySnapshotSchedulePolicy[];
    /**
     *
     */
    set snapshotSchedulePolicy(value: ComputeResourcePolicySnapshotSchedulePolicy[]);
    /**
     *
     */
    resetSnapshotSchedulePolicy(): void;
    /**
     *
     */
    get snapshotSchedulePolicyInput(): ComputeResourcePolicySnapshotSchedulePolicy[] | undefined;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): ComputeResourcePolicyTimeouts;
    /**
     *
     */
    set timeouts(value: ComputeResourcePolicyTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): ComputeResourcePolicyTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
