import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface ComputeRouterInterfaceConfig extends TerraformMetaArguments {
    /**
     * The name or resource link to the VLAN interconnect for this interface.
     *
     * Changing this forces a new interface to be created. Only one of vpn_tunnel and interconnect_attachment can be specified.
     */
    readonly interconnectAttachment?: string;
    /**
     * IP address and range of the interface.
     *
     * The IP range must be in the RFC3927 link-local IP space. Changing this forces a new interface to be created.
     */
    readonly ipRange?: string;
    /**
     * A unique name for the interface, required by GCE.
     *
     * Changing this forces a new interface to be created.
     */
    readonly name: string;
    /**
     * The ID of the project in which this interface's router belongs.
     *
     * If it is not provided, the provider project is used. Changing this forces a new interface to be created.
     */
    readonly project?: string;
    /**
     * The region this interface's router sits in.
     *
     * If not specified, the project region will be used. Changing this forces a new interface to be created.
     */
    readonly region?: string;
    /**
     * The name of the router this interface will be attached to.
     *
     * Changing this forces a new interface to be created.
     */
    readonly router: string;
    /**
     * The name or resource link to the VPN tunnel this interface will be linked to.
     *
     * Changing this forces a new interface to be created. Only one of vpn_tunnel and interconnect_attachment can be specified.
     */
    readonly vpnTunnel?: string;
    /**
     * timeouts block.
     */
    readonly timeouts?: ComputeRouterInterfaceTimeouts;
}
/**
 *
 */
export interface ComputeRouterInterfaceTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
}
/**
 *
 */
export declare class ComputeRouterInterface extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: ComputeRouterInterfaceConfig);
    /**
     *
     */
    get id(): string;
    private _interconnectAttachment?;
    /**
     *
     */
    get interconnectAttachment(): string;
    /**
     *
     */
    set interconnectAttachment(value: string);
    /**
     *
     */
    resetInterconnectAttachment(): void;
    /**
     *
     */
    get interconnectAttachmentInput(): string | undefined;
    private _ipRange?;
    /**
     *
     */
    get ipRange(): string;
    /**
     *
     */
    set ipRange(value: string);
    /**
     *
     */
    resetIpRange(): void;
    /**
     *
     */
    get ipRangeInput(): string | undefined;
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    get nameInput(): string;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _region?;
    /**
     *
     */
    get region(): string;
    /**
     *
     */
    set region(value: string);
    /**
     *
     */
    resetRegion(): void;
    /**
     *
     */
    get regionInput(): string | undefined;
    private _router;
    /**
     *
     */
    get router(): string;
    /**
     *
     */
    set router(value: string);
    /**
     *
     */
    get routerInput(): string;
    private _vpnTunnel?;
    /**
     *
     */
    get vpnTunnel(): string;
    /**
     *
     */
    set vpnTunnel(value: string);
    /**
     *
     */
    resetVpnTunnel(): void;
    /**
     *
     */
    get vpnTunnelInput(): string | undefined;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): ComputeRouterInterfaceTimeouts;
    /**
     *
     */
    set timeouts(value: ComputeRouterInterfaceTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): ComputeRouterInterfaceTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
