import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface ComputeRouterPeerConfig extends TerraformMetaArguments {
    /**
     * User-specified flag to indicate which mode to use for advertisement.
     *
     * Valid values of this enum field are: 'DEFAULT', 'CUSTOM' Default value: "DEFAULT" Possible values: ["DEFAULT", "CUSTOM"]
     */
    readonly advertiseMode?: string;
    /**
     * User-specified list of prefix groups to advertise in custom mode, which can take one of the following options:.
     *
     * 'ALL_SUBNETS': Advertises all available subnets, including peer VPC subnets.
     * 'ALL_VPC_SUBNETS': Advertises the router's own VPC subnets.
     * 'ALL_PEER_VPC_SUBNETS': Advertises peer subnets of the router's VPC network.
     *
     *
     * Note that this field can only be populated if advertiseMode is 'CUSTOM'
     * and overrides the list defined for the router (in the "bgp" message).
     * These groups are advertised in addition to any specified prefixes.
     * Leave this field blank to advertise no custom groups.
     */
    readonly advertisedGroups?: string[];
    /**
     * The priority of routes advertised to this BGP peer.
     *
     * Where there is more than one matching route of maximum
     * length, the routes with the lowest priority value win.
     */
    readonly advertisedRoutePriority?: number;
    /**
     * Name of the interface the BGP peer is associated with.
     */
    readonly interface: string;
    /**
     * Name of this BGP peer.
     *
     * The name must be 1-63 characters long,
     * and comply with RFC1035. Specifically, the name must be 1-63 characters
     * long and match the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which
     * means the first character must be a lowercase letter, and all
     * following characters must be a dash, lowercase letter, or digit,
     * except the last character, which cannot be a dash.
     */
    readonly name: string;
    /**
     * Peer BGP Autonomous System Number (ASN).
     *
     * Each BGP interface may use a different value.
     */
    readonly peerAsn: number;
    /**
     * IP address of the BGP interface outside Google Cloud Platform.
     *
     * Only IPv4 is supported.
     */
    readonly peerIpAddress: string;
    /**
     *
     */
    readonly project?: string;
    /**
     * Region where the router and BgpPeer reside.
     *
     * If it is not provided, the provider region is used.
     */
    readonly region?: string;
    /**
     * The name of the Cloud Router in which this BgpPeer will be configured.
     */
    readonly router: string;
    /**
     * advertised_ip_ranges block.
     */
    readonly advertisedIpRanges?: ComputeRouterPeerAdvertisedIpRanges[];
    /**
     * timeouts block.
     */
    readonly timeouts?: ComputeRouterPeerTimeouts;
}
/**
 *
 */
export interface ComputeRouterPeerAdvertisedIpRanges {
    /**
     * User-specified description for the IP range.
     */
    readonly description?: string;
    /**
     * The IP range to advertise.
     *
     * The value must be a
     * CIDR-formatted string.
     */
    readonly range: string;
}
/**
 *
 */
export interface ComputeRouterPeerTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class ComputeRouterPeer extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: ComputeRouterPeerConfig);
    private _advertiseMode?;
    /**
     *
     */
    get advertiseMode(): string;
    /**
     *
     */
    set advertiseMode(value: string);
    /**
     *
     */
    resetAdvertiseMode(): void;
    /**
     *
     */
    get advertiseModeInput(): string | undefined;
    private _advertisedGroups?;
    /**
     *
     */
    get advertisedGroups(): string[];
    /**
     *
     */
    set advertisedGroups(value: string[]);
    /**
     *
     */
    resetAdvertisedGroups(): void;
    /**
     *
     */
    get advertisedGroupsInput(): string[] | undefined;
    private _advertisedRoutePriority?;
    /**
     *
     */
    get advertisedRoutePriority(): number;
    /**
     *
     */
    set advertisedRoutePriority(value: number);
    /**
     *
     */
    resetAdvertisedRoutePriority(): void;
    /**
     *
     */
    get advertisedRoutePriorityInput(): number | undefined;
    /**
     *
     */
    get id(): string;
    private _interface;
    /**
     *
     */
    get interface(): string;
    /**
     *
     */
    set interface(value: string);
    /**
     *
     */
    get interfaceInput(): string;
    /**
     *
     */
    get ipAddress(): string;
    /**
     *
     */
    get managementType(): string;
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    get nameInput(): string;
    private _peerAsn;
    /**
     *
     */
    get peerAsn(): number;
    /**
     *
     */
    set peerAsn(value: number);
    /**
     *
     */
    get peerAsnInput(): number;
    private _peerIpAddress;
    /**
     *
     */
    get peerIpAddress(): string;
    /**
     *
     */
    set peerIpAddress(value: string);
    /**
     *
     */
    get peerIpAddressInput(): string;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _region?;
    /**
     *
     */
    get region(): string;
    /**
     *
     */
    set region(value: string);
    /**
     *
     */
    resetRegion(): void;
    /**
     *
     */
    get regionInput(): string | undefined;
    private _router;
    /**
     *
     */
    get router(): string;
    /**
     *
     */
    set router(value: string);
    /**
     *
     */
    get routerInput(): string;
    private _advertisedIpRanges?;
    /**
     *
     */
    get advertisedIpRanges(): ComputeRouterPeerAdvertisedIpRanges[];
    /**
     *
     */
    set advertisedIpRanges(value: ComputeRouterPeerAdvertisedIpRanges[]);
    /**
     *
     */
    resetAdvertisedIpRanges(): void;
    /**
     *
     */
    get advertisedIpRangesInput(): ComputeRouterPeerAdvertisedIpRanges[] | undefined;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): ComputeRouterPeerTimeouts;
    /**
     *
     */
    set timeouts(value: ComputeRouterPeerTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): ComputeRouterPeerTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
