import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface ComputeSnapshotConfig extends TerraformMetaArguments {
    /**
     * An optional description of this resource.
     */
    readonly description?: string;
    /**
     * Labels to apply to this Snapshot.
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the resource;
     *
     * provided by the client when the resource is
     * created. The name must be 1-63 characters long, and comply with
     * RFC1035. Specifically, the name must be 1-63 characters long and match
     * the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means the
     * first character must be a lowercase letter, and all following
     * characters must be a dash, lowercase letter, or digit, except the last
     * character, which cannot be a dash.
     */
    readonly name: string;
    /**
     *
     */
    readonly project?: string;
    /**
     * A reference to the disk used to create this snapshot.
     */
    readonly sourceDisk: string;
    /**
     * Cloud Storage bucket storage location of the snapshot (regional or multi-regional).
     */
    readonly storageLocations?: string[];
    /**
     * A reference to the zone where the disk is hosted.
     */
    readonly zone?: string;
    /**
     * snapshot_encryption_key block.
     */
    readonly snapshotEncryptionKey?: ComputeSnapshotSnapshotEncryptionKey[];
    /**
     * source_disk_encryption_key block.
     */
    readonly sourceDiskEncryptionKey?: ComputeSnapshotSourceDiskEncryptionKey[];
    /**
     * timeouts block.
     */
    readonly timeouts?: ComputeSnapshotTimeouts;
}
/**
 *
 */
export interface ComputeSnapshotSnapshotEncryptionKey {
    /**
     * The name of the encryption key that is stored in Google Cloud KMS.
     */
    readonly kmsKeySelfLink?: string;
    /**
     * The service account used for the encryption request for the given KMS key.
     *
     * If absent, the Compute Engine Service Agent service account is used.
     */
    readonly kmsKeyServiceAccount?: string;
    /**
     * Specifies a 256-bit customer-supplied encryption key, encoded in RFC 4648 base64 to either encrypt or decrypt this resource.
     */
    readonly rawKey?: string;
}
/**
 *
 */
export interface ComputeSnapshotSourceDiskEncryptionKey {
    /**
     * The service account used for the encryption request for the given KMS key.
     *
     * If absent, the Compute Engine Service Agent service account is used.
     */
    readonly kmsKeyServiceAccount?: string;
    /**
     * Specifies a 256-bit customer-supplied encryption key, encoded in RFC 4648 base64 to either encrypt or decrypt this resource.
     */
    readonly rawKey?: string;
}
/**
 *
 */
export interface ComputeSnapshotTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class ComputeSnapshot extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: ComputeSnapshotConfig);
    /**
     *
     */
    get creationTimestamp(): string;
    private _description?;
    /**
     *
     */
    get description(): string;
    /**
     *
     */
    set description(value: string);
    /**
     *
     */
    resetDescription(): void;
    /**
     *
     */
    get descriptionInput(): string | undefined;
    /**
     *
     */
    get diskSizeGb(): number;
    /**
     *
     */
    get id(): string;
    /**
     *
     */
    get labelFingerprint(): string;
    private _labels?;
    /**
     *
     */
    get labels(): {
        [key: string]: string;
    };
    /**
     *
     */
    set labels(value: {
        [key: string]: string;
    });
    /**
     *
     */
    resetLabels(): void;
    /**
     *
     */
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    /**
     *
     */
    get licenses(): string[];
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    get nameInput(): string;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    /**
     *
     */
    get selfLink(): string;
    /**
     *
     */
    get snapshotId(): number;
    private _sourceDisk;
    /**
     *
     */
    get sourceDisk(): string;
    /**
     *
     */
    set sourceDisk(value: string);
    /**
     *
     */
    get sourceDiskInput(): string;
    /**
     *
     */
    get sourceDiskLink(): string;
    /**
     *
     */
    get storageBytes(): number;
    private _storageLocations?;
    /**
     *
     */
    get storageLocations(): string[];
    /**
     *
     */
    set storageLocations(value: string[]);
    /**
     *
     */
    resetStorageLocations(): void;
    /**
     *
     */
    get storageLocationsInput(): string[] | undefined;
    private _zone?;
    /**
     *
     */
    get zone(): string;
    /**
     *
     */
    set zone(value: string);
    /**
     *
     */
    resetZone(): void;
    /**
     *
     */
    get zoneInput(): string | undefined;
    private _snapshotEncryptionKey?;
    /**
     *
     */
    get snapshotEncryptionKey(): ComputeSnapshotSnapshotEncryptionKey[];
    /**
     *
     */
    set snapshotEncryptionKey(value: ComputeSnapshotSnapshotEncryptionKey[]);
    /**
     *
     */
    resetSnapshotEncryptionKey(): void;
    /**
     *
     */
    get snapshotEncryptionKeyInput(): ComputeSnapshotSnapshotEncryptionKey[] | undefined;
    private _sourceDiskEncryptionKey?;
    /**
     *
     */
    get sourceDiskEncryptionKey(): ComputeSnapshotSourceDiskEncryptionKey[];
    /**
     *
     */
    set sourceDiskEncryptionKey(value: ComputeSnapshotSourceDiskEncryptionKey[]);
    /**
     *
     */
    resetSourceDiskEncryptionKey(): void;
    /**
     *
     */
    get sourceDiskEncryptionKeyInput(): ComputeSnapshotSourceDiskEncryptionKey[] | undefined;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): ComputeSnapshotTimeouts;
    /**
     *
     */
    set timeouts(value: ComputeSnapshotTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): ComputeSnapshotTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
