import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface ComputeSslCertificateConfig extends TerraformMetaArguments {
    /**
     * The certificate in PEM format.
     *
     * The certificate chain must be no greater than 5 certs long.
     * The chain must include at least one intermediate cert.
     */
    readonly certificate: string;
    /**
     * An optional description of this resource.
     */
    readonly description?: string;
    /**
     * Name of the resource.
     *
     * Provided by the client when the resource is
     * created. The name must be 1-63 characters long, and comply with
     * RFC1035. Specifically, the name must be 1-63 characters long and match
     * the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means the
     * first character must be a lowercase letter, and all following
     * characters must be a dash, lowercase letter, or digit, except the last
     * character, which cannot be a dash.
     *
     *
     * These are in the same namespace as the managed SSL certificates.
     */
    readonly name?: string;
    /**
     *
     */
    readonly namePrefix?: string;
    /**
     * The write-only private key in PEM format.
     */
    readonly privateKey: string;
    /**
     *
     */
    readonly project?: string;
    /**
     * timeouts block.
     */
    readonly timeouts?: ComputeSslCertificateTimeouts;
}
/**
 *
 */
export interface ComputeSslCertificateTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
}
/**
 *
 */
export declare class ComputeSslCertificate extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: ComputeSslCertificateConfig);
    private _certificate;
    /**
     *
     */
    get certificate(): string;
    /**
     *
     */
    set certificate(value: string);
    /**
     *
     */
    get certificateInput(): string;
    /**
     *
     */
    get certificateId(): number;
    /**
     *
     */
    get creationTimestamp(): string;
    private _description?;
    /**
     *
     */
    get description(): string;
    /**
     *
     */
    set description(value: string);
    /**
     *
     */
    resetDescription(): void;
    /**
     *
     */
    get descriptionInput(): string | undefined;
    /**
     *
     */
    get id(): string;
    private _name?;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    resetName(): void;
    /**
     *
     */
    get nameInput(): string | undefined;
    private _namePrefix?;
    /**
     *
     */
    get namePrefix(): string;
    /**
     *
     */
    set namePrefix(value: string);
    /**
     *
     */
    resetNamePrefix(): void;
    /**
     *
     */
    get namePrefixInput(): string | undefined;
    private _privateKey;
    /**
     *
     */
    get privateKey(): string;
    /**
     *
     */
    set privateKey(value: string);
    /**
     *
     */
    get privateKeyInput(): string;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    /**
     *
     */
    get selfLink(): string;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): ComputeSslCertificateTimeouts;
    /**
     *
     */
    set timeouts(value: ComputeSslCertificateTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): ComputeSslCertificateTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
