import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface ComputeSubnetworkConfig extends TerraformMetaArguments {
    /**
     * An optional description of this resource.
     *
     * Provide this property when
     * you create the resource. This field can be set only at resource
     * creation time.
     */
    readonly description?: string;
    /**
     * The range of internal addresses that are owned by this subnetwork.
     *
     * Provide this property when you create the subnetwork. For example,
     * 10.0.0.0/8 or 192.168.0.0/16. Ranges must be unique and
     * non-overlapping within a network. Only IPv4 is supported.
     */
    readonly ipCidrRange: string;
    /**
     * The name of the resource, provided by the client when initially creating the resource.
     *
     * The name must be 1-63 characters long, and
     * comply with RFC1035. Specifically, the name must be 1-63 characters
     * long and match the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which
     * means the first character must be a lowercase letter, and all
     * following characters must be a dash, lowercase letter, or digit,
     * except the last character, which cannot be a dash.
     */
    readonly name: string;
    /**
     * The network this subnet belongs to.
     *
     * Only networks that are in the distributed mode can have subnetworks.
     */
    readonly network: string;
    /**
     * When enabled, VMs in this subnetwork without external IP addresses can access Google APIs and services by using Private Google Access.
     */
    readonly privateIpGoogleAccess?: boolean;
    /**
     * The private IPv6 google access type for the VMs in this subnet.
     */
    readonly privateIpv6GoogleAccess?: string;
    /**
     *
     */
    readonly project?: string;
    /**
     * The GCP region for this subnetwork.
     */
    readonly region?: string;
    /**
     * An array of configurations for secondary IP ranges for VM instances contained in this subnetwork.
     *
     * The primary IP of such VM must belong
     * to the primary ipCidrRange of the subnetwork. The alias IPs may belong
     * to either primary or secondary ranges.
     *
     * *Note**: This field uses [attr-as-block mode](https://www.terraform.io/docs/configuration/attr-as-blocks.html) to avoid
     * breaking users during the 0.12 upgrade. To explicitly send a list
     * of zero objects you must use the following syntax:
     * 'example=[]'
     * For more details about this behavior, see [this section](https://www.terraform.io/docs/configuration/attr-as-blocks.html#defining-a-fixed-object-collection-value).
     */
    readonly secondaryIpRange?: ComputeSubnetworkSecondaryIpRange[];
    /**
     * log_config block.
     */
    readonly logConfig?: ComputeSubnetworkLogConfig[];
    /**
     * timeouts block.
     */
    readonly timeouts?: ComputeSubnetworkTimeouts;
}
/**
 *
 */
export interface ComputeSubnetworkSecondaryIpRange {
    /**
     *
     */
    readonly ipCidrRange?: string;
    /**
     *
     */
    readonly rangeName?: string;
}
/**
 *
 */
export interface ComputeSubnetworkLogConfig {
    /**
     * Can only be specified if VPC flow logging for this subnetwork is enabled.
     *
     * Toggles the aggregation interval for collecting flow logs. Increasing the
     * interval time will reduce the amount of generated flow logs for long
     * lasting connections. Default is an interval of 5 seconds per connection. Default value: "INTERVAL_5_SEC" Possible values: ["INTERVAL_5_SEC", "INTERVAL_30_SEC", "INTERVAL_1_MIN", "INTERVAL_5_MIN", "INTERVAL_10_MIN", "INTERVAL_15_MIN"]
     */
    readonly aggregationInterval?: string;
    /**
     * Export filter used to define which VPC flow logs should be logged, as as CEL expression.
     *
     * See
     * https://cloud.google.com/vpc/docs/flow-logs#filtering for details on how to format this field.
     * The default value is 'true', which evaluates to include everything.
     */
    readonly filterExpr?: string;
    /**
     * Can only be specified if VPC flow logging for this subnetwork is enabled.
     *
     * The value of the field must be in [0, 1]. Set the sampling rate of VPC
     * flow logs within the subnetwork where 1.0 means all collected logs are
     * reported and 0.0 means no logs are reported. Default is 0.5 which means
     * half of all collected logs are reported.
     */
    readonly flowSampling?: number;
    /**
     * Can only be specified if VPC flow logging for this subnetwork is enabled.
     *
     * Configures whether metadata fields should be added to the reported VPC
     * flow logs. Default value: "INCLUDE_ALL_METADATA" Possible values: ["EXCLUDE_ALL_METADATA", "INCLUDE_ALL_METADATA", "CUSTOM_METADATA"]
     */
    readonly metadata?: string;
    /**
     * List of metadata fields that should be added to reported logs.
     *
     * Can only be specified if VPC flow logs for this subnetwork is enabled and "metadata" is set to CUSTOM_METADATA.
     */
    readonly metadataFields?: string[];
}
/**
 *
 */
export interface ComputeSubnetworkTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class ComputeSubnetwork extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: ComputeSubnetworkConfig);
    /**
     *
     */
    get creationTimestamp(): string;
    private _description?;
    /**
     *
     */
    get description(): string;
    /**
     *
     */
    set description(value: string);
    /**
     *
     */
    resetDescription(): void;
    /**
     *
     */
    get descriptionInput(): string | undefined;
    /**
     *
     */
    get fingerprint(): string;
    /**
     *
     */
    get gatewayAddress(): string;
    /**
     *
     */
    get id(): string;
    private _ipCidrRange;
    /**
     *
     */
    get ipCidrRange(): string;
    /**
     *
     */
    set ipCidrRange(value: string);
    /**
     *
     */
    get ipCidrRangeInput(): string;
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    get nameInput(): string;
    private _network;
    /**
     *
     */
    get network(): string;
    /**
     *
     */
    set network(value: string);
    /**
     *
     */
    get networkInput(): string;
    private _privateIpGoogleAccess?;
    /**
     *
     */
    get privateIpGoogleAccess(): boolean;
    /**
     *
     */
    set privateIpGoogleAccess(value: boolean);
    /**
     *
     */
    resetPrivateIpGoogleAccess(): void;
    /**
     *
     */
    get privateIpGoogleAccessInput(): boolean | undefined;
    private _privateIpv6GoogleAccess?;
    /**
     *
     */
    get privateIpv6GoogleAccess(): string;
    /**
     *
     */
    set privateIpv6GoogleAccess(value: string);
    /**
     *
     */
    resetPrivateIpv6GoogleAccess(): void;
    /**
     *
     */
    get privateIpv6GoogleAccessInput(): string | undefined;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _region?;
    /**
     *
     */
    get region(): string;
    /**
     *
     */
    set region(value: string);
    /**
     *
     */
    resetRegion(): void;
    /**
     *
     */
    get regionInput(): string | undefined;
    private _secondaryIpRange?;
    /**
     *
     */
    get secondaryIpRange(): ComputeSubnetworkSecondaryIpRange[];
    /**
     *
     */
    set secondaryIpRange(value: ComputeSubnetworkSecondaryIpRange[]);
    /**
     *
     */
    resetSecondaryIpRange(): void;
    /**
     *
     */
    get secondaryIpRangeInput(): ComputeSubnetworkSecondaryIpRange[] | undefined;
    /**
     *
     */
    get selfLink(): string;
    private _logConfig?;
    /**
     *
     */
    get logConfig(): ComputeSubnetworkLogConfig[];
    /**
     *
     */
    set logConfig(value: ComputeSubnetworkLogConfig[]);
    /**
     *
     */
    resetLogConfig(): void;
    /**
     *
     */
    get logConfigInput(): ComputeSubnetworkLogConfig[] | undefined;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): ComputeSubnetworkTimeouts;
    /**
     *
     */
    set timeouts(value: ComputeSubnetworkTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): ComputeSubnetworkTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
