import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface ComputeTargetSslProxyConfig extends TerraformMetaArguments {
    /**
     * A reference to the BackendService resource.
     */
    readonly backendService: string;
    /**
     * An optional description of this resource.
     */
    readonly description?: string;
    /**
     * Name of the resource.
     *
     * Provided by the client when the resource is
     * created. The name must be 1-63 characters long, and comply with
     * RFC1035. Specifically, the name must be 1-63 characters long and match
     * the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means the
     * first character must be a lowercase letter, and all following
     * characters must be a dash, lowercase letter, or digit, except the last
     * character, which cannot be a dash.
     */
    readonly name: string;
    /**
     *
     */
    readonly project?: string;
    /**
     * Specifies the type of proxy header to append before sending data to the backend.
     *
     * Default value: "NONE" Possible values: ["NONE", "PROXY_V1"]
     */
    readonly proxyHeader?: string;
    /**
     * A list of SslCertificate resources that are used to authenticate connections between users and the load balancer.
     *
     * Currently, exactly
     * one SSL certificate must be specified.
     */
    readonly sslCertificates: string[];
    /**
     * A reference to the SslPolicy resource that will be associated with the TargetSslProxy resource.
     *
     * If not set, the TargetSslProxy
     * resource will not have any SSL policy configured.
     */
    readonly sslPolicy?: string;
    /**
     * timeouts block.
     */
    readonly timeouts?: ComputeTargetSslProxyTimeouts;
}
/**
 *
 */
export interface ComputeTargetSslProxyTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class ComputeTargetSslProxy extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: ComputeTargetSslProxyConfig);
    private _backendService;
    /**
     *
     */
    get backendService(): string;
    /**
     *
     */
    set backendService(value: string);
    /**
     *
     */
    get backendServiceInput(): string;
    /**
     *
     */
    get creationTimestamp(): string;
    private _description?;
    /**
     *
     */
    get description(): string;
    /**
     *
     */
    set description(value: string);
    /**
     *
     */
    resetDescription(): void;
    /**
     *
     */
    get descriptionInput(): string | undefined;
    /**
     *
     */
    get id(): string;
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    get nameInput(): string;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _proxyHeader?;
    /**
     *
     */
    get proxyHeader(): string;
    /**
     *
     */
    set proxyHeader(value: string);
    /**
     *
     */
    resetProxyHeader(): void;
    /**
     *
     */
    get proxyHeaderInput(): string | undefined;
    /**
     *
     */
    get proxyId(): number;
    /**
     *
     */
    get selfLink(): string;
    private _sslCertificates;
    /**
     *
     */
    get sslCertificates(): string[];
    /**
     *
     */
    set sslCertificates(value: string[]);
    /**
     *
     */
    get sslCertificatesInput(): string[];
    private _sslPolicy?;
    /**
     *
     */
    get sslPolicy(): string;
    /**
     *
     */
    set sslPolicy(value: string);
    /**
     *
     */
    resetSslPolicy(): void;
    /**
     *
     */
    get sslPolicyInput(): string | undefined;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): ComputeTargetSslProxyTimeouts;
    /**
     *
     */
    set timeouts(value: ComputeTargetSslProxyTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): ComputeTargetSslProxyTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
