import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface ContainerAnalysisNoteConfig extends TerraformMetaArguments {
    /**
     * Time of expiration for this note.
     *
     * Leave empty if note does not expire.
     */
    readonly expirationTime?: string;
    /**
     * A detailed description of the note.
     */
    readonly longDescription?: string;
    /**
     * The name of the note.
     */
    readonly name: string;
    /**
     *
     */
    readonly project?: string;
    /**
     * Names of other notes related to this note.
     */
    readonly relatedNoteNames?: string[];
    /**
     * A one sentence description of the note.
     */
    readonly shortDescription?: string;
    /**
     * attestation_authority block.
     */
    readonly attestationAuthority: ContainerAnalysisNoteAttestationAuthority[];
    /**
     * related_url block.
     */
    readonly relatedUrl?: ContainerAnalysisNoteRelatedUrl[];
    /**
     * timeouts block.
     */
    readonly timeouts?: ContainerAnalysisNoteTimeouts;
}
/**
 *
 */
export interface ContainerAnalysisNoteAttestationAuthorityHint {
    /**
     * The human readable name of this Attestation Authority, for example "qa".
     */
    readonly humanReadableName: string;
}
/**
 *
 */
export interface ContainerAnalysisNoteAttestationAuthority {
    /**
     * hint block.
     */
    readonly hint: ContainerAnalysisNoteAttestationAuthorityHint[];
}
/**
 *
 */
export interface ContainerAnalysisNoteRelatedUrl {
    /**
     * Label to describe usage of the URL.
     */
    readonly label?: string;
    /**
     * Specific URL associated with the resource.
     */
    readonly url: string;
}
/**
 *
 */
export interface ContainerAnalysisNoteTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class ContainerAnalysisNote extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: ContainerAnalysisNoteConfig);
    /**
     *
     */
    get createTime(): string;
    private _expirationTime?;
    /**
     *
     */
    get expirationTime(): string;
    /**
     *
     */
    set expirationTime(value: string);
    /**
     *
     */
    resetExpirationTime(): void;
    /**
     *
     */
    get expirationTimeInput(): string | undefined;
    /**
     *
     */
    get id(): string;
    /**
     *
     */
    get kind(): string;
    private _longDescription?;
    /**
     *
     */
    get longDescription(): string;
    /**
     *
     */
    set longDescription(value: string);
    /**
     *
     */
    resetLongDescription(): void;
    /**
     *
     */
    get longDescriptionInput(): string | undefined;
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    get nameInput(): string;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _relatedNoteNames?;
    /**
     *
     */
    get relatedNoteNames(): string[];
    /**
     *
     */
    set relatedNoteNames(value: string[]);
    /**
     *
     */
    resetRelatedNoteNames(): void;
    /**
     *
     */
    get relatedNoteNamesInput(): string[] | undefined;
    private _shortDescription?;
    /**
     *
     */
    get shortDescription(): string;
    /**
     *
     */
    set shortDescription(value: string);
    /**
     *
     */
    resetShortDescription(): void;
    /**
     *
     */
    get shortDescriptionInput(): string | undefined;
    /**
     *
     */
    get updateTime(): string;
    private _attestationAuthority;
    /**
     *
     */
    get attestationAuthority(): ContainerAnalysisNoteAttestationAuthority[];
    /**
     *
     */
    set attestationAuthority(value: ContainerAnalysisNoteAttestationAuthority[]);
    /**
     *
     */
    get attestationAuthorityInput(): ContainerAnalysisNoteAttestationAuthority[];
    private _relatedUrl?;
    /**
     *
     */
    get relatedUrl(): ContainerAnalysisNoteRelatedUrl[];
    /**
     *
     */
    set relatedUrl(value: ContainerAnalysisNoteRelatedUrl[]);
    /**
     *
     */
    resetRelatedUrl(): void;
    /**
     *
     */
    get relatedUrlInput(): ContainerAnalysisNoteRelatedUrl[] | undefined;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): ContainerAnalysisNoteTimeouts;
    /**
     *
     */
    set timeouts(value: ContainerAnalysisNoteTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): ContainerAnalysisNoteTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
