import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface ContainerAnalysisOccurrenceConfig extends TerraformMetaArguments {
    /**
     * The analysis note associated with this occurrence, in the form of projects/[PROJECT]/notes/[NOTE_ID].
     *
     * This field can be used as a
     * filter in list requests.
     */
    readonly noteName: string;
    /**
     *
     */
    readonly project?: string;
    /**
     * A description of actions that can be taken to remedy the note.
     */
    readonly remediation?: string;
    /**
     * Required.
     *
     * Immutable. A URI that represents the resource for which
     * the occurrence applies. For example,
     * https://gcr.io/project/image@sha256:123abc for a Docker image.
     */
    readonly resourceUri: string;
    /**
     * attestation block.
     */
    readonly attestation: ContainerAnalysisOccurrenceAttestation[];
    /**
     * timeouts block.
     */
    readonly timeouts?: ContainerAnalysisOccurrenceTimeouts;
}
/**
 *
 */
export interface ContainerAnalysisOccurrenceAttestationSignatures {
    /**
     * The identifier for the public key that verifies this signature.
     *
     * MUST be an RFC3986 conformant
     * URI. * When possible, the key id should be an
     * immutable reference, such as a cryptographic digest.
     * Examples of valid values:
     *
     * OpenPGP V4 public key fingerprint. See https://www.iana.org/assignments/uri-schemes/prov/openpgp4fpr
     * for more details on this scheme.
     * 'openpgp4fpr:74FAF3B861BDA0870C7B6DEF607E48D2A663AEEA'
     * RFC6920 digest-named SubjectPublicKeyInfo (digest of the DER serialization):
     * "ni:///sha-256;cD9o9Cq6LG3jD0iKXqEi_vdjJGecm_iXkbqVoScViaU"
     */
    readonly publicKeyId: string;
    /**
     * The content of the signature, an opaque bytestring.
     *
     * The payload that this signature verifies MUST be
     * unambiguously provided with the Signature during
     * verification. A wrapper message might provide the
     * payload explicitly. Alternatively, a message might
     * have a canonical serialization that can always be
     * unambiguously computed to derive the payload.
     */
    readonly signature?: string;
}
/**
 *
 */
export interface ContainerAnalysisOccurrenceAttestation {
    /**
     * The serialized payload that is verified by one or more signatures.
     *
     * A base64-encoded string.
     */
    readonly serializedPayload: string;
    /**
     * signatures block.
     */
    readonly signatures: ContainerAnalysisOccurrenceAttestationSignatures[];
}
/**
 *
 */
export interface ContainerAnalysisOccurrenceTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class ContainerAnalysisOccurrence extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: ContainerAnalysisOccurrenceConfig);
    /**
     *
     */
    get createTime(): string;
    /**
     *
     */
    get id(): string;
    /**
     *
     */
    get kind(): string;
    /**
     *
     */
    get name(): string;
    private _noteName;
    /**
     *
     */
    get noteName(): string;
    /**
     *
     */
    set noteName(value: string);
    /**
     *
     */
    get noteNameInput(): string;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _remediation?;
    /**
     *
     */
    get remediation(): string;
    /**
     *
     */
    set remediation(value: string);
    /**
     *
     */
    resetRemediation(): void;
    /**
     *
     */
    get remediationInput(): string | undefined;
    private _resourceUri;
    /**
     *
     */
    get resourceUri(): string;
    /**
     *
     */
    set resourceUri(value: string);
    /**
     *
     */
    get resourceUriInput(): string;
    /**
     *
     */
    get updateTime(): string;
    private _attestation;
    /**
     *
     */
    get attestation(): ContainerAnalysisOccurrenceAttestation[];
    /**
     *
     */
    set attestation(value: ContainerAnalysisOccurrenceAttestation[]);
    /**
     *
     */
    get attestationInput(): ContainerAnalysisOccurrenceAttestation[];
    private _timeouts?;
    /**
     *
     */
    get timeouts(): ContainerAnalysisOccurrenceTimeouts;
    /**
     *
     */
    set timeouts(value: ContainerAnalysisOccurrenceTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): ContainerAnalysisOccurrenceTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
