import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface DataCatalogTagTemplateConfig extends TerraformMetaArguments {
    /**
     * The display name for this template.
     */
    readonly displayName?: string;
    /**
     * This confirms the deletion of any possible tags using this template.
     *
     * Must be set to true in order to delete the tag template.
     */
    readonly forceDelete?: boolean;
    /**
     *
     */
    readonly project?: string;
    /**
     * Template location region.
     */
    readonly region?: string;
    /**
     * The id of the tag template to create.
     */
    readonly tagTemplateId: string;
    /**
     * fields block.
     */
    readonly fields: DataCatalogTagTemplateFields[];
    /**
     * timeouts block.
     */
    readonly timeouts?: DataCatalogTagTemplateTimeouts;
}
/**
 *
 */
export interface DataCatalogTagTemplateFieldsTypeEnumTypeAllowedValues {
    /**
     * The display name of the enum value.
     */
    readonly displayName: string;
}
/**
 *
 */
export interface DataCatalogTagTemplateFieldsTypeEnumType {
    /**
     * allowed_values block.
     */
    readonly allowedValues: DataCatalogTagTemplateFieldsTypeEnumTypeAllowedValues[];
}
/**
 *
 */
export interface DataCatalogTagTemplateFieldsType {
    /**
     * Represents primitive types - string, bool etc.
     *
     * Exactly one of 'primitive_type' or 'enum_type' must be set Possible values: ["DOUBLE", "STRING", "BOOL", "TIMESTAMP"]
     */
    readonly primitiveType?: string;
    /**
     * enum_type block.
     */
    readonly enumType?: DataCatalogTagTemplateFieldsTypeEnumType[];
}
/**
 *
 */
export interface DataCatalogTagTemplateFields {
    /**
     * The display name for this field.
     */
    readonly displayName?: string;
    /**
     *
     */
    readonly fieldId: string;
    /**
     * Whether this is a required field.
     *
     * Defaults to false.
     */
    readonly isRequired?: boolean;
    /**
     * The order of this field with respect to other fields in this tag template.
     *
     * A higher value indicates a more important field. The value can be negative.
     * Multiple fields can have the same order, and field orders within a tag do not have to be sequential.
     */
    readonly order?: number;
    /**
     * type block.
     */
    readonly type: DataCatalogTagTemplateFieldsType[];
}
/**
 *
 */
export interface DataCatalogTagTemplateTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class DataCatalogTagTemplate extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: DataCatalogTagTemplateConfig);
    private _displayName?;
    /**
     *
     */
    get displayName(): string;
    /**
     *
     */
    set displayName(value: string);
    /**
     *
     */
    resetDisplayName(): void;
    /**
     *
     */
    get displayNameInput(): string | undefined;
    private _forceDelete?;
    /**
     *
     */
    get forceDelete(): boolean;
    /**
     *
     */
    set forceDelete(value: boolean);
    /**
     *
     */
    resetForceDelete(): void;
    /**
     *
     */
    get forceDeleteInput(): boolean | undefined;
    /**
     *
     */
    get id(): string;
    /**
     *
     */
    get name(): string;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _region?;
    /**
     *
     */
    get region(): string;
    /**
     *
     */
    set region(value: string);
    /**
     *
     */
    resetRegion(): void;
    /**
     *
     */
    get regionInput(): string | undefined;
    private _tagTemplateId;
    /**
     *
     */
    get tagTemplateId(): string;
    /**
     *
     */
    set tagTemplateId(value: string);
    /**
     *
     */
    get tagTemplateIdInput(): string;
    private _fields;
    /**
     *
     */
    get fields(): DataCatalogTagTemplateFields[];
    /**
     *
     */
    set fields(value: DataCatalogTagTemplateFields[]);
    /**
     *
     */
    get fieldsInput(): DataCatalogTagTemplateFields[];
    private _timeouts?;
    /**
     *
     */
    get timeouts(): DataCatalogTagTemplateTimeouts;
    /**
     *
     */
    set timeouts(value: DataCatalogTagTemplateTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): DataCatalogTagTemplateTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
