import { Construct } from 'constructs';
import { TerraformDataSource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
import { ComplexComputedList } from "cdktf";
/**
 *
 */
export interface DataGoogleCloudRunServiceConfig extends TerraformMetaArguments {
    /**
     * The location of the cloud run instance.
     *
     * eg us-central1
     */
    readonly location: string;
    /**
     * Name must be unique within a namespace, within a Cloud Run region.
     *
     * Is required when creating resources. Name is primarily intended
     * for creation idempotence and configuration definition. Cannot be updated.
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name: string;
    /**
     *
     */
    readonly project?: string;
}
/**
 *
 */
export declare class DataGoogleCloudRunServiceMetadata extends ComplexComputedList {
    /**
     *
     */
    get annotations(): any;
    /**
     *
     */
    get generation(): number;
    /**
     *
     */
    get labels(): any;
    /**
     *
     */
    get namespace(): string;
    /**
     *
     */
    get resourceVersion(): string;
    /**
     *
     */
    get selfLink(): string;
    /**
     *
     */
    get uid(): string;
}
/**
 *
 */
export declare class DataGoogleCloudRunServiceStatusConditions extends ComplexComputedList {
    /**
     *
     */
    get message(): string;
    /**
     *
     */
    get reason(): string;
    /**
     *
     */
    get status(): string;
    /**
     *
     */
    get type(): string;
}
/**
 *
 */
export declare class DataGoogleCloudRunServiceStatus extends ComplexComputedList {
    /**
     *
     */
    get conditions(): any;
    /**
     *
     */
    get latestCreatedRevisionName(): string;
    /**
     *
     */
    get latestReadyRevisionName(): string;
    /**
     *
     */
    get observedGeneration(): number;
    /**
     *
     */
    get url(): string;
}
/**
 *
 */
export declare class DataGoogleCloudRunServiceTemplateMetadata extends ComplexComputedList {
    /**
     *
     */
    get annotations(): any;
    /**
     *
     */
    get generation(): number;
    /**
     *
     */
    get labels(): any;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    get namespace(): string;
    /**
     *
     */
    get resourceVersion(): string;
    /**
     *
     */
    get selfLink(): string;
    /**
     *
     */
    get uid(): string;
}
/**
 *
 */
export declare class DataGoogleCloudRunServiceTemplateSpecContainersEnv extends ComplexComputedList {
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    get value(): string;
}
/**
 *
 */
export declare class DataGoogleCloudRunServiceTemplateSpecContainersEnvFromConfigMapRefLocalObjectReference extends ComplexComputedList {
    /**
     *
     */
    get name(): string;
}
/**
 *
 */
export declare class DataGoogleCloudRunServiceTemplateSpecContainersEnvFromConfigMapRef extends ComplexComputedList {
    /**
     *
     */
    get localObjectReference(): any;
    /**
     *
     */
    get optional(): boolean;
}
/**
 *
 */
export declare class DataGoogleCloudRunServiceTemplateSpecContainersEnvFromSecretRefLocalObjectReference extends ComplexComputedList {
    /**
     *
     */
    get name(): string;
}
/**
 *
 */
export declare class DataGoogleCloudRunServiceTemplateSpecContainersEnvFromSecretRef extends ComplexComputedList {
    /**
     *
     */
    get localObjectReference(): any;
    /**
     *
     */
    get optional(): boolean;
}
/**
 *
 */
export declare class DataGoogleCloudRunServiceTemplateSpecContainersEnvFrom extends ComplexComputedList {
    /**
     *
     */
    get configMapRef(): any;
    /**
     *
     */
    get prefix(): string;
    /**
     *
     */
    get secretRef(): any;
}
/**
 *
 */
export declare class DataGoogleCloudRunServiceTemplateSpecContainersPorts extends ComplexComputedList {
    /**
     *
     */
    get containerPort(): number;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    get protocol(): string;
}
/**
 *
 */
export declare class DataGoogleCloudRunServiceTemplateSpecContainersResources extends ComplexComputedList {
    /**
     *
     */
    get limits(): any;
    /**
     *
     */
    get requests(): any;
}
/**
 *
 */
export declare class DataGoogleCloudRunServiceTemplateSpecContainers extends ComplexComputedList {
    /**
     *
     */
    get args(): string[];
    /**
     *
     */
    get command(): string[];
    /**
     *
     */
    get env(): any;
    /**
     *
     */
    get envFrom(): any;
    /**
     *
     */
    get image(): string;
    /**
     *
     */
    get ports(): any;
    /**
     *
     */
    get resources(): any;
    /**
     *
     */
    get workingDir(): string;
}
/**
 *
 */
export declare class DataGoogleCloudRunServiceTemplateSpec extends ComplexComputedList {
    /**
     *
     */
    get containerConcurrency(): number;
    /**
     *
     */
    get containers(): any;
    /**
     *
     */
    get serviceAccountName(): string;
    /**
     *
     */
    get servingState(): string;
    /**
     *
     */
    get timeoutSeconds(): number;
}
/**
 *
 */
export declare class DataGoogleCloudRunServiceTemplate extends ComplexComputedList {
    /**
     *
     */
    get metadata(): any;
    /**
     *
     */
    get spec(): any;
}
/**
 *
 */
export declare class DataGoogleCloudRunServiceTraffic extends ComplexComputedList {
    /**
     *
     */
    get latestRevision(): boolean;
    /**
     *
     */
    get percent(): number;
    /**
     *
     */
    get revisionName(): string;
}
/**
 *
 */
export declare class DataGoogleCloudRunService extends TerraformDataSource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: DataGoogleCloudRunServiceConfig);
    /**
     *
     */
    get autogenerateRevisionName(): boolean;
    /**
     *
     */
    get id(): string;
    private _location;
    /**
     *
     */
    get location(): string;
    /**
     *
     */
    set location(value: string);
    /**
     *
     */
    get locationInput(): string;
    /**
     *
     */
    metadata(index: string): DataGoogleCloudRunServiceMetadata;
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    get nameInput(): string;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    /**
     *
     */
    status(index: string): DataGoogleCloudRunServiceStatus;
    /**
     *
     */
    template(index: string): DataGoogleCloudRunServiceTemplate;
    /**
     *
     */
    traffic(index: string): DataGoogleCloudRunServiceTraffic;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
