import { Construct } from 'constructs';
import { TerraformDataSource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
import { ComplexComputedList } from "cdktf";
/**
 *
 */
export interface DataGoogleComputeInstanceConfig extends TerraformMetaArguments {
    /**
     * The name of the instance.
     *
     * One of name or self_link must be provided.
     */
    readonly name?: string;
    /**
     * The ID of the project in which the resource belongs.
     *
     * If self_link is provided, this value is ignored. If neither self_link nor project are provided, the provider project is used.
     */
    readonly project?: string;
    /**
     * The URI of the created resource.
     */
    readonly selfLink?: string;
    /**
     * The zone of the instance.
     *
     * If self_link is provided, this value is ignored. If neither self_link nor zone are provided, the provider zone is used.
     */
    readonly zone?: string;
}
/**
 *
 */
export declare class DataGoogleComputeInstanceAttachedDisk extends ComplexComputedList {
    /**
     *
     */
    get deviceName(): string;
    /**
     *
     */
    get diskEncryptionKeyRaw(): string;
    /**
     *
     */
    get diskEncryptionKeySha256(): string;
    /**
     *
     */
    get kmsKeySelfLink(): string;
    /**
     *
     */
    get mode(): string;
    /**
     *
     */
    get source(): string;
}
/**
 *
 */
export declare class DataGoogleComputeInstanceBootDiskInitializeParams extends ComplexComputedList {
    /**
     *
     */
    get image(): string;
    /**
     *
     */
    get labels(): any;
    /**
     *
     */
    get size(): number;
    /**
     *
     */
    get type(): string;
}
/**
 *
 */
export declare class DataGoogleComputeInstanceBootDisk extends ComplexComputedList {
    /**
     *
     */
    get autoDelete(): boolean;
    /**
     *
     */
    get deviceName(): string;
    /**
     *
     */
    get diskEncryptionKeyRaw(): string;
    /**
     *
     */
    get diskEncryptionKeySha256(): string;
    /**
     *
     */
    get initializeParams(): any;
    /**
     *
     */
    get kmsKeySelfLink(): string;
    /**
     *
     */
    get mode(): string;
    /**
     *
     */
    get source(): string;
}
/**
 *
 */
export declare class DataGoogleComputeInstanceGuestAccelerator extends ComplexComputedList {
    /**
     *
     */
    get count(): number;
    /**
     *
     */
    get type(): string;
}
/**
 *
 */
export declare class DataGoogleComputeInstanceNetworkInterfaceAccessConfig extends ComplexComputedList {
    /**
     *
     */
    get natIp(): string;
    /**
     *
     */
    get networkTier(): string;
    /**
     *
     */
    get publicPtrDomainName(): string;
}
/**
 *
 */
export declare class DataGoogleComputeInstanceNetworkInterfaceAliasIpRange extends ComplexComputedList {
    /**
     *
     */
    get ipCidrRange(): string;
    /**
     *
     */
    get subnetworkRangeName(): string;
}
/**
 *
 */
export declare class DataGoogleComputeInstanceNetworkInterface extends ComplexComputedList {
    /**
     *
     */
    get accessConfig(): any;
    /**
     *
     */
    get aliasIpRange(): any;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    get network(): string;
    /**
     *
     */
    get networkIp(): string;
    /**
     *
     */
    get subnetwork(): string;
    /**
     *
     */
    get subnetworkProject(): string;
}
/**
 *
 */
export declare class DataGoogleComputeInstanceSchedulingNodeAffinities extends ComplexComputedList {
    /**
     *
     */
    get key(): string;
    /**
     *
     */
    get operator(): string;
    /**
     *
     */
    get values(): string[];
}
/**
 *
 */
export declare class DataGoogleComputeInstanceScheduling extends ComplexComputedList {
    /**
     *
     */
    get automaticRestart(): boolean;
    /**
     *
     */
    get nodeAffinities(): any;
    /**
     *
     */
    get onHostMaintenance(): string;
    /**
     *
     */
    get preemptible(): boolean;
}
/**
 *
 */
export declare class DataGoogleComputeInstanceScratchDisk extends ComplexComputedList {
    /**
     *
     */
    get interface(): string;
}
/**
 *
 */
export declare class DataGoogleComputeInstanceServiceAccount extends ComplexComputedList {
    /**
     *
     */
    get email(): string;
    /**
     *
     */
    get scopes(): string[];
}
/**
 *
 */
export declare class DataGoogleComputeInstanceShieldedInstanceConfig extends ComplexComputedList {
    /**
     *
     */
    get enableIntegrityMonitoring(): boolean;
    /**
     *
     */
    get enableSecureBoot(): boolean;
    /**
     *
     */
    get enableVtpm(): boolean;
}
/**
 *
 */
export declare class DataGoogleComputeInstance extends TerraformDataSource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config?: DataGoogleComputeInstanceConfig);
    /**
     *
     */
    get allowStoppingForUpdate(): boolean;
    /**
     *
     */
    attachedDisk(index: string): DataGoogleComputeInstanceAttachedDisk;
    /**
     *
     */
    bootDisk(index: string): DataGoogleComputeInstanceBootDisk;
    /**
     *
     */
    get canIpForward(): boolean;
    /**
     *
     */
    get cpuPlatform(): string;
    /**
     *
     */
    get currentStatus(): string;
    /**
     *
     */
    get deletionProtection(): boolean;
    /**
     *
     */
    get description(): string;
    /**
     *
     */
    get desiredStatus(): string;
    /**
     *
     */
    get enableDisplay(): boolean;
    /**
     *
     */
    guestAccelerator(index: string): DataGoogleComputeInstanceGuestAccelerator;
    /**
     *
     */
    get hostname(): string;
    /**
     *
     */
    get id(): string;
    /**
     *
     */
    get instanceId(): string;
    /**
     *
     */
    get labelFingerprint(): string;
    /**
     *
     */
    labels(key: string): string;
    /**
     *
     */
    get machineType(): string;
    /**
     *
     */
    metadata(key: string): string;
    /**
     *
     */
    get metadataFingerprint(): string;
    /**
     *
     */
    get metadataStartupScript(): string;
    /**
     *
     */
    get minCpuPlatform(): string;
    private _name?;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    resetName(): void;
    /**
     *
     */
    get nameInput(): string | undefined;
    /**
     *
     */
    networkInterface(index: string): DataGoogleComputeInstanceNetworkInterface;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    /**
     *
     */
    get resourcePolicies(): string[];
    /**
     *
     */
    scheduling(index: string): DataGoogleComputeInstanceScheduling;
    /**
     *
     */
    scratchDisk(index: string): DataGoogleComputeInstanceScratchDisk;
    private _selfLink?;
    /**
     *
     */
    get selfLink(): string;
    /**
     *
     */
    set selfLink(value: string);
    /**
     *
     */
    resetSelfLink(): void;
    /**
     *
     */
    get selfLinkInput(): string | undefined;
    /**
     *
     */
    serviceAccount(index: string): DataGoogleComputeInstanceServiceAccount;
    /**
     *
     */
    shieldedInstanceConfig(index: string): DataGoogleComputeInstanceShieldedInstanceConfig;
    /**
     *
     */
    get tags(): string[];
    /**
     *
     */
    get tagsFingerprint(): string;
    private _zone?;
    /**
     *
     */
    get zone(): string;
    /**
     *
     */
    set zone(value: string);
    /**
     *
     */
    resetZone(): void;
    /**
     *
     */
    get zoneInput(): string | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
