import { Construct } from 'constructs';
import { TerraformDataSource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
import { ComplexComputedList } from "cdktf";
/**
 *
 */
export interface DataGoogleMonitoringNotificationChannelConfig extends TerraformMetaArguments {
    /**
     * An optional human-readable name for this notification channel.
     *
     * It is recommended that you specify a non-empty and unique name in order to make it easier to identify the channels in your project, though this is not enforced. The display name is limited to 512 Unicode characters.
     */
    readonly displayName?: string;
    /**
     * Configuration fields that define the channel and its behavior.
     *
     * The
     * permissible and required labels are specified in the
     * NotificationChannelDescriptor corresponding to the type field.
     *
     * Labels with sensitive data are obfuscated by the API and therefore Terraform cannot
     * determine if there are upstream changes to these fields. They can also be configured via
     * the sensitive_labels block, but cannot be configured in both places.
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     *
     */
    readonly project?: string;
    /**
     * The type of the notification channel.
     *
     * This field matches the value of the NotificationChannelDescriptor.type field. See https://cloud.google.com/monitoring/api/ref_v3/rest/v3/projects.notificationChannelDescriptors/list to get the list of valid values such as "email", "slack", etc...
     */
    readonly type?: string;
    /**
     * User-supplied key/value data that does not need to conform to the corresponding NotificationChannelDescriptor's schema, unlike the labels field.
     *
     * This field is intended to be used for organizing and identifying the NotificationChannel objects.The field can contain up to 64 entries. Each key and value is limited to 63 Unicode characters or 128 bytes, whichever is smaller. Labels and values can contain only lowercase letters, numerals, underscores, and dashes. Keys must begin with a letter.
     */
    readonly userLabels?: {
        [key: string]: string;
    };
}
/**
 *
 */
export declare class DataGoogleMonitoringNotificationChannelSensitiveLabels extends ComplexComputedList {
    /**
     *
     */
    get authToken(): string;
    /**
     *
     */
    get password(): string;
    /**
     *
     */
    get serviceKey(): string;
}
/**
 *
 */
export declare class DataGoogleMonitoringNotificationChannel extends TerraformDataSource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config?: DataGoogleMonitoringNotificationChannelConfig);
    /**
     *
     */
    get description(): string;
    private _displayName?;
    /**
     *
     */
    get displayName(): string;
    /**
     *
     */
    set displayName(value: string);
    /**
     *
     */
    resetDisplayName(): void;
    /**
     *
     */
    get displayNameInput(): string | undefined;
    /**
     *
     */
    get enabled(): boolean;
    /**
     *
     */
    get id(): string;
    private _labels?;
    /**
     *
     */
    get labels(): {
        [key: string]: string;
    };
    /**
     *
     */
    set labels(value: {
        [key: string]: string;
    });
    /**
     *
     */
    resetLabels(): void;
    /**
     *
     */
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    /**
     *
     */
    get name(): string;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    /**
     *
     */
    sensitiveLabels(index: string): DataGoogleMonitoringNotificationChannelSensitiveLabels;
    private _type?;
    /**
     *
     */
    get type(): string;
    /**
     *
     */
    set type(value: string);
    /**
     *
     */
    resetType(): void;
    /**
     *
     */
    get typeInput(): string | undefined;
    private _userLabels?;
    /**
     *
     */
    get userLabels(): {
        [key: string]: string;
    };
    /**
     *
     */
    set userLabels(value: {
        [key: string]: string;
    });
    /**
     *
     */
    resetUserLabels(): void;
    /**
     *
     */
    get userLabelsInput(): {
        [key: string]: string;
    } | undefined;
    /**
     *
     */
    get verificationStatus(): string;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
