import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface DataLossPreventionDeidentifyTemplateConfig extends TerraformMetaArguments {
    /**
     * A description of the template.
     */
    readonly description?: string;
    /**
     * User set display name of the template.
     */
    readonly displayName?: string;
    /**
     * The parent of the template in any of the following formats:.
     *
     * 'projects/{{project}}'
     * 'projects/{{project}}/locations/{{location}}'
     * 'organizations/{{organization_id}}'
     * 'organizations/{{organization_id}}/locations/{{location}}'
     */
    readonly parent: string;
    /**
     * deidentify_config block.
     */
    readonly deidentifyConfig: DataLossPreventionDeidentifyTemplateDeidentifyConfig[];
    /**
     * timeouts block.
     */
    readonly timeouts?: DataLossPreventionDeidentifyTemplateTimeouts;
}
/**
 *
 */
export interface DataLossPreventionDeidentifyTemplateDeidentifyConfigInfoTypeTransformationsTransformationsInfoTypes {
    /**
     * Name of the information type.
     */
    readonly name: string;
}
/**
 *
 */
export interface DataLossPreventionDeidentifyTemplateDeidentifyConfigInfoTypeTransformationsTransformationsPrimitiveTransformationCharacterMaskConfigCharactersToIgnore {
    /**
     * Characters to not transform when masking.
     */
    readonly characterToSkip?: string;
    /**
     * Common characters to not transform when masking.
     *
     * Useful to avoid removing punctuation. Possible values: ["NUMERIC", "ALPHA_UPPER_CASE", "ALPHA_LOWER_CASE", "PUNCTUATION", "WHITESPACE"]
     */
    readonly commonCharactersToIgnore?: string;
}
/**
 *
 */
export interface DataLossPreventionDeidentifyTemplateDeidentifyConfigInfoTypeTransformationsTransformationsPrimitiveTransformationCharacterMaskConfig {
    /**
     * Character to use to mask the sensitive values—for example, * for an alphabetic string such as a name, or 0 for a numeric string such as ZIP code or credit card number.
     *
     * This string must have a length of 1. If not supplied, this value defaults to * for
     * strings, and 0 for digits.
     */
    readonly maskingCharacter?: string;
    /**
     * Number of characters to mask.
     *
     * If not set, all matching chars will be masked. Skipped characters do not count towards this tally.
     */
    readonly numberToMask?: number;
    /**
     * Mask characters in reverse order.
     *
     * For example, if masking_character is 0, number_to_mask is 14, and reverse_order is 'false', then the
     * input string '1234-5678-9012-3456' is masked as '00000000000000-3456'.
     */
    readonly reverseOrder?: boolean;
    /**
     * characters_to_ignore block.
     */
    readonly charactersToIgnore?: DataLossPreventionDeidentifyTemplateDeidentifyConfigInfoTypeTransformationsTransformationsPrimitiveTransformationCharacterMaskConfigCharactersToIgnore[];
}
/**
 *
 */
export interface DataLossPreventionDeidentifyTemplateDeidentifyConfigInfoTypeTransformationsTransformationsPrimitiveTransformationReplaceConfigNewValueDateValue {
    /**
     * Day of month.
     *
     * Must be from 1 to 31 and valid for the year and month, or 0 if specifying a
     * year by itself or a year and month where the day is not significant.
     */
    readonly day?: number;
    /**
     * Month of year.
     *
     * Must be from 1 to 12, or 0 if specifying a year without a month and day.
     */
    readonly month?: number;
    /**
     * Year of date.
     *
     * Must be from 1 to 9999, or 0 if specifying a date without a year.
     */
    readonly year?: number;
}
/**
 *
 */
export interface DataLossPreventionDeidentifyTemplateDeidentifyConfigInfoTypeTransformationsTransformationsPrimitiveTransformationReplaceConfigNewValueTimeValue {
    /**
     * Hours of day in 24 hour format.
     *
     * Should be from 0 to 23.
     */
    readonly hours?: number;
    /**
     * Minutes of hour of day.
     *
     * Must be from 0 to 59.
     */
    readonly minutes?: number;
    /**
     * Fractions of seconds in nanoseconds.
     *
     * Must be from 0 to 999,999,999.
     */
    readonly nanos?: number;
    /**
     * Seconds of minutes of the time.
     *
     * Must normally be from 0 to 59.
     */
    readonly seconds?: number;
}
/**
 *
 */
export interface DataLossPreventionDeidentifyTemplateDeidentifyConfigInfoTypeTransformationsTransformationsPrimitiveTransformationReplaceConfigNewValue {
    /**
     * A boolean value.
     */
    readonly booleanValue?: boolean;
    /**
     * Represents a day of the week.
     *
     * Possible values: ["MONDAY", "TUESDAY", "WEDNESDAY", "THURSDAY", "FRIDAY", "SATURDAY", "SUNDAY"]
     */
    readonly dayOfWeekValue?: string;
    /**
     * A float value.
     */
    readonly floatValue?: number;
    /**
     * An integer value.
     */
    readonly integerValue?: number;
    /**
     * A string value.
     */
    readonly stringValue?: string;
    /**
     * A timestamp in RFC3339 UTC "Zulu" format, with nanosecond resolution and up to nine fractional digits.
     *
     * Examples: "2014-10-02T15:01:23Z" and "2014-10-02T15:01:23.045123456Z".
     */
    readonly timestampValue?: string;
    /**
     * date_value block.
     */
    readonly dateValue?: DataLossPreventionDeidentifyTemplateDeidentifyConfigInfoTypeTransformationsTransformationsPrimitiveTransformationReplaceConfigNewValueDateValue[];
    /**
     * time_value block.
     */
    readonly timeValue?: DataLossPreventionDeidentifyTemplateDeidentifyConfigInfoTypeTransformationsTransformationsPrimitiveTransformationReplaceConfigNewValueTimeValue[];
}
/**
 *
 */
export interface DataLossPreventionDeidentifyTemplateDeidentifyConfigInfoTypeTransformationsTransformationsPrimitiveTransformationReplaceConfig {
    /**
     * new_value block.
     */
    readonly newValue: DataLossPreventionDeidentifyTemplateDeidentifyConfigInfoTypeTransformationsTransformationsPrimitiveTransformationReplaceConfigNewValue[];
}
/**
 *
 */
export interface DataLossPreventionDeidentifyTemplateDeidentifyConfigInfoTypeTransformationsTransformationsPrimitiveTransformation {
    /**
     * character_mask_config block.
     */
    readonly characterMaskConfig?: DataLossPreventionDeidentifyTemplateDeidentifyConfigInfoTypeTransformationsTransformationsPrimitiveTransformationCharacterMaskConfig[];
    /**
     * replace_config block.
     */
    readonly replaceConfig?: DataLossPreventionDeidentifyTemplateDeidentifyConfigInfoTypeTransformationsTransformationsPrimitiveTransformationReplaceConfig[];
}
/**
 *
 */
export interface DataLossPreventionDeidentifyTemplateDeidentifyConfigInfoTypeTransformationsTransformations {
    /**
     * info_types block.
     */
    readonly infoTypes?: DataLossPreventionDeidentifyTemplateDeidentifyConfigInfoTypeTransformationsTransformationsInfoTypes[];
    /**
     * primitive_transformation block.
     */
    readonly primitiveTransformation: DataLossPreventionDeidentifyTemplateDeidentifyConfigInfoTypeTransformationsTransformationsPrimitiveTransformation[];
}
/**
 *
 */
export interface DataLossPreventionDeidentifyTemplateDeidentifyConfigInfoTypeTransformations {
    /**
     * transformations block.
     */
    readonly transformations: DataLossPreventionDeidentifyTemplateDeidentifyConfigInfoTypeTransformationsTransformations[];
}
/**
 *
 */
export interface DataLossPreventionDeidentifyTemplateDeidentifyConfig {
    /**
     * info_type_transformations block.
     */
    readonly infoTypeTransformations: DataLossPreventionDeidentifyTemplateDeidentifyConfigInfoTypeTransformations[];
}
/**
 *
 */
export interface DataLossPreventionDeidentifyTemplateTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class DataLossPreventionDeidentifyTemplate extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: DataLossPreventionDeidentifyTemplateConfig);
    private _description?;
    /**
     *
     */
    get description(): string;
    /**
     *
     */
    set description(value: string);
    /**
     *
     */
    resetDescription(): void;
    /**
     *
     */
    get descriptionInput(): string | undefined;
    private _displayName?;
    /**
     *
     */
    get displayName(): string;
    /**
     *
     */
    set displayName(value: string);
    /**
     *
     */
    resetDisplayName(): void;
    /**
     *
     */
    get displayNameInput(): string | undefined;
    /**
     *
     */
    get id(): string;
    /**
     *
     */
    get name(): string;
    private _parent;
    /**
     *
     */
    get parent(): string;
    /**
     *
     */
    set parent(value: string);
    /**
     *
     */
    get parentInput(): string;
    private _deidentifyConfig;
    /**
     *
     */
    get deidentifyConfig(): DataLossPreventionDeidentifyTemplateDeidentifyConfig[];
    /**
     *
     */
    set deidentifyConfig(value: DataLossPreventionDeidentifyTemplateDeidentifyConfig[]);
    /**
     *
     */
    get deidentifyConfigInput(): DataLossPreventionDeidentifyTemplateDeidentifyConfig[];
    private _timeouts?;
    /**
     *
     */
    get timeouts(): DataLossPreventionDeidentifyTemplateTimeouts;
    /**
     *
     */
    set timeouts(value: DataLossPreventionDeidentifyTemplateTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): DataLossPreventionDeidentifyTemplateTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
