import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface DataflowJobConfig extends TerraformMetaArguments {
    /**
     * List of experiments that should be used by the job.
     *
     * An example value is ["enable_stackdriver_agent_metrics"].
     */
    readonly additionalExperiments?: string[];
    /**
     * The configuration for VM IPs.
     *
     * Options are "WORKER_IP_PUBLIC" or "WORKER_IP_PRIVATE".
     */
    readonly ipConfiguration?: string;
    /**
     * User labels to be specified for the job.
     *
     * Keys and values should follow the restrictions specified in the labeling restrictions page. NOTE: Google-provided Dataflow templates often provide default labels that begin with goog-dataflow-provided. Unless explicitly set in config, these labels will be ignored to prevent diffs on re-apply.
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * The machine type to use for the job.
     */
    readonly machineType?: string;
    /**
     * The number of workers permitted to work on the job.
     *
     * More workers may improve processing speed at additional cost.
     */
    readonly maxWorkers?: number;
    /**
     * A unique name for the resource, required by Dataflow.
     */
    readonly name: string;
    /**
     * The network to which VMs will be assigned.
     *
     * If it is not provided, "default" will be used.
     */
    readonly network?: string;
    /**
     * One of "drain" or "cancel".
     *
     * Specifies behavior of deletion during terraform destroy.
     */
    readonly onDelete?: string;
    /**
     * Key/Value pairs to be passed to the Dataflow job (as used in the template).
     */
    readonly parameters?: {
        [key: string]: string;
    };
    /**
     * The project in which the resource belongs.
     */
    readonly project?: string;
    /**
     * The region in which the created job should run.
     */
    readonly region?: string;
    /**
     * The Service Account email used to create the job.
     */
    readonly serviceAccountEmail?: string;
    /**
     * The subnetwork to which VMs will be assigned.
     *
     * Should be of the form "regions/REGION/subnetworks/SUBNETWORK".
     */
    readonly subnetwork?: string;
    /**
     * A writeable location on Google Cloud Storage for the Dataflow job to dump its temporary data.
     */
    readonly tempGcsLocation: string;
    /**
     * The Google Cloud Storage path to the Dataflow job template.
     */
    readonly templateGcsPath: string;
    /**
     * Only applicable when updating a pipeline.
     *
     * Map of transform name prefixes of the job to be replaced with the corresponding name prefixes of the new job.
     */
    readonly transformNameMapping?: {
        [key: string]: string;
    };
    /**
     * The zone in which the created job should run.
     *
     * If it is not provided, the provider zone is used.
     */
    readonly zone?: string;
    /**
     * timeouts block.
     */
    readonly timeouts?: DataflowJobTimeouts;
}
/**
 *
 */
export interface DataflowJobTimeouts {
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class DataflowJob extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: DataflowJobConfig);
    private _additionalExperiments?;
    /**
     *
     */
    get additionalExperiments(): string[];
    /**
     *
     */
    set additionalExperiments(value: string[]);
    /**
     *
     */
    resetAdditionalExperiments(): void;
    /**
     *
     */
    get additionalExperimentsInput(): string[] | undefined;
    /**
     *
     */
    get id(): string;
    private _ipConfiguration?;
    /**
     *
     */
    get ipConfiguration(): string;
    /**
     *
     */
    set ipConfiguration(value: string);
    /**
     *
     */
    resetIpConfiguration(): void;
    /**
     *
     */
    get ipConfigurationInput(): string | undefined;
    /**
     *
     */
    get jobId(): string;
    private _labels?;
    /**
     *
     */
    get labels(): {
        [key: string]: string;
    };
    /**
     *
     */
    set labels(value: {
        [key: string]: string;
    });
    /**
     *
     */
    resetLabels(): void;
    /**
     *
     */
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _machineType?;
    /**
     *
     */
    get machineType(): string;
    /**
     *
     */
    set machineType(value: string);
    /**
     *
     */
    resetMachineType(): void;
    /**
     *
     */
    get machineTypeInput(): string | undefined;
    private _maxWorkers?;
    /**
     *
     */
    get maxWorkers(): number;
    /**
     *
     */
    set maxWorkers(value: number);
    /**
     *
     */
    resetMaxWorkers(): void;
    /**
     *
     */
    get maxWorkersInput(): number | undefined;
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    get nameInput(): string;
    private _network?;
    /**
     *
     */
    get network(): string;
    /**
     *
     */
    set network(value: string);
    /**
     *
     */
    resetNetwork(): void;
    /**
     *
     */
    get networkInput(): string | undefined;
    private _onDelete?;
    /**
     *
     */
    get onDelete(): string;
    /**
     *
     */
    set onDelete(value: string);
    /**
     *
     */
    resetOnDelete(): void;
    /**
     *
     */
    get onDeleteInput(): string | undefined;
    private _parameters?;
    /**
     *
     */
    get parameters(): {
        [key: string]: string;
    };
    /**
     *
     */
    set parameters(value: {
        [key: string]: string;
    });
    /**
     *
     */
    resetParameters(): void;
    /**
     *
     */
    get parametersInput(): {
        [key: string]: string;
    } | undefined;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _region?;
    /**
     *
     */
    get region(): string;
    /**
     *
     */
    set region(value: string);
    /**
     *
     */
    resetRegion(): void;
    /**
     *
     */
    get regionInput(): string | undefined;
    private _serviceAccountEmail?;
    /**
     *
     */
    get serviceAccountEmail(): string;
    /**
     *
     */
    set serviceAccountEmail(value: string);
    /**
     *
     */
    resetServiceAccountEmail(): void;
    /**
     *
     */
    get serviceAccountEmailInput(): string | undefined;
    /**
     *
     */
    get state(): string;
    private _subnetwork?;
    /**
     *
     */
    get subnetwork(): string;
    /**
     *
     */
    set subnetwork(value: string);
    /**
     *
     */
    resetSubnetwork(): void;
    /**
     *
     */
    get subnetworkInput(): string | undefined;
    private _tempGcsLocation;
    /**
     *
     */
    get tempGcsLocation(): string;
    /**
     *
     */
    set tempGcsLocation(value: string);
    /**
     *
     */
    get tempGcsLocationInput(): string;
    private _templateGcsPath;
    /**
     *
     */
    get templateGcsPath(): string;
    /**
     *
     */
    set templateGcsPath(value: string);
    /**
     *
     */
    get templateGcsPathInput(): string;
    private _transformNameMapping?;
    /**
     *
     */
    get transformNameMapping(): {
        [key: string]: string;
    };
    /**
     *
     */
    set transformNameMapping(value: {
        [key: string]: string;
    });
    /**
     *
     */
    resetTransformNameMapping(): void;
    /**
     *
     */
    get transformNameMappingInput(): {
        [key: string]: string;
    } | undefined;
    /**
     *
     */
    get type(): string;
    private _zone?;
    /**
     *
     */
    get zone(): string;
    /**
     *
     */
    set zone(value: string);
    /**
     *
     */
    resetZone(): void;
    /**
     *
     */
    get zoneInput(): string | undefined;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): DataflowJobTimeouts;
    /**
     *
     */
    set timeouts(value: DataflowJobTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): DataflowJobTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
