import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface DeploymentManagerDeploymentConfig extends TerraformMetaArguments {
    /**
     * Set the policy to use for creating new resources.
     *
     * Only used on
     * create and update. Valid values are 'CREATE_OR_ACQUIRE' (default) or
     * 'ACQUIRE'. If set to 'ACQUIRE' and resources do not already exist,
     * the deployment will fail. Note that updating this field does not
     * actually affect the deployment, just how it is updated. Default value: "CREATE_OR_ACQUIRE" Possible values: ["ACQUIRE", "CREATE_OR_ACQUIRE"]
     */
    readonly createPolicy?: string;
    /**
     * Set the policy to use for deleting new resources on update/delete.
     *
     * Valid values are 'DELETE' (default) or 'ABANDON'. If 'DELETE',
     * resource is deleted after removal from Deployment Manager. If
     * 'ABANDON', the resource is only removed from Deployment Manager
     * and is not actually deleted. Note that updating this field does not
     * actually change the deployment, just how it is updated. Default value: "DELETE" Possible values: ["ABANDON", "DELETE"]
     */
    readonly deletePolicy?: string;
    /**
     * Optional user-provided description of deployment.
     */
    readonly description?: string;
    /**
     * Unique name for the deployment.
     */
    readonly name: string;
    /**
     * If set to true, a deployment is created with "shell" resources that are not actually instantiated.
     *
     * This allows you to preview a
     * deployment. It can be updated to false to actually deploy
     * with real resources.
     * ~>**NOTE:** Deployment Manager does not allow update
     * of a deployment in preview (unless updating to preview=false). Thus,
     * Terraform will force-recreate deployments if either preview is updated
     * to true or if other fields are updated while preview is true.
     */
    readonly preview?: boolean;
    /**
     *
     */
    readonly project?: string;
    /**
     * labels block.
     */
    readonly labels?: DeploymentManagerDeploymentLabels[];
    /**
     * target block.
     */
    readonly target: DeploymentManagerDeploymentTarget[];
    /**
     * timeouts block.
     */
    readonly timeouts?: DeploymentManagerDeploymentTimeouts;
}
/**
 *
 */
export interface DeploymentManagerDeploymentLabels {
    /**
     * Key for label.
     */
    readonly key?: string;
    /**
     * Value of label.
     */
    readonly value?: string;
}
/**
 *
 */
export interface DeploymentManagerDeploymentTargetConfig {
    /**
     * The full YAML contents of your configuration file.
     */
    readonly content: string;
}
/**
 *
 */
export interface DeploymentManagerDeploymentTargetImports {
    /**
     * The full contents of the template that you want to import.
     */
    readonly content?: string;
    /**
     * The name of the template to import, as declared in the YAML configuration.
     */
    readonly name?: string;
}
/**
 *
 */
export interface DeploymentManagerDeploymentTarget {
    /**
     * config block.
     */
    readonly config: DeploymentManagerDeploymentTargetConfig[];
    /**
     * imports block.
     */
    readonly imports?: DeploymentManagerDeploymentTargetImports[];
}
/**
 *
 */
export interface DeploymentManagerDeploymentTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class DeploymentManagerDeployment extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: DeploymentManagerDeploymentConfig);
    private _createPolicy?;
    /**
     *
     */
    get createPolicy(): string;
    /**
     *
     */
    set createPolicy(value: string);
    /**
     *
     */
    resetCreatePolicy(): void;
    /**
     *
     */
    get createPolicyInput(): string | undefined;
    private _deletePolicy?;
    /**
     *
     */
    get deletePolicy(): string;
    /**
     *
     */
    set deletePolicy(value: string);
    /**
     *
     */
    resetDeletePolicy(): void;
    /**
     *
     */
    get deletePolicyInput(): string | undefined;
    /**
     *
     */
    get deploymentId(): string;
    private _description?;
    /**
     *
     */
    get description(): string;
    /**
     *
     */
    set description(value: string);
    /**
     *
     */
    resetDescription(): void;
    /**
     *
     */
    get descriptionInput(): string | undefined;
    /**
     *
     */
    get id(): string;
    /**
     *
     */
    get manifest(): string;
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    get nameInput(): string;
    private _preview?;
    /**
     *
     */
    get preview(): boolean;
    /**
     *
     */
    set preview(value: boolean);
    /**
     *
     */
    resetPreview(): void;
    /**
     *
     */
    get previewInput(): boolean | undefined;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    /**
     *
     */
    get selfLink(): string;
    private _labels?;
    /**
     *
     */
    get labels(): DeploymentManagerDeploymentLabels[];
    /**
     *
     */
    set labels(value: DeploymentManagerDeploymentLabels[]);
    /**
     *
     */
    resetLabels(): void;
    /**
     *
     */
    get labelsInput(): DeploymentManagerDeploymentLabels[] | undefined;
    private _target;
    /**
     *
     */
    get target(): DeploymentManagerDeploymentTarget[];
    /**
     *
     */
    set target(value: DeploymentManagerDeploymentTarget[]);
    /**
     *
     */
    get targetInput(): DeploymentManagerDeploymentTarget[];
    private _timeouts?;
    /**
     *
     */
    get timeouts(): DeploymentManagerDeploymentTimeouts;
    /**
     *
     */
    set timeouts(value: DeploymentManagerDeploymentTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): DeploymentManagerDeploymentTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
