import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
import { ComplexComputedList } from "cdktf";
/**
 *
 */
export interface DialogflowIntentConfig extends TerraformMetaArguments {
    /**
     * The name of the action associated with the intent.
     *
     * Note: The action name must not contain whitespaces.
     */
    readonly action?: string;
    /**
     * The list of platforms for which the first responses will be copied from the messages in PLATFORM_UNSPECIFIED (i.e. default platform). Possible values: ["FACEBOOK", "SLACK", "TELEGRAM", "KIK", "SKYPE", "LINE", "VIBER", "ACTIONS_ON_GOOGLE", "GOOGLE_HANGOUTS"].
     */
    readonly defaultResponsePlatforms?: string[];
    /**
     * The name of this intent to be displayed on the console.
     */
    readonly displayName: string;
    /**
     * The collection of event names that trigger the intent.
     *
     * If the collection of input contexts is not empty, all of
     * the contexts must be present in the active user session for an event to trigger this intent. See the
     * [events reference](https://cloud.google.com/dialogflow/docs/events-overview) for more details.
     */
    readonly events?: string[];
    /**
     * The list of context names required for this intent to be triggered.
     *
     * Format: projects/<Project ID>/agent/sessions/-/contexts/<Context ID>.
     */
    readonly inputContextNames?: string[];
    /**
     * Indicates whether this is a fallback intent.
     */
    readonly isFallback?: boolean;
    /**
     * Indicates whether Machine Learning is disabled for the intent.
     *
     * Note: If mlDisabled setting is set to true, then this intent is not taken into account during inference in ML
     * ONLY match mode. Also, auto-markup in the UI is turned off.
     */
    readonly mlDisabled?: boolean;
    /**
     * The unique identifier of the parent intent in the chain of followup intents.
     *
     * Format: projects/<Project ID>/agent/intents/<Intent ID>.
     */
    readonly parentFollowupIntentName?: string;
    /**
     * The priority of this intent.
     *
     * Higher numbers represent higher priorities.
     * - If the supplied value is unspecified or 0, the service translates the value to 500,000, which corresponds
     * to the Normal priority in the console.
     * - If the supplied value is negative, the intent is ignored in runtime detect intent requests.
     */
    readonly priority?: number;
    /**
     *
     */
    readonly project?: string;
    /**
     * Indicates whether to delete all contexts in the current session when this intent is matched.
     */
    readonly resetContexts?: boolean;
    /**
     * Indicates whether webhooks are enabled for the intent.
     *
     * WEBHOOK_STATE_ENABLED: Webhook is enabled in the agent and in the intent.
     * WEBHOOK_STATE_ENABLED_FOR_SLOT_FILLING: Webhook is enabled in the agent and in the intent. Also, each slot
     * filling prompt is forwarded to the webhook. Possible values: ["WEBHOOK_STATE_ENABLED", "WEBHOOK_STATE_ENABLED_FOR_SLOT_FILLING"]
     */
    readonly webhookState?: string;
    /**
     * timeouts block.
     */
    readonly timeouts?: DialogflowIntentTimeouts;
}
/**
 *
 */
export declare class DialogflowIntentFollowupIntentInfo extends ComplexComputedList {
    /**
     *
     */
    get followupIntentName(): string;
    /**
     *
     */
    get parentFollowupIntentName(): string;
}
/**
 *
 */
export interface DialogflowIntentTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class DialogflowIntent extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: DialogflowIntentConfig);
    private _action?;
    /**
     *
     */
    get action(): string;
    /**
     *
     */
    set action(value: string);
    /**
     *
     */
    resetAction(): void;
    /**
     *
     */
    get actionInput(): string | undefined;
    private _defaultResponsePlatforms?;
    /**
     *
     */
    get defaultResponsePlatforms(): string[];
    /**
     *
     */
    set defaultResponsePlatforms(value: string[]);
    /**
     *
     */
    resetDefaultResponsePlatforms(): void;
    /**
     *
     */
    get defaultResponsePlatformsInput(): string[] | undefined;
    private _displayName;
    /**
     *
     */
    get displayName(): string;
    /**
     *
     */
    set displayName(value: string);
    /**
     *
     */
    get displayNameInput(): string;
    private _events?;
    /**
     *
     */
    get events(): string[];
    /**
     *
     */
    set events(value: string[]);
    /**
     *
     */
    resetEvents(): void;
    /**
     *
     */
    get eventsInput(): string[] | undefined;
    /**
     *
     */
    followupIntentInfo(index: string): DialogflowIntentFollowupIntentInfo;
    /**
     *
     */
    get id(): string;
    private _inputContextNames?;
    /**
     *
     */
    get inputContextNames(): string[];
    /**
     *
     */
    set inputContextNames(value: string[]);
    /**
     *
     */
    resetInputContextNames(): void;
    /**
     *
     */
    get inputContextNamesInput(): string[] | undefined;
    private _isFallback?;
    /**
     *
     */
    get isFallback(): boolean;
    /**
     *
     */
    set isFallback(value: boolean);
    /**
     *
     */
    resetIsFallback(): void;
    /**
     *
     */
    get isFallbackInput(): boolean | undefined;
    private _mlDisabled?;
    /**
     *
     */
    get mlDisabled(): boolean;
    /**
     *
     */
    set mlDisabled(value: boolean);
    /**
     *
     */
    resetMlDisabled(): void;
    /**
     *
     */
    get mlDisabledInput(): boolean | undefined;
    /**
     *
     */
    get name(): string;
    private _parentFollowupIntentName?;
    /**
     *
     */
    get parentFollowupIntentName(): string;
    /**
     *
     */
    set parentFollowupIntentName(value: string);
    /**
     *
     */
    resetParentFollowupIntentName(): void;
    /**
     *
     */
    get parentFollowupIntentNameInput(): string | undefined;
    private _priority?;
    /**
     *
     */
    get priority(): number;
    /**
     *
     */
    set priority(value: number);
    /**
     *
     */
    resetPriority(): void;
    /**
     *
     */
    get priorityInput(): number | undefined;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _resetContexts?;
    /**
     *
     */
    get resetContexts(): boolean;
    /**
     *
     */
    set resetContexts(value: boolean);
    /**
     *
     */
    resetResetContexts(): void;
    /**
     *
     */
    get resetContextsInput(): boolean | undefined;
    /**
     *
     */
    get rootFollowupIntentName(): string;
    private _webhookState?;
    /**
     *
     */
    get webhookState(): string;
    /**
     *
     */
    set webhookState(value: string);
    /**
     *
     */
    resetWebhookState(): void;
    /**
     *
     */
    get webhookStateInput(): string | undefined;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): DialogflowIntentTimeouts;
    /**
     *
     */
    set timeouts(value: DialogflowIntentTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): DialogflowIntentTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
