import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface DnsPolicyConfig extends TerraformMetaArguments {
    /**
     * A textual description field.
     *
     * Defaults to 'Managed by Terraform'.
     */
    readonly description?: string;
    /**
     * Allows networks bound to this policy to receive DNS queries sent by VMs or applications over VPN connections.
     *
     * When enabled, a
     * virtual IP address will be allocated from each of the sub-networks
     * that are bound to this policy.
     */
    readonly enableInboundForwarding?: boolean;
    /**
     * Controls whether logging is enabled for the networks bound to this policy.
     *
     * Defaults to no logging if not set.
     */
    readonly enableLogging?: boolean;
    /**
     * User assigned name for this policy.
     */
    readonly name: string;
    /**
     *
     */
    readonly project?: string;
    /**
     * alternative_name_server_config block.
     */
    readonly alternativeNameServerConfig?: DnsPolicyAlternativeNameServerConfig[];
    /**
     * networks block.
     */
    readonly networks?: DnsPolicyNetworks[];
    /**
     * timeouts block.
     */
    readonly timeouts?: DnsPolicyTimeouts;
}
/**
 *
 */
export interface DnsPolicyAlternativeNameServerConfigTargetNameServers {
    /**
     * Forwarding path for this TargetNameServer.
     *
     * If unset or 'default' Cloud DNS will make forwarding
     * decision based on address ranges, i.e. RFC1918 addresses go to the VPC, Non-RFC1918 addresses go
     * to the Internet. When set to 'private', Cloud DNS will always send queries through VPC for this target Possible values: ["default", "private"]
     */
    readonly forwardingPath?: string;
    /**
     * IPv4 address to forward to.
     */
    readonly ipv4Address: string;
}
/**
 *
 */
export interface DnsPolicyAlternativeNameServerConfig {
    /**
     * target_name_servers block.
     */
    readonly targetNameServers: DnsPolicyAlternativeNameServerConfigTargetNameServers[];
}
/**
 *
 */
export interface DnsPolicyNetworks {
    /**
     * The id or fully qualified URL of the VPC network to forward queries to.
     *
     * This should be formatted like 'projects/{project}/global/networks/{network}' or
     * 'https://www.googleapis.com/compute/v1/projects/{project}/global/networks/{network}'
     */
    readonly networkUrl: string;
}
/**
 *
 */
export interface DnsPolicyTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class DnsPolicy extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: DnsPolicyConfig);
    private _description?;
    /**
     *
     */
    get description(): string;
    /**
     *
     */
    set description(value: string);
    /**
     *
     */
    resetDescription(): void;
    /**
     *
     */
    get descriptionInput(): string | undefined;
    private _enableInboundForwarding?;
    /**
     *
     */
    get enableInboundForwarding(): boolean;
    /**
     *
     */
    set enableInboundForwarding(value: boolean);
    /**
     *
     */
    resetEnableInboundForwarding(): void;
    /**
     *
     */
    get enableInboundForwardingInput(): boolean | undefined;
    private _enableLogging?;
    /**
     *
     */
    get enableLogging(): boolean;
    /**
     *
     */
    set enableLogging(value: boolean);
    /**
     *
     */
    resetEnableLogging(): void;
    /**
     *
     */
    get enableLoggingInput(): boolean | undefined;
    /**
     *
     */
    get id(): string;
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    get nameInput(): string;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _alternativeNameServerConfig?;
    /**
     *
     */
    get alternativeNameServerConfig(): DnsPolicyAlternativeNameServerConfig[];
    /**
     *
     */
    set alternativeNameServerConfig(value: DnsPolicyAlternativeNameServerConfig[]);
    /**
     *
     */
    resetAlternativeNameServerConfig(): void;
    /**
     *
     */
    get alternativeNameServerConfigInput(): DnsPolicyAlternativeNameServerConfig[] | undefined;
    private _networks?;
    /**
     *
     */
    get networks(): DnsPolicyNetworks[];
    /**
     *
     */
    set networks(value: DnsPolicyNetworks[]);
    /**
     *
     */
    resetNetworks(): void;
    /**
     *
     */
    get networksInput(): DnsPolicyNetworks[] | undefined;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): DnsPolicyTimeouts;
    /**
     *
     */
    set timeouts(value: DnsPolicyTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): DnsPolicyTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
