import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface DnsRecordSetConfig extends TerraformMetaArguments {
    /**
     * The name of the zone in which this record set will reside.
     */
    readonly managedZone: string;
    /**
     * The DNS name this record set will apply to.
     */
    readonly name: string;
    /**
     * The ID of the project in which the resource belongs.
     *
     * If it is not provided, the provider project is used.
     */
    readonly project?: string;
    /**
     * The string data for the records in this record set whose meaning depends on the DNS type.
     *
     * For TXT record, if the string data contains spaces, add surrounding \" if you don't want your string to get split on spaces. To specify a single record value longer than 255 characters such as a TXT record for DKIM, add \"\" inside the Terraform configuration string (e.g. "first255characters\"\"morecharacters").
     */
    readonly rrdatas: string[];
    /**
     * The time-to-live of this record set (seconds).
     */
    readonly ttl: number;
    /**
     * The DNS record set type.
     */
    readonly type: string;
}
/**
 *
 */
export declare class DnsRecordSet extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: DnsRecordSetConfig);
    /**
     *
     */
    get id(): string;
    private _managedZone;
    /**
     *
     */
    get managedZone(): string;
    /**
     *
     */
    set managedZone(value: string);
    /**
     *
     */
    get managedZoneInput(): string;
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    get nameInput(): string;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _rrdatas;
    /**
     *
     */
    get rrdatas(): string[];
    /**
     *
     */
    set rrdatas(value: string[]);
    /**
     *
     */
    get rrdatasInput(): string[];
    private _ttl;
    /**
     *
     */
    get ttl(): number;
    /**
     *
     */
    set ttl(value: number);
    /**
     *
     */
    get ttlInput(): number;
    private _type;
    /**
     *
     */
    get type(): string;
    /**
     *
     */
    set type(value: string);
    /**
     *
     */
    get typeInput(): string;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
