import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface GameServicesGameServerConfigConfig extends TerraformMetaArguments {
    /**
     * A unique id for the deployment config.
     */
    readonly configId: string;
    /**
     * A unique id for the deployment.
     */
    readonly deploymentId: string;
    /**
     * The description of the game server config.
     */
    readonly description?: string;
    /**
     * The labels associated with this game server config.
     *
     * Each label is a
     * key-value pair.
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Location of the Deployment.
     */
    readonly location?: string;
    /**
     *
     */
    readonly project?: string;
    /**
     * fleet_configs block.
     */
    readonly fleetConfigs: GameServicesGameServerConfigFleetConfigs[];
    /**
     * scaling_configs block.
     */
    readonly scalingConfigs?: GameServicesGameServerConfigScalingConfigs[];
    /**
     * timeouts block.
     */
    readonly timeouts?: GameServicesGameServerConfigTimeouts;
}
/**
 *
 */
export interface GameServicesGameServerConfigFleetConfigs {
    /**
     * The fleet spec, which is sent to Agones to configure fleet.
     *
     * The spec can be passed as inline json but it is recommended to use a file reference
     * instead. File references can contain the json or yaml format of the fleet spec. Eg:
     *
     * fleet_spec = jsonencode(yamldecode(file("fleet_configs.yaml")))
     * fleet_spec = file("fleet_configs.json")
     *
     * The format of the spec can be found :
     * 'https://agones.dev/site/docs/reference/fleet/'.
     */
    readonly fleetSpec: string;
    /**
     * The name of the FleetConfig.
     */
    readonly name?: string;
}
/**
 *
 */
export interface GameServicesGameServerConfigScalingConfigsSchedules {
    /**
     * The duration for the cron job event. The duration of the event is effective after the cron job's start time.
     *
     * A duration in seconds with up to nine fractional digits, terminated by 's'. Example: "3.5s".
     */
    readonly cronJobDuration?: string;
    /**
     * The cron definition of the scheduled event.
     *
     * See
     * https://en.wikipedia.org/wiki/Cron. Cron spec specifies the local time as
     * defined by the realm.
     */
    readonly cronSpec?: string;
    /**
     * The end time of the event.
     *
     * A timestamp in RFC3339 UTC "Zulu" format, accurate to nanoseconds. Example: "2014-10-02T15:01:23.045123456Z".
     */
    readonly endTime?: string;
    /**
     * The start time of the event.
     *
     * A timestamp in RFC3339 UTC "Zulu" format, accurate to nanoseconds. Example: "2014-10-02T15:01:23.045123456Z".
     */
    readonly startTime?: string;
}
/**
 *
 */
export interface GameServicesGameServerConfigScalingConfigsSelectors {
    /**
     * Set of labels to group by.
     */
    readonly labels?: {
        [key: string]: string;
    };
}
/**
 *
 */
export interface GameServicesGameServerConfigScalingConfigs {
    /**
     * Fleet autoscaler spec, which is sent to Agones.
     *
     * Example spec can be found :
     * https://agones.dev/site/docs/reference/fleetautoscaler/
     */
    readonly fleetAutoscalerSpec: string;
    /**
     * The name of the ScalingConfig.
     */
    readonly name: string;
    /**
     * schedules block.
     */
    readonly schedules?: GameServicesGameServerConfigScalingConfigsSchedules[];
    /**
     * selectors block.
     */
    readonly selectors?: GameServicesGameServerConfigScalingConfigsSelectors[];
}
/**
 *
 */
export interface GameServicesGameServerConfigTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
}
/**
 *
 */
export declare class GameServicesGameServerConfig extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: GameServicesGameServerConfigConfig);
    private _configId;
    /**
     *
     */
    get configId(): string;
    /**
     *
     */
    set configId(value: string);
    /**
     *
     */
    get configIdInput(): string;
    private _deploymentId;
    /**
     *
     */
    get deploymentId(): string;
    /**
     *
     */
    set deploymentId(value: string);
    /**
     *
     */
    get deploymentIdInput(): string;
    private _description?;
    /**
     *
     */
    get description(): string;
    /**
     *
     */
    set description(value: string);
    /**
     *
     */
    resetDescription(): void;
    /**
     *
     */
    get descriptionInput(): string | undefined;
    /**
     *
     */
    get id(): string;
    private _labels?;
    /**
     *
     */
    get labels(): {
        [key: string]: string;
    };
    /**
     *
     */
    set labels(value: {
        [key: string]: string;
    });
    /**
     *
     */
    resetLabels(): void;
    /**
     *
     */
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    /**
     *
     */
    get location(): string;
    /**
     *
     */
    set location(value: string);
    /**
     *
     */
    resetLocation(): void;
    /**
     *
     */
    get locationInput(): string | undefined;
    /**
     *
     */
    get name(): string;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _fleetConfigs;
    /**
     *
     */
    get fleetConfigs(): GameServicesGameServerConfigFleetConfigs[];
    /**
     *
     */
    set fleetConfigs(value: GameServicesGameServerConfigFleetConfigs[]);
    /**
     *
     */
    get fleetConfigsInput(): GameServicesGameServerConfigFleetConfigs[];
    private _scalingConfigs?;
    /**
     *
     */
    get scalingConfigs(): GameServicesGameServerConfigScalingConfigs[];
    /**
     *
     */
    set scalingConfigs(value: GameServicesGameServerConfigScalingConfigs[]);
    /**
     *
     */
    resetScalingConfigs(): void;
    /**
     *
     */
    get scalingConfigsInput(): GameServicesGameServerConfigScalingConfigs[] | undefined;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): GameServicesGameServerConfigTimeouts;
    /**
     *
     */
    set timeouts(value: GameServicesGameServerConfigTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): GameServicesGameServerConfigTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
