import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface HealthcareDicomStoreConfig extends TerraformMetaArguments {
    /**
     * Identifies the dataset addressed by this request.
     *
     * Must be in the format
     * 'projects/{project}/locations/{location}/datasets/{dataset}'
     */
    readonly dataset: string;
    /**
     * User-supplied key-value pairs used to organize DICOM stores.
     *
     * Label keys must be between 1 and 63 characters long, have a UTF-8 encoding of maximum 128 bytes, and must
     * conform to the following PCRE regular expression: [\p{Ll}\p{Lo}][\p{Ll}\p{Lo}\p{N}_-]{0,62}
     *
     * Label values are optional, must be between 1 and 63 characters long, have a UTF-8 encoding of maximum 128
     * bytes, and must conform to the following PCRE regular expression: [\p{Ll}\p{Lo}\p{N}_-]{0,63}
     *
     * No more than 64 labels can be associated with a given store.
     *
     * An object containing a list of "key": value pairs.
     * Example: { "name": "wrench", "mass": "1.3kg", "count": "3" }.
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * The resource name for the DicomStore.
     *
     * * Changing this property may recreate the Dicom store (removing all data) **
     */
    readonly name: string;
    /**
     * notification_config block.
     */
    readonly notificationConfig?: HealthcareDicomStoreNotificationConfig[];
    /**
     * timeouts block.
     */
    readonly timeouts?: HealthcareDicomStoreTimeouts;
}
/**
 *
 */
export interface HealthcareDicomStoreNotificationConfig {
    /**
     * The Cloud Pub/Sub topic that notifications of changes are published on.
     *
     * Supplied by the client.
     * PubsubMessage.Data will contain the resource name. PubsubMessage.MessageId is the ID of this message.
     * It is guaranteed to be unique within the topic. PubsubMessage.PublishTime is the time at which the message
     * was published. Notifications are only sent if the topic is non-empty. Topic names must be scoped to a
     * project. cloud-healthcare@system.gserviceaccount.com must have publisher permissions on the given
     * Cloud Pub/Sub topic. Not having adequate permissions will cause the calls that send notifications to fail.
     */
    readonly pubsubTopic: string;
}
/**
 *
 */
export interface HealthcareDicomStoreTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class HealthcareDicomStore extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: HealthcareDicomStoreConfig);
    private _dataset;
    /**
     *
     */
    get dataset(): string;
    /**
     *
     */
    set dataset(value: string);
    /**
     *
     */
    get datasetInput(): string;
    /**
     *
     */
    get id(): string;
    private _labels?;
    /**
     *
     */
    get labels(): {
        [key: string]: string;
    };
    /**
     *
     */
    set labels(value: {
        [key: string]: string;
    });
    /**
     *
     */
    resetLabels(): void;
    /**
     *
     */
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    get nameInput(): string;
    /**
     *
     */
    get selfLink(): string;
    private _notificationConfig?;
    /**
     *
     */
    get notificationConfig(): HealthcareDicomStoreNotificationConfig[];
    /**
     *
     */
    set notificationConfig(value: HealthcareDicomStoreNotificationConfig[]);
    /**
     *
     */
    resetNotificationConfig(): void;
    /**
     *
     */
    get notificationConfigInput(): HealthcareDicomStoreNotificationConfig[] | undefined;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): HealthcareDicomStoreTimeouts;
    /**
     *
     */
    set timeouts(value: HealthcareDicomStoreTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): HealthcareDicomStoreTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
