import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface IdentityPlatformTenantInboundSamlConfigConfig extends TerraformMetaArguments {
    /**
     * Human friendly display name.
     */
    readonly displayName: string;
    /**
     * If this config allows users to sign in with the provider.
     */
    readonly enabled?: boolean;
    /**
     * The name of the InboundSamlConfig resource.
     *
     * Must start with 'saml.' and can only have alphanumeric characters,
     * hyphens, underscores or periods. The part after 'saml.' must also start with a lowercase letter, end with an
     * alphanumeric character, and have at least 2 characters.
     */
    readonly name: string;
    /**
     *
     */
    readonly project?: string;
    /**
     * The name of the tenant where this inbound SAML config resource exists.
     */
    readonly tenant: string;
    /**
     * idp_config block.
     */
    readonly idpConfig: IdentityPlatformTenantInboundSamlConfigIdpConfig[];
    /**
     * sp_config block.
     */
    readonly spConfig: IdentityPlatformTenantInboundSamlConfigSpConfig[];
    /**
     * timeouts block.
     */
    readonly timeouts?: IdentityPlatformTenantInboundSamlConfigTimeouts;
}
/**
 *
 */
export interface IdentityPlatformTenantInboundSamlConfigIdpConfigIdpCertificates {
    /**
     * The x509 certificate.
     */
    readonly x509Certificate?: string;
}
/**
 *
 */
export interface IdentityPlatformTenantInboundSamlConfigIdpConfig {
    /**
     * Unique identifier for all SAML entities.
     */
    readonly idpEntityId: string;
    /**
     * Indicates if outbounding SAMLRequest should be signed.
     */
    readonly signRequest?: boolean;
    /**
     * URL to send Authentication request to.
     */
    readonly ssoUrl: string;
    /**
     * idp_certificates block.
     */
    readonly idpCertificates: IdentityPlatformTenantInboundSamlConfigIdpConfigIdpCertificates[];
}
/**
 *
 */
export interface IdentityPlatformTenantInboundSamlConfigSpConfig {
    /**
     * Callback URI where responses from IDP are handled.
     *
     * Must start with 'https://'.
     */
    readonly callbackUri: string;
    /**
     * Unique identifier for all SAML entities.
     */
    readonly spEntityId: string;
}
/**
 *
 */
export interface IdentityPlatformTenantInboundSamlConfigTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class IdentityPlatformTenantInboundSamlConfig extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: IdentityPlatformTenantInboundSamlConfigConfig);
    private _displayName;
    /**
     *
     */
    get displayName(): string;
    /**
     *
     */
    set displayName(value: string);
    /**
     *
     */
    get displayNameInput(): string;
    private _enabled?;
    /**
     *
     */
    get enabled(): boolean;
    /**
     *
     */
    set enabled(value: boolean);
    /**
     *
     */
    resetEnabled(): void;
    /**
     *
     */
    get enabledInput(): boolean | undefined;
    /**
     *
     */
    get id(): string;
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    get nameInput(): string;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _tenant;
    /**
     *
     */
    get tenant(): string;
    /**
     *
     */
    set tenant(value: string);
    /**
     *
     */
    get tenantInput(): string;
    private _idpConfig;
    /**
     *
     */
    get idpConfig(): IdentityPlatformTenantInboundSamlConfigIdpConfig[];
    /**
     *
     */
    set idpConfig(value: IdentityPlatformTenantInboundSamlConfigIdpConfig[]);
    /**
     *
     */
    get idpConfigInput(): IdentityPlatformTenantInboundSamlConfigIdpConfig[];
    private _spConfig;
    /**
     *
     */
    get spConfig(): IdentityPlatformTenantInboundSamlConfigSpConfig[];
    /**
     *
     */
    set spConfig(value: IdentityPlatformTenantInboundSamlConfigSpConfig[]);
    /**
     *
     */
    get spConfigInput(): IdentityPlatformTenantInboundSamlConfigSpConfig[];
    private _timeouts?;
    /**
     *
     */
    get timeouts(): IdentityPlatformTenantInboundSamlConfigTimeouts;
    /**
     *
     */
    set timeouts(value: IdentityPlatformTenantInboundSamlConfigTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): IdentityPlatformTenantInboundSamlConfigTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
