import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
import { ComplexComputedList } from "cdktf";
/**
 *
 */
export interface KmsKeyRingImportJobConfig extends TerraformMetaArguments {
    /**
     * It must be unique within a KeyRing and match the regular expression [a-zA-Z0-9_-]{1,63}.
     */
    readonly importJobId: string;
    /**
     * The wrapping method to be used for incoming key material.
     *
     * Possible values: ["RSA_OAEP_3072_SHA1_AES_256", "RSA_OAEP_4096_SHA1_AES_256"]
     */
    readonly importMethod: string;
    /**
     * The KeyRing that this import job belongs to.
     *
     * Format: ''projects/{{project}}/locations/{{location}}/keyRings/{{keyRing}}''.
     */
    readonly keyRing: string;
    /**
     * The protection level of the ImportJob.
     *
     * This must match the protectionLevel of the
     * versionTemplate on the CryptoKey you attempt to import into. Possible values: ["SOFTWARE", "HSM", "EXTERNAL"]
     */
    readonly protectionLevel: string;
    /**
     * timeouts block.
     */
    readonly timeouts?: KmsKeyRingImportJobTimeouts;
}
/**
 *
 */
export declare class KmsKeyRingImportJobAttestation extends ComplexComputedList {
    /**
     *
     */
    get content(): string;
    /**
     *
     */
    get format(): string;
}
/**
 *
 */
export declare class KmsKeyRingImportJobPublicKey extends ComplexComputedList {
    /**
     *
     */
    get pem(): string;
}
/**
 *
 */
export interface KmsKeyRingImportJobTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
}
/**
 *
 */
export declare class KmsKeyRingImportJob extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: KmsKeyRingImportJobConfig);
    /**
     *
     */
    attestation(index: string): KmsKeyRingImportJobAttestation;
    /**
     *
     */
    get expireTime(): string;
    /**
     *
     */
    get id(): string;
    private _importJobId;
    /**
     *
     */
    get importJobId(): string;
    /**
     *
     */
    set importJobId(value: string);
    /**
     *
     */
    get importJobIdInput(): string;
    private _importMethod;
    /**
     *
     */
    get importMethod(): string;
    /**
     *
     */
    set importMethod(value: string);
    /**
     *
     */
    get importMethodInput(): string;
    private _keyRing;
    /**
     *
     */
    get keyRing(): string;
    /**
     *
     */
    set keyRing(value: string);
    /**
     *
     */
    get keyRingInput(): string;
    /**
     *
     */
    get name(): string;
    private _protectionLevel;
    /**
     *
     */
    get protectionLevel(): string;
    /**
     *
     */
    set protectionLevel(value: string);
    /**
     *
     */
    get protectionLevelInput(): string;
    /**
     *
     */
    publicKey(index: string): KmsKeyRingImportJobPublicKey;
    /**
     *
     */
    get state(): string;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): KmsKeyRingImportJobTimeouts;
    /**
     *
     */
    set timeouts(value: KmsKeyRingImportJobTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): KmsKeyRingImportJobTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
