import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface LoggingBillingAccountSinkConfig extends TerraformMetaArguments {
    /**
     * The billing account exported to the sink.
     */
    readonly billingAccount: string;
    /**
     * The destination of the sink (or, in other words, where logs are written to).
     *
     * Can be a Cloud Storage bucket, a PubSub topic, or a BigQuery dataset. Examples: "storage.googleapis.com/[GCS_BUCKET]" "bigquery.googleapis.com/projects/[PROJECT_ID]/datasets/[DATASET]" "pubsub.googleapis.com/projects/[PROJECT_ID]/topics/[TOPIC_ID]" The writer associated with the sink must have access to write to the above resource.
     */
    readonly destination: string;
    /**
     * The filter to apply when exporting logs.
     *
     * Only log entries that match the filter are exported.
     */
    readonly filter?: string;
    /**
     * The name of the logging sink.
     */
    readonly name: string;
    /**
     * bigquery_options block.
     */
    readonly bigqueryOptions?: LoggingBillingAccountSinkBigqueryOptions[];
    /**
     * exclusions block.
     */
    readonly exclusions?: LoggingBillingAccountSinkExclusions[];
}
/**
 *
 */
export interface LoggingBillingAccountSinkBigqueryOptions {
    /**
     * Whether to use BigQuery's partition tables.
     *
     * By default, Logging creates dated tables based on the log entries' timestamps, e.g. syslog_20170523. With partitioned tables the date suffix is no longer present and special query syntax has to be used instead. In both cases, tables are sharded based on UTC timezone.
     */
    readonly usePartitionedTables: boolean;
}
/**
 *
 */
export interface LoggingBillingAccountSinkExclusions {
    /**
     * A description of this exclusion.
     */
    readonly description?: string;
    /**
     * If set to True, then this exclusion is disabled and it does not exclude any log entries.
     */
    readonly disabled?: boolean;
    /**
     * An advanced logs filter that matches the log entries to be excluded.
     *
     * By using the sample function, you can exclude less than 100% of the matching log entries
     */
    readonly filter: string;
    /**
     * A client-assigned identifier, such as "load-balancer-exclusion".
     *
     * Identifiers are limited to 100 characters and can include only letters, digits, underscores, hyphens, and periods. First character has to be alphanumeric.
     */
    readonly name: string;
}
/**
 *
 */
export declare class LoggingBillingAccountSink extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: LoggingBillingAccountSinkConfig);
    private _billingAccount;
    /**
     *
     */
    get billingAccount(): string;
    /**
     *
     */
    set billingAccount(value: string);
    /**
     *
     */
    get billingAccountInput(): string;
    private _destination;
    /**
     *
     */
    get destination(): string;
    /**
     *
     */
    set destination(value: string);
    /**
     *
     */
    get destinationInput(): string;
    private _filter?;
    /**
     *
     */
    get filter(): string;
    /**
     *
     */
    set filter(value: string);
    /**
     *
     */
    resetFilter(): void;
    /**
     *
     */
    get filterInput(): string | undefined;
    /**
     *
     */
    get id(): string;
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    get nameInput(): string;
    /**
     *
     */
    get writerIdentity(): string;
    private _bigqueryOptions?;
    /**
     *
     */
    get bigqueryOptions(): LoggingBillingAccountSinkBigqueryOptions[];
    /**
     *
     */
    set bigqueryOptions(value: LoggingBillingAccountSinkBigqueryOptions[]);
    /**
     *
     */
    resetBigqueryOptions(): void;
    /**
     *
     */
    get bigqueryOptionsInput(): LoggingBillingAccountSinkBigqueryOptions[] | undefined;
    private _exclusions?;
    /**
     *
     */
    get exclusions(): LoggingBillingAccountSinkExclusions[];
    /**
     *
     */
    set exclusions(value: LoggingBillingAccountSinkExclusions[]);
    /**
     *
     */
    resetExclusions(): void;
    /**
     *
     */
    get exclusionsInput(): LoggingBillingAccountSinkExclusions[] | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
