import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface LoggingMetricConfig extends TerraformMetaArguments {
    /**
     * A description of this metric, which is used in documentation.
     *
     * The maximum length of the
     * description is 8000 characters.
     */
    readonly description?: string;
    /**
     * An advanced logs filter (https://cloud.google.com/logging/docs/view/advanced-filters) which is used to match log entries.
     */
    readonly filter: string;
    /**
     * A map from a label key string to an extractor expression which is used to extract data from a log entry field and assign as the label value.
     *
     * Each label key specified in the LabelDescriptor must
     * have an associated extractor expression in this map. The syntax of the extractor expression is
     * the same as for the valueExtractor field.
     */
    readonly labelExtractors?: {
        [key: string]: string;
    };
    /**
     * The client-assigned metric identifier.
     *
     * Examples - "error_count", "nginx/requests".
     * Metric identifiers are limited to 100 characters and can include only the following
     * characters A-Z, a-z, 0-9, and the special characters _-.,+!*',()%/. The forward-slash
     * character (/) denotes a hierarchy of name pieces, and it cannot be the first character
     * of the name.
     */
    readonly name: string;
    /**
     *
     */
    readonly project?: string;
    /**
     * A valueExtractor is required when using a distribution logs-based metric to extract the values to record from a log entry.
     *
     * Two functions are supported for value extraction - EXTRACT(field) or
     * REGEXP_EXTRACT(field, regex). The argument are 1. field - The name of the log entry field from which
     * the value is to be extracted. 2. regex - A regular expression using the Google RE2 syntax
     * (https://github.com/google/re2/wiki/Syntax) with a single capture group to extract data from the specified
     * log entry field. The value of the field is converted to a string before applying the regex. It is an
     * error to specify a regex that does not include exactly one capture group.
     */
    readonly valueExtractor?: string;
    /**
     * bucket_options block.
     */
    readonly bucketOptions?: LoggingMetricBucketOptions[];
    /**
     * metric_descriptor block.
     */
    readonly metricDescriptor: LoggingMetricMetricDescriptor[];
    /**
     * timeouts block.
     */
    readonly timeouts?: LoggingMetricTimeouts;
}
/**
 *
 */
export interface LoggingMetricBucketOptionsExplicitBuckets {
    /**
     * The values must be monotonically increasing.
     */
    readonly bounds: number[];
}
/**
 *
 */
export interface LoggingMetricBucketOptionsExponentialBuckets {
    /**
     * Must be greater than 1.
     */
    readonly growthFactor?: number;
    /**
     * Must be greater than 0.
     */
    readonly numFiniteBuckets?: number;
    /**
     * Must be greater than 0.
     */
    readonly scale?: number;
}
/**
 *
 */
export interface LoggingMetricBucketOptionsLinearBuckets {
    /**
     * Must be greater than 0.
     */
    readonly numFiniteBuckets?: number;
    /**
     * Lower bound of the first bucket.
     */
    readonly offset?: number;
    /**
     * Must be greater than 0.
     */
    readonly width?: number;
}
/**
 *
 */
export interface LoggingMetricBucketOptions {
    /**
     * explicit_buckets block.
     */
    readonly explicitBuckets?: LoggingMetricBucketOptionsExplicitBuckets[];
    /**
     * exponential_buckets block.
     */
    readonly exponentialBuckets?: LoggingMetricBucketOptionsExponentialBuckets[];
    /**
     * linear_buckets block.
     */
    readonly linearBuckets?: LoggingMetricBucketOptionsLinearBuckets[];
}
/**
 *
 */
export interface LoggingMetricMetricDescriptorLabels {
    /**
     * A human-readable description for the label.
     */
    readonly description?: string;
    /**
     * The label key.
     */
    readonly key: string;
    /**
     * The type of data that can be assigned to the label.
     *
     * Default value: "STRING" Possible values: ["BOOL", "INT64", "STRING"]
     */
    readonly valueType?: string;
}
/**
 *
 */
export interface LoggingMetricMetricDescriptor {
    /**
     * A concise name for the metric, which can be displayed in user interfaces.
     *
     * Use sentence case
     * without an ending period, for example "Request count". This field is optional but it is
     * recommended to be set for any metrics associated with user-visible concepts, such as Quota.
     */
    readonly displayName?: string;
    /**
     * Whether the metric records instantaneous values, changes to a value, etc.
     *
     * Some combinations of metricKind and valueType might not be supported.
     * For counter metrics, set this to DELTA. Possible values: ["DELTA", "GAUGE", "CUMULATIVE"]
     */
    readonly metricKind: string;
    /**
     * The unit in which the metric value is reported.
     *
     * It is only applicable if the valueType is
     * 'INT64', 'DOUBLE', or 'DISTRIBUTION'. The supported units are a subset of
     * [The Unified Code for Units of Measure](http://unitsofmeasure.org/ucum.html) standard
     */
    readonly unit?: string;
    /**
     * Whether the measurement is an integer, a floating-point number, etc.
     *
     * Some combinations of metricKind and valueType might not be supported.
     * For counter metrics, set this to INT64. Possible values: ["BOOL", "INT64", "DOUBLE", "STRING", "DISTRIBUTION", "MONEY"]
     */
    readonly valueType: string;
    /**
     * labels block.
     */
    readonly labels?: LoggingMetricMetricDescriptorLabels[];
}
/**
 *
 */
export interface LoggingMetricTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class LoggingMetric extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: LoggingMetricConfig);
    private _description?;
    /**
     *
     */
    get description(): string;
    /**
     *
     */
    set description(value: string);
    /**
     *
     */
    resetDescription(): void;
    /**
     *
     */
    get descriptionInput(): string | undefined;
    private _filter;
    /**
     *
     */
    get filter(): string;
    /**
     *
     */
    set filter(value: string);
    /**
     *
     */
    get filterInput(): string;
    /**
     *
     */
    get id(): string;
    private _labelExtractors?;
    /**
     *
     */
    get labelExtractors(): {
        [key: string]: string;
    };
    /**
     *
     */
    set labelExtractors(value: {
        [key: string]: string;
    });
    /**
     *
     */
    resetLabelExtractors(): void;
    /**
     *
     */
    get labelExtractorsInput(): {
        [key: string]: string;
    } | undefined;
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    get nameInput(): string;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _valueExtractor?;
    /**
     *
     */
    get valueExtractor(): string;
    /**
     *
     */
    set valueExtractor(value: string);
    /**
     *
     */
    resetValueExtractor(): void;
    /**
     *
     */
    get valueExtractorInput(): string | undefined;
    private _bucketOptions?;
    /**
     *
     */
    get bucketOptions(): LoggingMetricBucketOptions[];
    /**
     *
     */
    set bucketOptions(value: LoggingMetricBucketOptions[]);
    /**
     *
     */
    resetBucketOptions(): void;
    /**
     *
     */
    get bucketOptionsInput(): LoggingMetricBucketOptions[] | undefined;
    private _metricDescriptor;
    /**
     *
     */
    get metricDescriptor(): LoggingMetricMetricDescriptor[];
    /**
     *
     */
    set metricDescriptor(value: LoggingMetricMetricDescriptor[]);
    /**
     *
     */
    get metricDescriptorInput(): LoggingMetricMetricDescriptor[];
    private _timeouts?;
    /**
     *
     */
    get timeouts(): LoggingMetricTimeouts;
    /**
     *
     */
    set timeouts(value: LoggingMetricTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): LoggingMetricTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
