import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface LoggingOrganizationSinkConfig extends TerraformMetaArguments {
    /**
     * The destination of the sink (or, in other words, where logs are written to).
     *
     * Can be a Cloud Storage bucket, a PubSub topic, or a BigQuery dataset. Examples: "storage.googleapis.com/[GCS_BUCKET]" "bigquery.googleapis.com/projects/[PROJECT_ID]/datasets/[DATASET]" "pubsub.googleapis.com/projects/[PROJECT_ID]/topics/[TOPIC_ID]" The writer associated with the sink must have access to write to the above resource.
     */
    readonly destination: string;
    /**
     * The filter to apply when exporting logs.
     *
     * Only log entries that match the filter are exported.
     */
    readonly filter?: string;
    /**
     * Whether or not to include children organizations in the sink export.
     *
     * If true, logs associated with child projects are also exported; otherwise only logs relating to the provided organization are included.
     */
    readonly includeChildren?: boolean;
    /**
     * The name of the logging sink.
     */
    readonly name: string;
    /**
     * The numeric ID of the organization to be exported to the sink.
     */
    readonly orgId: string;
    /**
     * bigquery_options block.
     */
    readonly bigqueryOptions?: LoggingOrganizationSinkBigqueryOptions[];
    /**
     * exclusions block.
     */
    readonly exclusions?: LoggingOrganizationSinkExclusions[];
}
/**
 *
 */
export interface LoggingOrganizationSinkBigqueryOptions {
    /**
     * Whether to use BigQuery's partition tables.
     *
     * By default, Logging creates dated tables based on the log entries' timestamps, e.g. syslog_20170523. With partitioned tables the date suffix is no longer present and special query syntax has to be used instead. In both cases, tables are sharded based on UTC timezone.
     */
    readonly usePartitionedTables: boolean;
}
/**
 *
 */
export interface LoggingOrganizationSinkExclusions {
    /**
     * A description of this exclusion.
     */
    readonly description?: string;
    /**
     * If set to True, then this exclusion is disabled and it does not exclude any log entries.
     */
    readonly disabled?: boolean;
    /**
     * An advanced logs filter that matches the log entries to be excluded.
     *
     * By using the sample function, you can exclude less than 100% of the matching log entries
     */
    readonly filter: string;
    /**
     * A client-assigned identifier, such as "load-balancer-exclusion".
     *
     * Identifiers are limited to 100 characters and can include only letters, digits, underscores, hyphens, and periods. First character has to be alphanumeric.
     */
    readonly name: string;
}
/**
 *
 */
export declare class LoggingOrganizationSink extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: LoggingOrganizationSinkConfig);
    private _destination;
    /**
     *
     */
    get destination(): string;
    /**
     *
     */
    set destination(value: string);
    /**
     *
     */
    get destinationInput(): string;
    private _filter?;
    /**
     *
     */
    get filter(): string;
    /**
     *
     */
    set filter(value: string);
    /**
     *
     */
    resetFilter(): void;
    /**
     *
     */
    get filterInput(): string | undefined;
    /**
     *
     */
    get id(): string;
    private _includeChildren?;
    /**
     *
     */
    get includeChildren(): boolean;
    /**
     *
     */
    set includeChildren(value: boolean);
    /**
     *
     */
    resetIncludeChildren(): void;
    /**
     *
     */
    get includeChildrenInput(): boolean | undefined;
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    get nameInput(): string;
    private _orgId;
    /**
     *
     */
    get orgId(): string;
    /**
     *
     */
    set orgId(value: string);
    /**
     *
     */
    get orgIdInput(): string;
    /**
     *
     */
    get writerIdentity(): string;
    private _bigqueryOptions?;
    /**
     *
     */
    get bigqueryOptions(): LoggingOrganizationSinkBigqueryOptions[];
    /**
     *
     */
    set bigqueryOptions(value: LoggingOrganizationSinkBigqueryOptions[]);
    /**
     *
     */
    resetBigqueryOptions(): void;
    /**
     *
     */
    get bigqueryOptionsInput(): LoggingOrganizationSinkBigqueryOptions[] | undefined;
    private _exclusions?;
    /**
     *
     */
    get exclusions(): LoggingOrganizationSinkExclusions[];
    /**
     *
     */
    set exclusions(value: LoggingOrganizationSinkExclusions[]);
    /**
     *
     */
    resetExclusions(): void;
    /**
     *
     */
    get exclusionsInput(): LoggingOrganizationSinkExclusions[] | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
