import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface MlEngineModelConfig extends TerraformMetaArguments {
    /**
     * The description specified for the model when it was created.
     */
    readonly description?: string;
    /**
     * One or more labels that you can add, to organize your models.
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * The name specified for the model.
     */
    readonly name: string;
    /**
     * If true, online prediction nodes send stderr and stdout streams to Stackdriver Logging.
     */
    readonly onlinePredictionConsoleLogging?: boolean;
    /**
     * If true, online prediction access logs are sent to StackDriver Logging.
     */
    readonly onlinePredictionLogging?: boolean;
    /**
     *
     */
    readonly project?: string;
    /**
     * The list of regions where the model is going to be deployed.
     *
     * Currently only one region per model is supported
     */
    readonly regions?: string[];
    /**
     * default_version block.
     */
    readonly defaultVersion?: MlEngineModelDefaultVersion[];
    /**
     * timeouts block.
     */
    readonly timeouts?: MlEngineModelTimeouts;
}
/**
 *
 */
export interface MlEngineModelDefaultVersion {
    /**
     * The name specified for the version when it was created.
     */
    readonly name: string;
}
/**
 *
 */
export interface MlEngineModelTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
}
/**
 *
 */
export declare class MlEngineModel extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: MlEngineModelConfig);
    private _description?;
    /**
     *
     */
    get description(): string;
    /**
     *
     */
    set description(value: string);
    /**
     *
     */
    resetDescription(): void;
    /**
     *
     */
    get descriptionInput(): string | undefined;
    /**
     *
     */
    get id(): string;
    private _labels?;
    /**
     *
     */
    get labels(): {
        [key: string]: string;
    };
    /**
     *
     */
    set labels(value: {
        [key: string]: string;
    });
    /**
     *
     */
    resetLabels(): void;
    /**
     *
     */
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    get nameInput(): string;
    private _onlinePredictionConsoleLogging?;
    /**
     *
     */
    get onlinePredictionConsoleLogging(): boolean;
    /**
     *
     */
    set onlinePredictionConsoleLogging(value: boolean);
    /**
     *
     */
    resetOnlinePredictionConsoleLogging(): void;
    /**
     *
     */
    get onlinePredictionConsoleLoggingInput(): boolean | undefined;
    private _onlinePredictionLogging?;
    /**
     *
     */
    get onlinePredictionLogging(): boolean;
    /**
     *
     */
    set onlinePredictionLogging(value: boolean);
    /**
     *
     */
    resetOnlinePredictionLogging(): void;
    /**
     *
     */
    get onlinePredictionLoggingInput(): boolean | undefined;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _regions?;
    /**
     *
     */
    get regions(): string[];
    /**
     *
     */
    set regions(value: string[]);
    /**
     *
     */
    resetRegions(): void;
    /**
     *
     */
    get regionsInput(): string[] | undefined;
    private _defaultVersion?;
    /**
     *
     */
    get defaultVersion(): MlEngineModelDefaultVersion[];
    /**
     *
     */
    set defaultVersion(value: MlEngineModelDefaultVersion[]);
    /**
     *
     */
    resetDefaultVersion(): void;
    /**
     *
     */
    get defaultVersionInput(): MlEngineModelDefaultVersion[] | undefined;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): MlEngineModelTimeouts;
    /**
     *
     */
    set timeouts(value: MlEngineModelTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): MlEngineModelTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
