import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface MonitoringGroupConfig extends TerraformMetaArguments {
    /**
     * A user-assigned name for this group, used only for display purposes.
     */
    readonly displayName: string;
    /**
     * The filter used to determine which monitored resources belong to this group.
     */
    readonly filter: string;
    /**
     * If true, the members of this group are considered to be a cluster.
     *
     * The system can perform additional analysis on
     * groups that are clusters.
     */
    readonly isCluster?: boolean;
    /**
     * The name of the group's parent, if it has one.
     *
     * The format is
     * "projects/{project_id_or_number}/groups/{group_id}". For
     * groups with no parent, parentName is the empty string, "".
     */
    readonly parentName?: string;
    /**
     *
     */
    readonly project?: string;
    /**
     * timeouts block.
     */
    readonly timeouts?: MonitoringGroupTimeouts;
}
/**
 *
 */
export interface MonitoringGroupTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class MonitoringGroup extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: MonitoringGroupConfig);
    private _displayName;
    /**
     *
     */
    get displayName(): string;
    /**
     *
     */
    set displayName(value: string);
    /**
     *
     */
    get displayNameInput(): string;
    private _filter;
    /**
     *
     */
    get filter(): string;
    /**
     *
     */
    set filter(value: string);
    /**
     *
     */
    get filterInput(): string;
    /**
     *
     */
    get id(): string;
    private _isCluster?;
    /**
     *
     */
    get isCluster(): boolean;
    /**
     *
     */
    set isCluster(value: boolean);
    /**
     *
     */
    resetIsCluster(): void;
    /**
     *
     */
    get isClusterInput(): boolean | undefined;
    /**
     *
     */
    get name(): string;
    private _parentName?;
    /**
     *
     */
    get parentName(): string;
    /**
     *
     */
    set parentName(value: string);
    /**
     *
     */
    resetParentName(): void;
    /**
     *
     */
    get parentNameInput(): string | undefined;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): MonitoringGroupTimeouts;
    /**
     *
     */
    set timeouts(value: MonitoringGroupTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): MonitoringGroupTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
