import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface MonitoringMetricDescriptorConfig extends TerraformMetaArguments {
    /**
     * A detailed description of the metric, which can be used in documentation.
     */
    readonly description: string;
    /**
     * A concise name for the metric, which can be displayed in user interfaces.
     *
     * Use sentence case without an ending period, for example "Request count".
     */
    readonly displayName: string;
    /**
     * The launch stage of the metric definition.
     *
     * Possible values: ["LAUNCH_STAGE_UNSPECIFIED", "UNIMPLEMENTED", "PRELAUNCH", "EARLY_ACCESS", "ALPHA", "BETA", "GA", "DEPRECATED"]
     */
    readonly launchStage?: string;
    /**
     * Whether the metric records instantaneous values, changes to a value, etc.
     *
     * Some combinations of metricKind and valueType might not be supported. Possible values: ["METRIC_KIND_UNSPECIFIED", "GAUGE", "DELTA", "CUMULATIVE"]
     */
    readonly metricKind: string;
    /**
     *
     */
    readonly project?: string;
    /**
     * The metric type, including its DNS name prefix.
     *
     * The type is not URL-encoded. All service defined metrics must be prefixed with the service name, in the format of {service name}/{relative metric name}, such as cloudsql.googleapis.com/database/cpu/utilization. The relative metric name must have only upper and lower-case letters, digits, '/' and underscores '_' are allowed. Additionally, the maximum number of characters allowed for the relative_metric_name is 100. All user-defined metric types have the DNS name custom.googleapis.com, external.googleapis.com, or logging.googleapis.com/user/.
     */
    readonly type: string;
    /**
     * The units in which the metric value is reported.
     *
     * It is only applicable if the
     * valueType is INT64, DOUBLE, or DISTRIBUTION. The unit defines the representation of
     * the stored metric values.
     *
     * Different systems may scale the values to be more easily displayed (so a value of
     * 0.02KBy might be displayed as 20By, and a value of 3523KBy might be displayed as
     * 3.5MBy). However, if the unit is KBy, then the value of the metric is always in
     * thousands of bytes, no matter how it may be displayed.
     *
     * If you want a custom metric to record the exact number of CPU-seconds used by a job,
     * you can create an INT64 CUMULATIVE metric whose unit is s{CPU} (or equivalently
     * 1s{CPU} or just s). If the job uses 12,005 CPU-seconds, then the value is written as
     * 12005.
     *
     * Alternatively, if you want a custom metric to record data in a more granular way, you
     * can create a DOUBLE CUMULATIVE metric whose unit is ks{CPU}, and then write the value
     * 12.005 (which is 12005/1000), or use Kis{CPU} and write 11.723 (which is 12005/1024).
     * The supported units are a subset of The Unified Code for Units of Measure standard.
     * More info can be found in the API documentation
     * (https://cloud.google.com/monitoring/api/ref_v3/rest/v3/projects.metricDescriptors).
     */
    readonly unit?: string;
    /**
     * Whether the measurement is an integer, a floating-point number, etc.
     *
     * Some combinations of metricKind and valueType might not be supported. Possible values: ["BOOL", "INT64", "DOUBLE", "STRING", "DISTRIBUTION"]
     */
    readonly valueType: string;
    /**
     * labels block.
     */
    readonly labels?: MonitoringMetricDescriptorLabels[];
    /**
     * metadata block.
     */
    readonly metadata?: MonitoringMetricDescriptorMetadata[];
    /**
     * timeouts block.
     */
    readonly timeouts?: MonitoringMetricDescriptorTimeouts;
}
/**
 *
 */
export interface MonitoringMetricDescriptorLabels {
    /**
     * A human-readable description for the label.
     */
    readonly description?: string;
    /**
     * The key for this label.
     *
     * The key must not exceed 100 characters. The first character of the key must be an upper- or lower-case letter, the remaining characters must be letters, digits or underscores, and the key must match the regular expression [a-zA-Z][a-zA-Z0-9_]*
     */
    readonly key: string;
    /**
     * The type of data that can be assigned to the label.
     *
     * Default value: "STRING" Possible values: ["STRING", "BOOL", "INT64"]
     */
    readonly valueType?: string;
}
/**
 *
 */
export interface MonitoringMetricDescriptorMetadata {
    /**
     * The delay of data points caused by ingestion.
     *
     * Data points older than this age are guaranteed to be ingested and available to be read, excluding data loss due to errors. In '[duration format](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf?&_ga=2.264881487.1507873253.1593446723-935052455.1591817775#google.protobuf.Duration)'.
     */
    readonly ingestDelay?: string;
    /**
     * The sampling period of metric data points.
     *
     * For metrics which are written periodically, consecutive data points are stored at this time interval, excluding data loss due to errors. Metrics with a higher granularity have a smaller sampling period. In '[duration format](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf?&_ga=2.264881487.1507873253.1593446723-935052455.1591817775#google.protobuf.Duration)'.
     */
    readonly samplePeriod?: string;
}
/**
 *
 */
export interface MonitoringMetricDescriptorTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class MonitoringMetricDescriptor extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: MonitoringMetricDescriptorConfig);
    private _description;
    /**
     *
     */
    get description(): string;
    /**
     *
     */
    set description(value: string);
    /**
     *
     */
    get descriptionInput(): string;
    private _displayName;
    /**
     *
     */
    get displayName(): string;
    /**
     *
     */
    set displayName(value: string);
    /**
     *
     */
    get displayNameInput(): string;
    /**
     *
     */
    get id(): string;
    private _launchStage?;
    /**
     *
     */
    get launchStage(): string;
    /**
     *
     */
    set launchStage(value: string);
    /**
     *
     */
    resetLaunchStage(): void;
    /**
     *
     */
    get launchStageInput(): string | undefined;
    private _metricKind;
    /**
     *
     */
    get metricKind(): string;
    /**
     *
     */
    set metricKind(value: string);
    /**
     *
     */
    get metricKindInput(): string;
    /**
     *
     */
    get monitoredResourceTypes(): string[];
    /**
     *
     */
    get name(): string;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _type;
    /**
     *
     */
    get type(): string;
    /**
     *
     */
    set type(value: string);
    /**
     *
     */
    get typeInput(): string;
    private _unit?;
    /**
     *
     */
    get unit(): string;
    /**
     *
     */
    set unit(value: string);
    /**
     *
     */
    resetUnit(): void;
    /**
     *
     */
    get unitInput(): string | undefined;
    private _valueType;
    /**
     *
     */
    get valueType(): string;
    /**
     *
     */
    set valueType(value: string);
    /**
     *
     */
    get valueTypeInput(): string;
    private _labels?;
    /**
     *
     */
    get labels(): MonitoringMetricDescriptorLabels[];
    /**
     *
     */
    set labels(value: MonitoringMetricDescriptorLabels[]);
    /**
     *
     */
    resetLabels(): void;
    /**
     *
     */
    get labelsInput(): MonitoringMetricDescriptorLabels[] | undefined;
    private _metadata?;
    /**
     *
     */
    get metadata(): MonitoringMetricDescriptorMetadata[];
    /**
     *
     */
    set metadata(value: MonitoringMetricDescriptorMetadata[]);
    /**
     *
     */
    resetMetadata(): void;
    /**
     *
     */
    get metadataInput(): MonitoringMetricDescriptorMetadata[] | undefined;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): MonitoringMetricDescriptorTimeouts;
    /**
     *
     */
    set timeouts(value: MonitoringMetricDescriptorTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): MonitoringMetricDescriptorTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
