import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface MonitoringNotificationChannelConfig extends TerraformMetaArguments {
    /**
     * An optional human-readable description of this notification channel.
     *
     * This description may provide additional details, beyond the display name, for the channel. This may not exceed 1024 Unicode characters.
     */
    readonly description?: string;
    /**
     * An optional human-readable name for this notification channel.
     *
     * It is recommended that you specify a non-empty and unique name in order to make it easier to identify the channels in your project, though this is not enforced. The display name is limited to 512 Unicode characters.
     */
    readonly displayName?: string;
    /**
     * Whether notifications are forwarded to the described channel.
     *
     * This makes it possible to disable delivery of notifications to a particular channel without removing the channel from all alerting policies that reference the channel. This is a more convenient approach when the change is temporary and you want to receive notifications from the same set of alerting policies on the channel at some point in the future.
     */
    readonly enabled?: boolean;
    /**
     * Configuration fields that define the channel and its behavior.
     *
     * The
     * permissible and required labels are specified in the
     * NotificationChannelDescriptor corresponding to the type field.
     *
     * Labels with sensitive data are obfuscated by the API and therefore Terraform cannot
     * determine if there are upstream changes to these fields. They can also be configured via
     * the sensitive_labels block, but cannot be configured in both places.
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     *
     */
    readonly project?: string;
    /**
     * The type of the notification channel.
     *
     * This field matches the value of the NotificationChannelDescriptor.type field. See https://cloud.google.com/monitoring/api/ref_v3/rest/v3/projects.notificationChannelDescriptors/list to get the list of valid values such as "email", "slack", etc...
     */
    readonly type: string;
    /**
     * User-supplied key/value data that does not need to conform to the corresponding NotificationChannelDescriptor's schema, unlike the labels field.
     *
     * This field is intended to be used for organizing and identifying the NotificationChannel objects.The field can contain up to 64 entries. Each key and value is limited to 63 Unicode characters or 128 bytes, whichever is smaller. Labels and values can contain only lowercase letters, numerals, underscores, and dashes. Keys must begin with a letter.
     */
    readonly userLabels?: {
        [key: string]: string;
    };
    /**
     * sensitive_labels block.
     */
    readonly sensitiveLabels?: MonitoringNotificationChannelSensitiveLabels[];
    /**
     * timeouts block.
     */
    readonly timeouts?: MonitoringNotificationChannelTimeouts;
}
/**
 *
 */
export interface MonitoringNotificationChannelSensitiveLabels {
    /**
     * An authorization token for a notification channel.
     *
     * Channel types that support this field include: slack
     */
    readonly authToken?: string;
    /**
     * An password for a notification channel.
     *
     * Channel types that support this field include: webhook_basicauth
     */
    readonly password?: string;
    /**
     * An servicekey token for a notification channel.
     *
     * Channel types that support this field include: pagerduty
     */
    readonly serviceKey?: string;
}
/**
 *
 */
export interface MonitoringNotificationChannelTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class MonitoringNotificationChannel extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: MonitoringNotificationChannelConfig);
    private _description?;
    /**
     *
     */
    get description(): string;
    /**
     *
     */
    set description(value: string);
    /**
     *
     */
    resetDescription(): void;
    /**
     *
     */
    get descriptionInput(): string | undefined;
    private _displayName?;
    /**
     *
     */
    get displayName(): string;
    /**
     *
     */
    set displayName(value: string);
    /**
     *
     */
    resetDisplayName(): void;
    /**
     *
     */
    get displayNameInput(): string | undefined;
    private _enabled?;
    /**
     *
     */
    get enabled(): boolean;
    /**
     *
     */
    set enabled(value: boolean);
    /**
     *
     */
    resetEnabled(): void;
    /**
     *
     */
    get enabledInput(): boolean | undefined;
    /**
     *
     */
    get id(): string;
    private _labels?;
    /**
     *
     */
    get labels(): {
        [key: string]: string;
    };
    /**
     *
     */
    set labels(value: {
        [key: string]: string;
    });
    /**
     *
     */
    resetLabels(): void;
    /**
     *
     */
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    /**
     *
     */
    get name(): string;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _type;
    /**
     *
     */
    get type(): string;
    /**
     *
     */
    set type(value: string);
    /**
     *
     */
    get typeInput(): string;
    private _userLabels?;
    /**
     *
     */
    get userLabels(): {
        [key: string]: string;
    };
    /**
     *
     */
    set userLabels(value: {
        [key: string]: string;
    });
    /**
     *
     */
    resetUserLabels(): void;
    /**
     *
     */
    get userLabelsInput(): {
        [key: string]: string;
    } | undefined;
    /**
     *
     */
    get verificationStatus(): string;
    private _sensitiveLabels?;
    /**
     *
     */
    get sensitiveLabels(): MonitoringNotificationChannelSensitiveLabels[];
    /**
     *
     */
    set sensitiveLabels(value: MonitoringNotificationChannelSensitiveLabels[]);
    /**
     *
     */
    resetSensitiveLabels(): void;
    /**
     *
     */
    get sensitiveLabelsInput(): MonitoringNotificationChannelSensitiveLabels[] | undefined;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): MonitoringNotificationChannelTimeouts;
    /**
     *
     */
    set timeouts(value: MonitoringNotificationChannelTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): MonitoringNotificationChannelTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
