import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface NetworkManagementConnectivityTestConfig extends TerraformMetaArguments {
    /**
     * The user-supplied description of the Connectivity Test.
     *
     * Maximum of 512 characters.
     */
    readonly description?: string;
    /**
     * Resource labels to represent user-provided metadata.
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Unique name for the connectivity test.
     */
    readonly name: string;
    /**
     *
     */
    readonly project?: string;
    /**
     * IP Protocol of the test.
     *
     * When not provided, "TCP" is assumed.
     */
    readonly protocol?: string;
    /**
     * Other projects that may be relevant for reachability analysis.
     *
     * This is applicable to scenarios where a test can cross project
     * boundaries.
     */
    readonly relatedProjects?: string[];
    /**
     * destination block.
     */
    readonly destination: NetworkManagementConnectivityTestDestination[];
    /**
     * source block.
     */
    readonly source: NetworkManagementConnectivityTestSource[];
    /**
     * timeouts block.
     */
    readonly timeouts?: NetworkManagementConnectivityTestTimeouts;
}
/**
 *
 */
export interface NetworkManagementConnectivityTestDestination {
    /**
     * A Compute Engine instance URI.
     */
    readonly instance?: string;
    /**
     * The IP address of the endpoint, which can be an external or internal IP.
     *
     * An IPv6 address is only allowed when the test's
     * destination is a global load balancer VIP.
     */
    readonly ipAddress?: string;
    /**
     * A Compute Engine network URI.
     */
    readonly network?: string;
    /**
     * The IP protocol port of the endpoint.
     *
     * Only applicable when
     * protocol is TCP or UDP.
     */
    readonly port?: number;
    /**
     * Project ID where the endpoint is located.
     *
     * The Project ID can be
     * derived from the URI if you provide a VM instance or network URI.
     * The following are two cases where you must provide the project ID:
     * 1. Only the IP address is specified, and the IP address is within
     * a GCP project. 2. When you are using Shared VPC and the IP address
     * that you provide is from the service project. In this case, the
     * network that the IP address resides in is defined in the host
     * project.
     */
    readonly projectId?: string;
}
/**
 *
 */
export interface NetworkManagementConnectivityTestSource {
    /**
     * A Compute Engine instance URI.
     */
    readonly instance?: string;
    /**
     * The IP address of the endpoint, which can be an external or internal IP.
     *
     * An IPv6 address is only allowed when the test's
     * destination is a global load balancer VIP.
     */
    readonly ipAddress?: string;
    /**
     * A Compute Engine network URI.
     */
    readonly network?: string;
    /**
     * Type of the network where the endpoint is located.
     *
     * Possible values: ["GCP_NETWORK", "NON_GCP_NETWORK"]
     */
    readonly networkType?: string;
    /**
     * The IP protocol port of the endpoint.
     *
     * Only applicable when
     * protocol is TCP or UDP.
     */
    readonly port?: number;
    /**
     * Project ID where the endpoint is located.
     *
     * The Project ID can be
     * derived from the URI if you provide a VM instance or network URI.
     * The following are two cases where you must provide the project ID:
     *
     * 1. Only the IP address is specified, and the IP address is
     * within a GCP project.
     * 2. When you are using Shared VPC and the IP address
     * that you provide is from the service project. In this case,
     * the network that the IP address resides in is defined in the
     * host project.
     */
    readonly projectId?: string;
}
/**
 *
 */
export interface NetworkManagementConnectivityTestTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class NetworkManagementConnectivityTest extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: NetworkManagementConnectivityTestConfig);
    private _description?;
    /**
     *
     */
    get description(): string;
    /**
     *
     */
    set description(value: string);
    /**
     *
     */
    resetDescription(): void;
    /**
     *
     */
    get descriptionInput(): string | undefined;
    /**
     *
     */
    get id(): string;
    private _labels?;
    /**
     *
     */
    get labels(): {
        [key: string]: string;
    };
    /**
     *
     */
    set labels(value: {
        [key: string]: string;
    });
    /**
     *
     */
    resetLabels(): void;
    /**
     *
     */
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    get nameInput(): string;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _protocol?;
    /**
     *
     */
    get protocol(): string;
    /**
     *
     */
    set protocol(value: string);
    /**
     *
     */
    resetProtocol(): void;
    /**
     *
     */
    get protocolInput(): string | undefined;
    private _relatedProjects?;
    /**
     *
     */
    get relatedProjects(): string[];
    /**
     *
     */
    set relatedProjects(value: string[]);
    /**
     *
     */
    resetRelatedProjects(): void;
    /**
     *
     */
    get relatedProjectsInput(): string[] | undefined;
    private _destination;
    /**
     *
     */
    get destination(): NetworkManagementConnectivityTestDestination[];
    /**
     *
     */
    set destination(value: NetworkManagementConnectivityTestDestination[]);
    /**
     *
     */
    get destinationInput(): NetworkManagementConnectivityTestDestination[];
    private _source;
    /**
     *
     */
    get source(): NetworkManagementConnectivityTestSource[];
    /**
     *
     */
    set source(value: NetworkManagementConnectivityTestSource[]);
    /**
     *
     */
    get sourceInput(): NetworkManagementConnectivityTestSource[];
    private _timeouts?;
    /**
     *
     */
    get timeouts(): NetworkManagementConnectivityTestTimeouts;
    /**
     *
     */
    set timeouts(value: NetworkManagementConnectivityTestTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): NetworkManagementConnectivityTestTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
