import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface OrganizationPolicyConfig extends TerraformMetaArguments {
    /**
     * The name of the Constraint the Policy is configuring, for example, serviceuser.services.
     */
    readonly constraint: string;
    /**
     *
     */
    readonly orgId: string;
    /**
     * Version of the Policy.
     *
     * Default version is 0.
     */
    readonly version?: number;
    /**
     * boolean_policy block.
     */
    readonly booleanPolicy?: OrganizationPolicyBooleanPolicy[];
    /**
     * list_policy block.
     */
    readonly listPolicy?: OrganizationPolicyListPolicy[];
    /**
     * restore_policy block.
     */
    readonly restorePolicy?: OrganizationPolicyRestorePolicy[];
    /**
     * timeouts block.
     */
    readonly timeouts?: OrganizationPolicyTimeouts;
}
/**
 *
 */
export interface OrganizationPolicyBooleanPolicy {
    /**
     * If true, then the Policy is enforced.
     *
     * If false, then any configuration is acceptable.
     */
    readonly enforced: boolean;
}
/**
 *
 */
export interface OrganizationPolicyListPolicyAllow {
    /**
     * The policy allows or denies all values.
     */
    readonly all?: boolean;
    /**
     * The policy can define specific values that are allowed or denied.
     */
    readonly values?: string[];
}
/**
 *
 */
export interface OrganizationPolicyListPolicyDeny {
    /**
     * The policy allows or denies all values.
     */
    readonly all?: boolean;
    /**
     * The policy can define specific values that are allowed or denied.
     */
    readonly values?: string[];
}
/**
 *
 */
export interface OrganizationPolicyListPolicy {
    /**
     * If set to true, the values from the effective Policy of the parent resource are inherited, meaning the values set in this Policy are added to the values inherited up the hierarchy.
     */
    readonly inheritFromParent?: boolean;
    /**
     * The Google Cloud Console will try to default to a configuration that matches the value specified in this field.
     */
    readonly suggestedValue?: string;
    /**
     * allow block.
     */
    readonly allow?: OrganizationPolicyListPolicyAllow[];
    /**
     * deny block.
     */
    readonly deny?: OrganizationPolicyListPolicyDeny[];
}
/**
 *
 */
export interface OrganizationPolicyRestorePolicy {
    /**
     * May only be set to true.
     *
     * If set, then the default Policy is restored.
     */
    readonly default: boolean;
}
/**
 *
 */
export interface OrganizationPolicyTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly read?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class OrganizationPolicy extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: OrganizationPolicyConfig);
    private _constraint;
    /**
     *
     */
    get constraint(): string;
    /**
     *
     */
    set constraint(value: string);
    /**
     *
     */
    get constraintInput(): string;
    /**
     *
     */
    get etag(): string;
    /**
     *
     */
    get id(): string;
    private _orgId;
    /**
     *
     */
    get orgId(): string;
    /**
     *
     */
    set orgId(value: string);
    /**
     *
     */
    get orgIdInput(): string;
    /**
     *
     */
    get updateTime(): string;
    private _version?;
    /**
     *
     */
    get version(): number;
    /**
     *
     */
    set version(value: number);
    /**
     *
     */
    resetVersion(): void;
    /**
     *
     */
    get versionInput(): number | undefined;
    private _booleanPolicy?;
    /**
     *
     */
    get booleanPolicy(): OrganizationPolicyBooleanPolicy[];
    /**
     *
     */
    set booleanPolicy(value: OrganizationPolicyBooleanPolicy[]);
    /**
     *
     */
    resetBooleanPolicy(): void;
    /**
     *
     */
    get booleanPolicyInput(): OrganizationPolicyBooleanPolicy[] | undefined;
    private _listPolicy?;
    /**
     *
     */
    get listPolicy(): OrganizationPolicyListPolicy[];
    /**
     *
     */
    set listPolicy(value: OrganizationPolicyListPolicy[]);
    /**
     *
     */
    resetListPolicy(): void;
    /**
     *
     */
    get listPolicyInput(): OrganizationPolicyListPolicy[] | undefined;
    private _restorePolicy?;
    /**
     *
     */
    get restorePolicy(): OrganizationPolicyRestorePolicy[];
    /**
     *
     */
    set restorePolicy(value: OrganizationPolicyRestorePolicy[]);
    /**
     *
     */
    resetRestorePolicy(): void;
    /**
     *
     */
    get restorePolicyInput(): OrganizationPolicyRestorePolicy[] | undefined;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): OrganizationPolicyTimeouts;
    /**
     *
     */
    set timeouts(value: OrganizationPolicyTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): OrganizationPolicyTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
