import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface ProjectAccessApprovalSettingsConfig extends TerraformMetaArguments {
    /**
     * A list of email addresses to which notifications relating to approval requests should be sent.
     *
     * Notifications relating to a resource will be sent to all emails in the settings of ancestor
     * resources of that resource. A maximum of 50 email addresses are allowed.
     */
    readonly notificationEmails?: string[];
    /**
     *
     */
    readonly project?: string;
    /**
     * ID of the project of the access approval settings.
     */
    readonly projectId: string;
    /**
     * enrolled_services block.
     */
    readonly enrolledServices: ProjectAccessApprovalSettingsEnrolledServices[];
    /**
     * timeouts block.
     */
    readonly timeouts?: ProjectAccessApprovalSettingsTimeouts;
}
/**
 *
 */
export interface ProjectAccessApprovalSettingsEnrolledServices {
    /**
     * The product for which Access Approval will be enrolled.
     *
     * Allowed values are listed (case-sensitive):
     * all
     * appengine.googleapis.com
     * bigquery.googleapis.com
     * bigtable.googleapis.com
     * cloudkms.googleapis.com
     * compute.googleapis.com
     * dataflow.googleapis.com
     * iam.googleapis.com
     * pubsub.googleapis.com
     * storage.googleapis.com
     */
    readonly cloudProduct: string;
    /**
     * The enrollment level of the service.
     *
     * Default value: "BLOCK_ALL" Possible values: ["BLOCK_ALL"]
     */
    readonly enrollmentLevel?: string;
}
/**
 *
 */
export interface ProjectAccessApprovalSettingsTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class ProjectAccessApprovalSettings extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: ProjectAccessApprovalSettingsConfig);
    /**
     *
     */
    get enrolledAncestor(): boolean;
    /**
     *
     */
    get id(): string;
    /**
     *
     */
    get name(): string;
    private _notificationEmails?;
    /**
     *
     */
    get notificationEmails(): string[];
    /**
     *
     */
    set notificationEmails(value: string[]);
    /**
     *
     */
    resetNotificationEmails(): void;
    /**
     *
     */
    get notificationEmailsInput(): string[] | undefined;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _projectId;
    /**
     *
     */
    get projectId(): string;
    /**
     *
     */
    set projectId(value: string);
    /**
     *
     */
    get projectIdInput(): string;
    private _enrolledServices;
    /**
     *
     */
    get enrolledServices(): ProjectAccessApprovalSettingsEnrolledServices[];
    /**
     *
     */
    set enrolledServices(value: ProjectAccessApprovalSettingsEnrolledServices[]);
    /**
     *
     */
    get enrolledServicesInput(): ProjectAccessApprovalSettingsEnrolledServices[];
    private _timeouts?;
    /**
     *
     */
    get timeouts(): ProjectAccessApprovalSettingsTimeouts;
    /**
     *
     */
    set timeouts(value: ProjectAccessApprovalSettingsTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): ProjectAccessApprovalSettingsTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
