import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface ProjectOrganizationPolicyConfig extends TerraformMetaArguments {
    /**
     * The name of the Constraint the Policy is configuring, for example, serviceuser.services.
     */
    readonly constraint: string;
    /**
     * The project ID.
     */
    readonly project: string;
    /**
     * Version of the Policy.
     *
     * Default version is 0.
     */
    readonly version?: number;
    /**
     * boolean_policy block.
     */
    readonly booleanPolicy?: ProjectOrganizationPolicyBooleanPolicy[];
    /**
     * list_policy block.
     */
    readonly listPolicy?: ProjectOrganizationPolicyListPolicy[];
    /**
     * restore_policy block.
     */
    readonly restorePolicy?: ProjectOrganizationPolicyRestorePolicy[];
    /**
     * timeouts block.
     */
    readonly timeouts?: ProjectOrganizationPolicyTimeouts;
}
/**
 *
 */
export interface ProjectOrganizationPolicyBooleanPolicy {
    /**
     * If true, then the Policy is enforced.
     *
     * If false, then any configuration is acceptable.
     */
    readonly enforced: boolean;
}
/**
 *
 */
export interface ProjectOrganizationPolicyListPolicyAllow {
    /**
     * The policy allows or denies all values.
     */
    readonly all?: boolean;
    /**
     * The policy can define specific values that are allowed or denied.
     */
    readonly values?: string[];
}
/**
 *
 */
export interface ProjectOrganizationPolicyListPolicyDeny {
    /**
     * The policy allows or denies all values.
     */
    readonly all?: boolean;
    /**
     * The policy can define specific values that are allowed or denied.
     */
    readonly values?: string[];
}
/**
 *
 */
export interface ProjectOrganizationPolicyListPolicy {
    /**
     * If set to true, the values from the effective Policy of the parent resource are inherited, meaning the values set in this Policy are added to the values inherited up the hierarchy.
     */
    readonly inheritFromParent?: boolean;
    /**
     * The Google Cloud Console will try to default to a configuration that matches the value specified in this field.
     */
    readonly suggestedValue?: string;
    /**
     * allow block.
     */
    readonly allow?: ProjectOrganizationPolicyListPolicyAllow[];
    /**
     * deny block.
     */
    readonly deny?: ProjectOrganizationPolicyListPolicyDeny[];
}
/**
 *
 */
export interface ProjectOrganizationPolicyRestorePolicy {
    /**
     * May only be set to true.
     *
     * If set, then the default Policy is restored.
     */
    readonly default: boolean;
}
/**
 *
 */
export interface ProjectOrganizationPolicyTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly read?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class ProjectOrganizationPolicy extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: ProjectOrganizationPolicyConfig);
    private _constraint;
    /**
     *
     */
    get constraint(): string;
    /**
     *
     */
    set constraint(value: string);
    /**
     *
     */
    get constraintInput(): string;
    /**
     *
     */
    get etag(): string;
    /**
     *
     */
    get id(): string;
    private _project;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    get projectInput(): string;
    /**
     *
     */
    get updateTime(): string;
    private _version?;
    /**
     *
     */
    get version(): number;
    /**
     *
     */
    set version(value: number);
    /**
     *
     */
    resetVersion(): void;
    /**
     *
     */
    get versionInput(): number | undefined;
    private _booleanPolicy?;
    /**
     *
     */
    get booleanPolicy(): ProjectOrganizationPolicyBooleanPolicy[];
    /**
     *
     */
    set booleanPolicy(value: ProjectOrganizationPolicyBooleanPolicy[]);
    /**
     *
     */
    resetBooleanPolicy(): void;
    /**
     *
     */
    get booleanPolicyInput(): ProjectOrganizationPolicyBooleanPolicy[] | undefined;
    private _listPolicy?;
    /**
     *
     */
    get listPolicy(): ProjectOrganizationPolicyListPolicy[];
    /**
     *
     */
    set listPolicy(value: ProjectOrganizationPolicyListPolicy[]);
    /**
     *
     */
    resetListPolicy(): void;
    /**
     *
     */
    get listPolicyInput(): ProjectOrganizationPolicyListPolicy[] | undefined;
    private _restorePolicy?;
    /**
     *
     */
    get restorePolicy(): ProjectOrganizationPolicyRestorePolicy[];
    /**
     *
     */
    set restorePolicy(value: ProjectOrganizationPolicyRestorePolicy[]);
    /**
     *
     */
    resetRestorePolicy(): void;
    /**
     *
     */
    get restorePolicyInput(): ProjectOrganizationPolicyRestorePolicy[] | undefined;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): ProjectOrganizationPolicyTimeouts;
    /**
     *
     */
    set timeouts(value: ProjectOrganizationPolicyTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): ProjectOrganizationPolicyTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
