import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface RedisInstanceConfig extends TerraformMetaArguments {
    /**
     * Only applicable to STANDARD_HA tier which protects the instance against zonal failures by provisioning it across two zones.
     *
     * If provided, it must be a different zone from the one provided in
     * [locationId].
     */
    readonly alternativeLocationId?: string;
    /**
     * The full name of the Google Compute Engine network to which the instance is connected.
     *
     * If left unspecified, the default network
     * will be used.
     */
    readonly authorizedNetwork?: string;
    /**
     * The connection mode of the Redis instance.
     *
     * Default value: "DIRECT_PEERING" Possible values: ["DIRECT_PEERING", "PRIVATE_SERVICE_ACCESS"]
     */
    readonly connectMode?: string;
    /**
     * An arbitrary and optional user-provided name for the instance.
     */
    readonly displayName?: string;
    /**
     * Resource labels to represent user provided metadata.
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * The zone where the instance will be provisioned.
     *
     * If not provided,
     * the service will choose a zone for the instance. For STANDARD_HA tier,
     * instances will be created across two zones for protection against
     * zonal failures. If [alternativeLocationId] is also provided, it must
     * be different from [locationId].
     */
    readonly locationId?: string;
    /**
     * Redis memory size in GiB.
     */
    readonly memorySizeGb: number;
    /**
     * The ID of the instance or a fully qualified identifier for the instance.
     */
    readonly name: string;
    /**
     *
     */
    readonly project?: string;
    /**
     * Redis configuration parameters, according to http://redis.io/topics/config. Please check Memorystore documentation for the list of supported parameters: https://cloud.google.com/memorystore/docs/redis/reference/rest/v1/projects.locations.instances#Instance.FIELDS.redis_configs.
     */
    readonly redisConfigs?: {
        [key: string]: string;
    };
    /**
     * The version of Redis software. If not provided, latest supported version will be used. Currently, the supported values are:.
     *
     * - REDIS_5_0 for Redis 5.0 compatibility
     * - REDIS_4_0 for Redis 4.0 compatibility
     * - REDIS_3_2 for Redis 3.2 compatibility
     */
    readonly redisVersion?: string;
    /**
     * The name of the Redis region of the instance.
     */
    readonly region?: string;
    /**
     * The CIDR range of internal addresses that are reserved for this instance.
     *
     * If not provided, the service will choose an unused /29
     * block, for example, 10.0.0.0/29 or 192.168.0.0/29. Ranges must be
     * unique and non-overlapping with existing subnets in an authorized
     * network.
     */
    readonly reservedIpRange?: string;
    /**
     * The service tier of the instance. Must be one of these values:.
     *
     * - BASIC: standalone instance
     * - STANDARD_HA: highly available primary/replica instances Default value: "BASIC" Possible values: ["BASIC", "STANDARD_HA"]
     */
    readonly tier?: string;
    /**
     * timeouts block.
     */
    readonly timeouts?: RedisInstanceTimeouts;
}
/**
 *
 */
export interface RedisInstanceTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class RedisInstance extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: RedisInstanceConfig);
    private _alternativeLocationId?;
    /**
     *
     */
    get alternativeLocationId(): string;
    /**
     *
     */
    set alternativeLocationId(value: string);
    /**
     *
     */
    resetAlternativeLocationId(): void;
    /**
     *
     */
    get alternativeLocationIdInput(): string | undefined;
    private _authorizedNetwork?;
    /**
     *
     */
    get authorizedNetwork(): string;
    /**
     *
     */
    set authorizedNetwork(value: string);
    /**
     *
     */
    resetAuthorizedNetwork(): void;
    /**
     *
     */
    get authorizedNetworkInput(): string | undefined;
    private _connectMode?;
    /**
     *
     */
    get connectMode(): string;
    /**
     *
     */
    set connectMode(value: string);
    /**
     *
     */
    resetConnectMode(): void;
    /**
     *
     */
    get connectModeInput(): string | undefined;
    /**
     *
     */
    get createTime(): string;
    /**
     *
     */
    get currentLocationId(): string;
    private _displayName?;
    /**
     *
     */
    get displayName(): string;
    /**
     *
     */
    set displayName(value: string);
    /**
     *
     */
    resetDisplayName(): void;
    /**
     *
     */
    get displayNameInput(): string | undefined;
    /**
     *
     */
    get host(): string;
    /**
     *
     */
    get id(): string;
    private _labels?;
    /**
     *
     */
    get labels(): {
        [key: string]: string;
    };
    /**
     *
     */
    set labels(value: {
        [key: string]: string;
    });
    /**
     *
     */
    resetLabels(): void;
    /**
     *
     */
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _locationId?;
    /**
     *
     */
    get locationId(): string;
    /**
     *
     */
    set locationId(value: string);
    /**
     *
     */
    resetLocationId(): void;
    /**
     *
     */
    get locationIdInput(): string | undefined;
    private _memorySizeGb;
    /**
     *
     */
    get memorySizeGb(): number;
    /**
     *
     */
    set memorySizeGb(value: number);
    /**
     *
     */
    get memorySizeGbInput(): number;
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    get nameInput(): string;
    /**
     *
     */
    get persistenceIamIdentity(): string;
    /**
     *
     */
    get port(): number;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _redisConfigs?;
    /**
     *
     */
    get redisConfigs(): {
        [key: string]: string;
    };
    /**
     *
     */
    set redisConfigs(value: {
        [key: string]: string;
    });
    /**
     *
     */
    resetRedisConfigs(): void;
    /**
     *
     */
    get redisConfigsInput(): {
        [key: string]: string;
    } | undefined;
    private _redisVersion?;
    /**
     *
     */
    get redisVersion(): string;
    /**
     *
     */
    set redisVersion(value: string);
    /**
     *
     */
    resetRedisVersion(): void;
    /**
     *
     */
    get redisVersionInput(): string | undefined;
    private _region?;
    /**
     *
     */
    get region(): string;
    /**
     *
     */
    set region(value: string);
    /**
     *
     */
    resetRegion(): void;
    /**
     *
     */
    get regionInput(): string | undefined;
    private _reservedIpRange?;
    /**
     *
     */
    get reservedIpRange(): string;
    /**
     *
     */
    set reservedIpRange(value: string);
    /**
     *
     */
    resetReservedIpRange(): void;
    /**
     *
     */
    get reservedIpRangeInput(): string | undefined;
    private _tier?;
    /**
     *
     */
    get tier(): string;
    /**
     *
     */
    set tier(value: string);
    /**
     *
     */
    resetTier(): void;
    /**
     *
     */
    get tierInput(): string | undefined;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): RedisInstanceTimeouts;
    /**
     *
     */
    set timeouts(value: RedisInstanceTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): RedisInstanceTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
