import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface ResourceManagerLienConfig extends TerraformMetaArguments {
    /**
     * A stable, user-visible/meaningful string identifying the origin of the Lien, intended to be inspected programmatically.
     *
     * Maximum length of
     * 200 characters.
     */
    readonly origin: string;
    /**
     * A reference to the resource this Lien is attached to.
     *
     * The server will validate the parent against those for which Liens are supported.
     * Since a variety of objects can have Liens against them, you must provide the type
     * prefix (e.g. "projects/my-project-name").
     */
    readonly parent: string;
    /**
     * Concise user-visible strings indicating why an action cannot be performed on a resource.
     *
     * Maximum length of 200 characters.
     */
    readonly reason: string;
    /**
     * The types of operations which should be blocked as a result of this Lien.
     *
     * Each value should correspond to an IAM permission. The server will validate
     * the permissions against those for which Liens are supported.  An empty
     * list is meaningless and will be rejected.
     * e.g. ['resourcemanager.projects.delete']
     */
    readonly restrictions: string[];
    /**
     * timeouts block.
     */
    readonly timeouts?: ResourceManagerLienTimeouts;
}
/**
 *
 */
export interface ResourceManagerLienTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
}
/**
 *
 */
export declare class ResourceManagerLien extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: ResourceManagerLienConfig);
    /**
     *
     */
    get createTime(): string;
    /**
     *
     */
    get id(): string;
    /**
     *
     */
    get name(): string;
    private _origin;
    /**
     *
     */
    get origin(): string;
    /**
     *
     */
    set origin(value: string);
    /**
     *
     */
    get originInput(): string;
    private _parent;
    /**
     *
     */
    get parent(): string;
    /**
     *
     */
    set parent(value: string);
    /**
     *
     */
    get parentInput(): string;
    private _reason;
    /**
     *
     */
    get reason(): string;
    /**
     *
     */
    set reason(value: string);
    /**
     *
     */
    get reasonInput(): string;
    private _restrictions;
    /**
     *
     */
    get restrictions(): string[];
    /**
     *
     */
    set restrictions(value: string[]);
    /**
     *
     */
    get restrictionsInput(): string[];
    private _timeouts?;
    /**
     *
     */
    get timeouts(): ResourceManagerLienTimeouts;
    /**
     *
     */
    set timeouts(value: ResourceManagerLienTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): ResourceManagerLienTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
