import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface SccSourceConfig extends TerraformMetaArguments {
    /**
     * The description of the source (max of 1024 characters).
     */
    readonly description?: string;
    /**
     * The source’s display name.
     *
     * A source’s display name must be unique
     * amongst its siblings, for example, two sources with the same parent
     * can't share the same display name. The display name must start and end
     * with a letter or digit, may contain letters, digits, spaces, hyphens,
     * and underscores, and can be no longer than 32 characters.
     */
    readonly displayName: string;
    /**
     * The organization whose Cloud Security Command Center the Source lives in.
     */
    readonly organization: string;
    /**
     * timeouts block.
     */
    readonly timeouts?: SccSourceTimeouts;
}
/**
 *
 */
export interface SccSourceTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class SccSource extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: SccSourceConfig);
    private _description?;
    /**
     *
     */
    get description(): string;
    /**
     *
     */
    set description(value: string);
    /**
     *
     */
    resetDescription(): void;
    /**
     *
     */
    get descriptionInput(): string | undefined;
    private _displayName;
    /**
     *
     */
    get displayName(): string;
    /**
     *
     */
    set displayName(value: string);
    /**
     *
     */
    get displayNameInput(): string;
    /**
     *
     */
    get id(): string;
    /**
     *
     */
    get name(): string;
    private _organization;
    /**
     *
     */
    get organization(): string;
    /**
     *
     */
    set organization(value: string);
    /**
     *
     */
    get organizationInput(): string;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): SccSourceTimeouts;
    /**
     *
     */
    set timeouts(value: SccSourceTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): SccSourceTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
