import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface SourcerepoRepositoryConfig extends TerraformMetaArguments {
    /**
     * Resource name of the repository, of the form '{{repo}}'.
     *
     * The repo name may contain slashes. eg, 'name/with/slash'
     */
    readonly name: string;
    /**
     *
     */
    readonly project?: string;
    /**
     * pubsub_configs block.
     */
    readonly pubsubConfigs?: SourcerepoRepositoryPubsubConfigs[];
    /**
     * timeouts block.
     */
    readonly timeouts?: SourcerepoRepositoryTimeouts;
}
/**
 *
 */
export interface SourcerepoRepositoryPubsubConfigs {
    /**
     * The format of the Cloud Pub/Sub messages.
     *
     * - PROTOBUF: The message payload is a serialized protocol buffer of SourceRepoEvent.
     * - JSON: The message payload is a JSON string of SourceRepoEvent. Possible values: ["PROTOBUF", "JSON"]
     */
    readonly messageFormat: string;
    /**
     * Email address of the service account used for publishing Cloud Pub/Sub messages.
     *
     * This service account needs to be in the same project as the PubsubConfig. When added,
     * the caller needs to have iam.serviceAccounts.actAs permission on this service account.
     * If unspecified, it defaults to the compute engine default service account.
     */
    readonly serviceAccountEmail?: string;
    /**
     *
     */
    readonly topic: string;
}
/**
 *
 */
export interface SourcerepoRepositoryTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class SourcerepoRepository extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: SourcerepoRepositoryConfig);
    /**
     *
     */
    get id(): string;
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    get nameInput(): string;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    /**
     *
     */
    get size(): number;
    /**
     *
     */
    get url(): string;
    private _pubsubConfigs?;
    /**
     *
     */
    get pubsubConfigs(): SourcerepoRepositoryPubsubConfigs[];
    /**
     *
     */
    set pubsubConfigs(value: SourcerepoRepositoryPubsubConfigs[]);
    /**
     *
     */
    resetPubsubConfigs(): void;
    /**
     *
     */
    get pubsubConfigsInput(): SourcerepoRepositoryPubsubConfigs[] | undefined;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): SourcerepoRepositoryTimeouts;
    /**
     *
     */
    set timeouts(value: SourcerepoRepositoryTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): SourcerepoRepositoryTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
