import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface SpannerDatabaseConfig extends TerraformMetaArguments {
    /**
     * An optional list of DDL statements to run inside the newly created database.
     *
     * Statements can create tables, indexes, etc. These statements
     * execute atomically with the creation of the database: if there is an
     * error in any statement, the database is not created.
     */
    readonly ddl?: string[];
    /**
     *
     */
    readonly deletionProtection?: boolean;
    /**
     * The instance to create the database on.
     */
    readonly instance: string;
    /**
     * A unique identifier for the database, which cannot be changed after the instance is created.
     *
     * Values are of the form [a-z][-a-z0-9]*[a-z0-9].
     */
    readonly name: string;
    /**
     *
     */
    readonly project?: string;
    /**
     * timeouts block.
     */
    readonly timeouts?: SpannerDatabaseTimeouts;
}
/**
 *
 */
export interface SpannerDatabaseTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class SpannerDatabase extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: SpannerDatabaseConfig);
    private _ddl?;
    /**
     *
     */
    get ddl(): string[];
    /**
     *
     */
    set ddl(value: string[]);
    /**
     *
     */
    resetDdl(): void;
    /**
     *
     */
    get ddlInput(): string[] | undefined;
    private _deletionProtection?;
    /**
     *
     */
    get deletionProtection(): boolean;
    /**
     *
     */
    set deletionProtection(value: boolean);
    /**
     *
     */
    resetDeletionProtection(): void;
    /**
     *
     */
    get deletionProtectionInput(): boolean | undefined;
    /**
     *
     */
    get id(): string;
    private _instance;
    /**
     *
     */
    get instance(): string;
    /**
     *
     */
    set instance(value: string);
    /**
     *
     */
    get instanceInput(): string;
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    get nameInput(): string;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    /**
     *
     */
    get state(): string;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): SpannerDatabaseTimeouts;
    /**
     *
     */
    set timeouts(value: SpannerDatabaseTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): SpannerDatabaseTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
