import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface SpannerInstanceConfig extends TerraformMetaArguments {
    /**
     * The name of the instance's configuration (similar but not quite the same as a region) which defines defines the geographic placement and replication of your databases in this instance.
     *
     * It determines where your data
     * is stored. Values are typically of the form 'regional-europe-west1' , 'us-central' etc.
     * In order to obtain a valid list please consult the
     * [Configuration section of the docs](https://cloud.google.com/spanner/docs/instances).
     */
    readonly config: string;
    /**
     * The descriptive name for this instance as it appears in UIs.
     *
     * Must be
     * unique per project and between 4 and 30 characters in length.
     */
    readonly displayName: string;
    /**
     * An object containing a list of "key": value pairs.
     *
     * Example: { "name": "wrench", "mass": "1.3kg", "count": "3" }.
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * A unique identifier for the instance, which cannot be changed after the instance is created.
     *
     * The name must be between 6 and 30 characters
     * in length.
     *
     *
     * If not provided, a random string starting with 'tf-' will be selected.
     */
    readonly name?: string;
    /**
     * The number of nodes allocated to this instance.
     */
    readonly numNodes?: number;
    /**
     *
     */
    readonly project?: string;
    /**
     * timeouts block.
     */
    readonly timeouts?: SpannerInstanceTimeouts;
}
/**
 *
 */
export interface SpannerInstanceTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class SpannerInstance extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: SpannerInstanceConfig);
    private _config;
    /**
     *
     */
    get config(): string;
    /**
     *
     */
    set config(value: string);
    /**
     *
     */
    get configInput(): string;
    private _displayName;
    /**
     *
     */
    get displayName(): string;
    /**
     *
     */
    set displayName(value: string);
    /**
     *
     */
    get displayNameInput(): string;
    /**
     *
     */
    get id(): string;
    private _labels?;
    /**
     *
     */
    get labels(): {
        [key: string]: string;
    };
    /**
     *
     */
    set labels(value: {
        [key: string]: string;
    });
    /**
     *
     */
    resetLabels(): void;
    /**
     *
     */
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    resetName(): void;
    /**
     *
     */
    get nameInput(): string | undefined;
    private _numNodes?;
    /**
     *
     */
    get numNodes(): number;
    /**
     *
     */
    set numNodes(value: number);
    /**
     *
     */
    resetNumNodes(): void;
    /**
     *
     */
    get numNodesInput(): number | undefined;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    /**
     *
     */
    get state(): string;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): SpannerInstanceTimeouts;
    /**
     *
     */
    set timeouts(value: SpannerInstanceTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): SpannerInstanceTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
