import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
import { ComplexComputedList } from "cdktf";
/**
 *
 */
export interface SqlDatabaseInstanceConfig extends TerraformMetaArguments {
    /**
     * The MySQL, PostgreSQL or SQL Server (beta) version to use.
     *
     * Supported values include MYSQL_5_6, MYSQL_5_7, POSTGRES_9_6,POSTGRES_11, SQLSERVER_2017_STANDARD, SQLSERVER_2017_ENTERPRISE, SQLSERVER_2017_EXPRESS, SQLSERVER_2017_WEB. Database Version Policies includes an up-to-date reference of supported versions.
     */
    readonly databaseVersion?: string;
    /**
     * Used to block Terraform from deleting a SQL Instance.
     */
    readonly deletionProtection?: boolean;
    /**
     * The name of the instance that will act as the master in the replication setup.
     *
     * Note, this requires the master to have binary_log_enabled set, as well as existing backups.
     */
    readonly masterInstanceName?: string;
    /**
     * The name of the instance.
     *
     * If the name is left blank, Terraform will randomly generate one when the instance is first created. This is done because after a name is used, it cannot be reused for up to one week.
     */
    readonly name?: string;
    /**
     * The ID of the project in which the resource belongs.
     *
     * If it is not provided, the provider project is used.
     */
    readonly project?: string;
    /**
     * The region the instance will sit in.
     *
     * Note, Cloud SQL is not available in all regions - choose from one of the options listed here. A valid region must be provided to use this resource. If a region is not provided in the resource definition, the provider region will be used instead, but this will be an apply-time error for instances if the provider region is not supported with Cloud SQL. If you choose not to provide the region argument for this resource, make sure you understand this.
     */
    readonly region?: string;
    /**
     * Initial root password.
     *
     * Required for MS SQL Server, ignored by MySQL and PostgreSQL.
     */
    readonly rootPassword?: string;
    /**
     * replica_configuration block.
     */
    readonly replicaConfiguration?: SqlDatabaseInstanceReplicaConfiguration[];
    /**
     * settings block.
     */
    readonly settings: SqlDatabaseInstanceSettings[];
    /**
     * timeouts block.
     */
    readonly timeouts?: SqlDatabaseInstanceTimeouts;
}
/**
 *
 */
export declare class SqlDatabaseInstanceIpAddress extends ComplexComputedList {
    /**
     *
     */
    get ipAddress(): string;
    /**
     *
     */
    get timeToRetire(): string;
    /**
     *
     */
    get type(): string;
}
/**
 *
 */
export declare class SqlDatabaseInstanceServerCaCert extends ComplexComputedList {
    /**
     *
     */
    get cert(): string;
    /**
     *
     */
    get commonName(): string;
    /**
     *
     */
    get createTime(): string;
    /**
     *
     */
    get expirationTime(): string;
    /**
     *
     */
    get sha1Fingerprint(): string;
}
/**
 *
 */
export interface SqlDatabaseInstanceReplicaConfiguration {
    /**
     * PEM representation of the trusted CA's x509 certificate.
     */
    readonly caCertificate?: string;
    /**
     * PEM representation of the slave's x509 certificate.
     */
    readonly clientCertificate?: string;
    /**
     * PEM representation of the slave's private key.
     *
     * The corresponding public key in encoded in the client_certificate.
     */
    readonly clientKey?: string;
    /**
     * The number of seconds between connect retries.
     */
    readonly connectRetryInterval?: number;
    /**
     * Path to a SQL file in Google Cloud Storage from which slave instances are created.
     *
     * Format is gs://bucket/filename.
     */
    readonly dumpFilePath?: string;
    /**
     * Specifies if the replica is the failover target.
     *
     * If the field is set to true the replica will be designated as a failover replica. If the master instance fails, the replica instance will be promoted as the new master instance.
     */
    readonly failoverTarget?: boolean;
    /**
     * Time in ms between replication heartbeats.
     */
    readonly masterHeartbeatPeriod?: number;
    /**
     * Password for the replication connection.
     */
    readonly password?: string;
    /**
     * Permissible ciphers for use in SSL encryption.
     */
    readonly sslCipher?: string;
    /**
     * Username for replication connection.
     */
    readonly username?: string;
    /**
     * True if the master's common name value is checked during the SSL handshake.
     */
    readonly verifyServerCertificate?: boolean;
}
/**
 *
 */
export interface SqlDatabaseInstanceSettingsBackupConfiguration {
    /**
     * True if binary logging is enabled.
     *
     * If settings.backup_configuration.enabled is false, this must be as well. Cannot be used with Postgres.
     */
    readonly binaryLogEnabled?: boolean;
    /**
     * True if backup configuration is enabled.
     */
    readonly enabled?: boolean;
    /**
     * Location of the backup configuration.
     */
    readonly location?: string;
    /**
     * True if Point-in-time recovery is enabled.
     */
    readonly pointInTimeRecoveryEnabled?: boolean;
    /**
     * HH:MM format time indicating when backup configuration starts.
     */
    readonly startTime?: string;
}
/**
 *
 */
export interface SqlDatabaseInstanceSettingsDatabaseFlags {
    /**
     * Name of the flag.
     */
    readonly name: string;
    /**
     * Value of the flag.
     */
    readonly value: string;
}
/**
 *
 */
export interface SqlDatabaseInstanceSettingsIpConfigurationAuthorizedNetworks {
    /**
     *
     */
    readonly expirationTime?: string;
    /**
     *
     */
    readonly name?: string;
    /**
     *
     */
    readonly value: string;
}
/**
 *
 */
export interface SqlDatabaseInstanceSettingsIpConfiguration {
    /**
     * Whether this Cloud SQL instance should be assigned a public IPV4 address.
     *
     * Either ipv4_enabled must be enabled or a private_network must be configured.
     */
    readonly ipv4Enabled?: boolean;
    /**
     * The VPC network from which the Cloud SQL instance is accessible for private IP.
     *
     * For example, projects/myProject/global/networks/default. Specifying a network enables private IP. Either ipv4_enabled must be enabled or a private_network must be configured. This setting can be updated, but it cannot be removed after it is set.
     */
    readonly privateNetwork?: string;
    /**
     *
     */
    readonly requireSsl?: boolean;
    /**
     * authorized_networks block.
     */
    readonly authorizedNetworks?: SqlDatabaseInstanceSettingsIpConfigurationAuthorizedNetworks[];
}
/**
 *
 */
export interface SqlDatabaseInstanceSettingsLocationPreference {
    /**
     * A Google App Engine application whose zone to remain in.
     *
     * Must be in the same region as this instance.
     */
    readonly followGaeApplication?: string;
    /**
     * The preferred compute engine zone.
     */
    readonly zone?: string;
}
/**
 *
 */
export interface SqlDatabaseInstanceSettingsMaintenanceWindow {
    /**
     * Day of week (1-7), starting on Monday.
     */
    readonly day?: number;
    /**
     * Hour of day (0-23), ignored if day not set.
     */
    readonly hour?: number;
    /**
     * Receive updates earlier (canary) or later (stable).
     */
    readonly updateTrack?: string;
}
/**
 *
 */
export interface SqlDatabaseInstanceSettings {
    /**
     * This specifies when the instance should be active.
     *
     * Can be either ALWAYS, NEVER or ON_DEMAND.
     */
    readonly activationPolicy?: string;
    /**
     * This property is only applicable to First Generation instances.
     *
     * First Generation instances are now deprecated, see https://cloud.google.com/sql/docs/mysql/deprecation-notice for information on how to upgrade to Second Generation instances. A list of Google App Engine project names that are allowed to access this instance.
     */
    readonly authorizedGaeApplications?: string[];
    /**
     * The availability type of the Cloud SQL instance, high availability (REGIONAL) or single zone (ZONAL).
     *
     * For MySQL instances, ensure that
     * settings.backup_configuration.enabled and
     * settings.backup_configuration.binary_log_enabled are both set to true.
     */
    readonly availabilityType?: string;
    /**
     * This property is only applicable to First Generation instances.
     *
     * First Generation instances are now deprecated, see here for information on how to upgrade to Second Generation instances. Specific to read instances, indicates when crash-safe replication flags are enabled.
     */
    readonly crashSafeReplication?: boolean;
    /**
     * Configuration to increase storage size automatically.
     *
     * Note that future terraform apply calls will attempt to resize the disk to the value specified in disk_size - if this is set, do not set disk_size.
     */
    readonly diskAutoresize?: boolean;
    /**
     * The size of data disk, in GB.
     *
     * Size of a running instance cannot be reduced but can be increased.
     */
    readonly diskSize?: number;
    /**
     * The type of data disk: PD_SSD or PD_HDD.
     */
    readonly diskType?: string;
    /**
     * Pricing plan for this instance, can only be PER_USE.
     */
    readonly pricingPlan?: string;
    /**
     * This property is only applicable to First Generation instances.
     *
     * First Generation instances are now deprecated, see here for information on how to upgrade to Second Generation instances. Replication type for this instance, can be one of ASYNCHRONOUS or SYNCHRONOUS.
     */
    readonly replicationType?: string;
    /**
     * The machine type to use.
     *
     * See tiers for more details and supported versions. Postgres supports only shared-core machine types such as db-f1-micro, and custom machine types such as db-custom-2-13312. See the Custom Machine Type Documentation to learn about specifying custom machine types.
     */
    readonly tier: string;
    /**
     * A set of key/value user label pairs to assign to the instance.
     */
    readonly userLabels?: {
        [key: string]: string;
    };
    /**
     * backup_configuration block.
     */
    readonly backupConfiguration?: SqlDatabaseInstanceSettingsBackupConfiguration[];
    /**
     * database_flags block.
     */
    readonly databaseFlags?: SqlDatabaseInstanceSettingsDatabaseFlags[];
    /**
     * ip_configuration block.
     */
    readonly ipConfiguration?: SqlDatabaseInstanceSettingsIpConfiguration[];
    /**
     * location_preference block.
     */
    readonly locationPreference?: SqlDatabaseInstanceSettingsLocationPreference[];
    /**
     * maintenance_window block.
     */
    readonly maintenanceWindow?: SqlDatabaseInstanceSettingsMaintenanceWindow[];
}
/**
 *
 */
export interface SqlDatabaseInstanceTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class SqlDatabaseInstance extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: SqlDatabaseInstanceConfig);
    /**
     *
     */
    get connectionName(): string;
    private _databaseVersion?;
    /**
     *
     */
    get databaseVersion(): string;
    /**
     *
     */
    set databaseVersion(value: string);
    /**
     *
     */
    resetDatabaseVersion(): void;
    /**
     *
     */
    get databaseVersionInput(): string | undefined;
    private _deletionProtection?;
    /**
     *
     */
    get deletionProtection(): boolean;
    /**
     *
     */
    set deletionProtection(value: boolean);
    /**
     *
     */
    resetDeletionProtection(): void;
    /**
     *
     */
    get deletionProtectionInput(): boolean | undefined;
    /**
     *
     */
    get firstIpAddress(): string;
    /**
     *
     */
    get id(): string;
    /**
     *
     */
    ipAddress(index: string): SqlDatabaseInstanceIpAddress;
    private _masterInstanceName?;
    /**
     *
     */
    get masterInstanceName(): string;
    /**
     *
     */
    set masterInstanceName(value: string);
    /**
     *
     */
    resetMasterInstanceName(): void;
    /**
     *
     */
    get masterInstanceNameInput(): string | undefined;
    private _name?;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    resetName(): void;
    /**
     *
     */
    get nameInput(): string | undefined;
    /**
     *
     */
    get privateIpAddress(): string;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    /**
     *
     */
    get publicIpAddress(): string;
    private _region?;
    /**
     *
     */
    get region(): string;
    /**
     *
     */
    set region(value: string);
    /**
     *
     */
    resetRegion(): void;
    /**
     *
     */
    get regionInput(): string | undefined;
    private _rootPassword?;
    /**
     *
     */
    get rootPassword(): string;
    /**
     *
     */
    set rootPassword(value: string);
    /**
     *
     */
    resetRootPassword(): void;
    /**
     *
     */
    get rootPasswordInput(): string | undefined;
    /**
     *
     */
    get selfLink(): string;
    /**
     *
     */
    serverCaCert(index: string): SqlDatabaseInstanceServerCaCert;
    /**
     *
     */
    get serviceAccountEmailAddress(): string;
    private _replicaConfiguration?;
    /**
     *
     */
    get replicaConfiguration(): SqlDatabaseInstanceReplicaConfiguration[];
    /**
     *
     */
    set replicaConfiguration(value: SqlDatabaseInstanceReplicaConfiguration[]);
    /**
     *
     */
    resetReplicaConfiguration(): void;
    /**
     *
     */
    get replicaConfigurationInput(): SqlDatabaseInstanceReplicaConfiguration[] | undefined;
    private _settings;
    /**
     *
     */
    get settings(): SqlDatabaseInstanceSettings[];
    /**
     *
     */
    set settings(value: SqlDatabaseInstanceSettings[]);
    /**
     *
     */
    get settingsInput(): SqlDatabaseInstanceSettings[];
    private _timeouts?;
    /**
     *
     */
    get timeouts(): SqlDatabaseInstanceTimeouts;
    /**
     *
     */
    set timeouts(value: SqlDatabaseInstanceTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): SqlDatabaseInstanceTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
