import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface SqlSourceRepresentationInstanceConfig extends TerraformMetaArguments {
    /**
     * The MySQL version running on your source database server.
     *
     * Possible values: ["MYSQL_5_6", "MYSQL_5_7"]
     */
    readonly databaseVersion: string;
    /**
     * The externally accessible IPv4 address for the source database server.
     */
    readonly host: string;
    /**
     * The name of the source representation instance.
     *
     * Use any valid Cloud SQL instance name.
     */
    readonly name: string;
    /**
     * The externally accessible port for the source database server.
     *
     * Defaults to 3306.
     */
    readonly port?: number;
    /**
     *
     */
    readonly project?: string;
    /**
     * The Region in which the created instance should reside.
     *
     * If it is not provided, the provider region is used.
     */
    readonly region?: string;
    /**
     * timeouts block.
     */
    readonly timeouts?: SqlSourceRepresentationInstanceTimeouts;
}
/**
 *
 */
export interface SqlSourceRepresentationInstanceTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
}
/**
 *
 */
export declare class SqlSourceRepresentationInstance extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: SqlSourceRepresentationInstanceConfig);
    private _databaseVersion;
    /**
     *
     */
    get databaseVersion(): string;
    /**
     *
     */
    set databaseVersion(value: string);
    /**
     *
     */
    get databaseVersionInput(): string;
    private _host;
    /**
     *
     */
    get host(): string;
    /**
     *
     */
    set host(value: string);
    /**
     *
     */
    get hostInput(): string;
    /**
     *
     */
    get id(): string;
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    get nameInput(): string;
    private _port?;
    /**
     *
     */
    get port(): number;
    /**
     *
     */
    set port(value: number);
    /**
     *
     */
    resetPort(): void;
    /**
     *
     */
    get portInput(): number | undefined;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _region?;
    /**
     *
     */
    get region(): string;
    /**
     *
     */
    set region(value: string);
    /**
     *
     */
    resetRegion(): void;
    /**
     *
     */
    get regionInput(): string | undefined;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): SqlSourceRepresentationInstanceTimeouts;
    /**
     *
     */
    set timeouts(value: SqlSourceRepresentationInstanceTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): SqlSourceRepresentationInstanceTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
