import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface SqlUserConfig extends TerraformMetaArguments {
    /**
     * The host the user can connect from.
     *
     * This is only supported for MySQL instances. Don't set this field for PostgreSQL instances. Can be an IP address. Changing this forces a new resource to be created.
     */
    readonly host?: string;
    /**
     * The name of the Cloud SQL instance.
     *
     * Changing this forces a new resource to be created.
     */
    readonly instance: string;
    /**
     * The name of the user.
     *
     * Changing this forces a new resource to be created.
     */
    readonly name: string;
    /**
     * The password for the user.
     *
     * Can be updated. For Postgres instances this is a Required field.
     */
    readonly password?: string;
    /**
     * The ID of the project in which the resource belongs.
     *
     * If it is not provided, the provider project is used.
     */
    readonly project?: string;
    /**
     * timeouts block.
     */
    readonly timeouts?: SqlUserTimeouts;
}
/**
 *
 */
export interface SqlUserTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class SqlUser extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: SqlUserConfig);
    private _host?;
    /**
     *
     */
    get host(): string;
    /**
     *
     */
    set host(value: string);
    /**
     *
     */
    resetHost(): void;
    /**
     *
     */
    get hostInput(): string | undefined;
    /**
     *
     */
    get id(): string;
    private _instance;
    /**
     *
     */
    get instance(): string;
    /**
     *
     */
    set instance(value: string);
    /**
     *
     */
    get instanceInput(): string;
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    get nameInput(): string;
    private _password?;
    /**
     *
     */
    get password(): string;
    /**
     *
     */
    set password(value: string);
    /**
     *
     */
    resetPassword(): void;
    /**
     *
     */
    get passwordInput(): string | undefined;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): SqlUserTimeouts;
    /**
     *
     */
    set timeouts(value: SqlUserTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): SqlUserTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
