import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface VpcAccessConnectorConfig extends TerraformMetaArguments {
    /**
     * The range of internal addresses that follows RFC 4632 notation.
     *
     * Example: '10.132.0.0/28'.
     */
    readonly ipCidrRange: string;
    /**
     * Maximum throughput of the connector in Mbps, must be greater than 'min_throughput'.
     *
     * Default is 1000.
     */
    readonly maxThroughput?: number;
    /**
     * Minimum throughput of the connector in Mbps.
     *
     * Default and min is 200.
     */
    readonly minThroughput?: number;
    /**
     * The name of the resource (Max 25 characters).
     */
    readonly name: string;
    /**
     * Name of a VPC network.
     */
    readonly network: string;
    /**
     *
     */
    readonly project?: string;
    /**
     * Region where the VPC Access connector resides.
     */
    readonly region: string;
    /**
     * timeouts block.
     */
    readonly timeouts?: VpcAccessConnectorTimeouts;
}
/**
 *
 */
export interface VpcAccessConnectorTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
}
/**
 *
 */
export declare class VpcAccessConnector extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: VpcAccessConnectorConfig);
    /**
     *
     */
    get id(): string;
    private _ipCidrRange;
    /**
     *
     */
    get ipCidrRange(): string;
    /**
     *
     */
    set ipCidrRange(value: string);
    /**
     *
     */
    get ipCidrRangeInput(): string;
    private _maxThroughput?;
    /**
     *
     */
    get maxThroughput(): number;
    /**
     *
     */
    set maxThroughput(value: number);
    /**
     *
     */
    resetMaxThroughput(): void;
    /**
     *
     */
    get maxThroughputInput(): number | undefined;
    private _minThroughput?;
    /**
     *
     */
    get minThroughput(): number;
    /**
     *
     */
    set minThroughput(value: number);
    /**
     *
     */
    resetMinThroughput(): void;
    /**
     *
     */
    get minThroughputInput(): number | undefined;
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    get nameInput(): string;
    private _network;
    /**
     *
     */
    get network(): string;
    /**
     *
     */
    set network(value: string);
    /**
     *
     */
    get networkInput(): string;
    private _project?;
    /**
     *
     */
    get project(): string;
    /**
     *
     */
    set project(value: string);
    /**
     *
     */
    resetProject(): void;
    /**
     *
     */
    get projectInput(): string | undefined;
    private _region;
    /**
     *
     */
    get region(): string;
    /**
     *
     */
    set region(value: string);
    /**
     *
     */
    get regionInput(): string;
    /**
     *
     */
    get selfLink(): string;
    /**
     *
     */
    get state(): string;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): VpcAccessConnectorTimeouts;
    /**
     *
     */
    set timeouts(value: VpcAccessConnectorTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): VpcAccessConnectorTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
